@@ -1,19 +1,9 @@
-/***************************************************************************
-                          showedittextfileagent  -  description
-                             -------------------
-    begin                : Tue Sep 13 2005
-    copyright            : (C) 2005, 2010, 2016 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+showedittextfileagent - This file is part of the RKWard project. Created: Tue Sep 13 2005
+SPDX-FileCopyrightText: 2005-2016 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef SHOWEDITTEXTFILEAGENT_H
 #define SHOWEDITTEXTFILEAGENT_H
