@@ -27,8 +27,8 @@ REnvironmentObject::REnvironmentObject (RContainerObject *parent, const QString
 		if (name.contains (':')) {
 			type |= PackageEnv;
 		}
-	} else if (parent == 0) {
-		RK_ASSERT (name == ".GlobalEnv");
+	} else if (parent == nullptr) {
+		RK_ASSERT(name == QStringLiteral(".GlobalEnv"));
 		type |= ToplevelEnv | GlobalEnv;
 	}
 }
@@ -55,10 +55,10 @@ QString REnvironmentObject::getFullName (int options) const {
 
 	if (type & GlobalEnv) return name;	// .GlobalEnv
 	if ((type & ToplevelEnv) && (options & IncludeEnvirIfNotGlobalEnv)) return ("as.environment (" + rQuote (name) + ')');
-	return parent->makeChildName (name, type & Misplaced, options);
+	return parent->makeChildName(name, options);
 }
 
-QString REnvironmentObject::makeChildName (const QString &short_child_name, bool misplaced, int options) const {
+QString REnvironmentObject::makeChildName (const QString &short_child_name, int options) const {
 	RK_TRACE (OBJECTS);
 
 	QString safe_name;
@@ -77,8 +77,8 @@ QString REnvironmentObject::makeChildName (const QString &short_child_name, bool
 /* Some items are placed outside of their native namespace. E.g. in package:boot item "motor". It can be retrieved using as.environment ("package:boot")$motor. This is extremely ugly. We need to give them (and only them) this special treatment. */
 // TODO: hopefully one day operator "::" will work even in those cases. So check back later, and remove after a sufficient amount of backwards compatibility time
 // NOTE: This appears to have been fixed in R 2.14.0, when all packages were forced to have namespaces. Currently backend has a version check to set "misplaced", appropriately.
-		if ((type & PackageEnv) && (!misplaced)) return (packageName () + "::" + safe_name);
-		return (getFullName (options) + '$' + safe_name);
+		if (type & PackageEnv) return (packageName() + "::" + safe_name);
+		return (getFullName(options) + '$' + safe_name);
 	}
 	return (getFullName (options) + '$' + safe_name);
 }
@@ -95,8 +95,8 @@ void REnvironmentObject::updateFromR(RCommandChain *chain, const QStringList &ad
 
 	for (int i = removed_symbols.size() -1; i >= 0; --i) {
 		RObject *removed_object = findChildByName(removed_symbols[i]);
-		RK_ASSERT(removed_object);
-		if (removed_object) RKModificationTracker::instance()->removeObject(removed_object, 0, true);
+		if(!removed_object) RK_DEBUG(OBJECTS, DL_ERROR, "Removed object %s was not registered", qPrintable(removed_symbols[i]));
+		if (removed_object) RKModificationTracker::instance()->removeObject(removed_object, nullptr, true);
 	}
 
 	for (int i = added_symbols.size() -1; i >= 0; --i) {
@@ -135,7 +135,7 @@ bool REnvironmentObject::updateStructure (RData *new_data) {
 		if (new_data->getDataLength () > (StorageSizeBasicInfo + 1)) {
 			RK_ASSERT (new_data->getDataLength () == (StorageSizeBasicInfo + 2));
 			updateNamespace (new_data_data.at (StoragePositionNamespace));
-		} else updateNamespace (0);
+		} else updateNamespace(nullptr);
 	} else {
 		RK_ASSERT (false);
 	}
@@ -146,7 +146,7 @@ void REnvironmentObject::updateNamespace (RData* new_data) {
 	RK_TRACE (OBJECTS);
 
 	if (!new_data) {
-		setSpecialChildObject (0, NamespaceObject);
+		setSpecialChildObject(nullptr, NamespaceObject);
 		return;
 	}
 
@@ -168,7 +168,7 @@ void REnvironmentObject::updateNamespace (RData* new_data) {
 QString REnvironmentObject::renameChildCommand (RObject *object, const QString &new_name) const {
 	RK_TRACE (OBJECTS);
 
-	return (makeChildName (new_name, false, IncludeEnvirIfNotGlobalEnv) + " <- " + object->getFullName () + '\n' + removeChildCommand (object));
+	return (makeChildName(new_name, IncludeEnvirIfNotGlobalEnv) + " <- " + object->getFullName() + '\n' + removeChildCommand(object));
 }
 
 QString REnvironmentObject::removeChildCommand (RObject *object) const {
