@@ -9,7 +9,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "../rbackend/rdata.h"
 #include "rkmodificationtracker.h"
-#include "../rkglobals.h"
+
 #include "../debug.h"
 
 RFunctionObject::RFunctionObject (RObject *parent, const QString &name) : RObject (parent, name) {
@@ -43,7 +43,7 @@ bool RFunctionObject::updateStructure (RData *new_data) {
 
 	if (!RObject::updateStructure (new_data)) return false;
 
-	if (updateArguments (new_data)) RKGlobals::tracker ()->objectMetaChanged (this);
+	if (updateArguments (new_data)) RKModificationTracker::instance()->objectMetaChanged (this);
 
 	return true;
 }
