@@ -37,7 +37,7 @@ public:
 	ListenerType listenerType () const { return type; };
 	bool wantsNotificationType (NotificationType type) const { return (notifications & type); };
 protected:
-	RObjectListener (ListenerType type);
+	explicit RObjectListener(ListenerType type);
 	virtual ~RObjectListener ();
 
 friend class RKModificationTracker;
@@ -76,8 +76,8 @@ public:
 		ColumnCount = ClassColumn + 1
 	};
 protected:
-	RKObjectListModel (QObject *parent);
-	virtual ~RKObjectListModel ();
+	explicit RKObjectListModel(QObject *parent);
+	virtual ~RKObjectListModel();
 public:
 	/** implements QAbstractItemModel::index() */
 	QModelIndex index (int row, int column, const QModelIndex& parent = QModelIndex ()) const override;
@@ -116,7 +116,7 @@ public:
 	static RKModificationTracker* instance() { return _instance; };
 	
 /** the given object should be removed (either it was removed in the R-workspace, or the user requests removal of the object in an editor or the RObjectList). First, if the object is being edited somewhere, the user will get a chance to object to the removal. If the user does not object, the RKModificationTracker will remove the object and notify all interested listeners that the object really was removed. When calling from the RObjectList, you will likely set removed_in_workspace to true, to signal that the object-data is already gone in the workspace. */
-	bool removeObject (RObject *object, RKEditor *editor=0, bool removed_in_workspace=false);
+	bool removeObject (RObject *object, RKEditor *editor=nullptr, bool removed_in_workspace=false);
 /** essentially like the above function, but requests a renaming of the object. Will also take care of finding out, whether the name is valid and prompting for a different name otherwise. */
 	void renameObject (RObject *object, const QString &new_name);
 /** the object's meta data was modified. Tells all editors and lists containing the object to update accordingly. */
