@@ -26,7 +26,7 @@ public:
 	~RSlotsPseudoObject ();
 
 	QString getFullName (int) const override;
-	QString makeChildName (const QString &short_child_name, bool misplaced, int) const override;
+	QString makeChildName(const QString &short_child_name, int) const override;
 };
 
 /**
@@ -42,7 +42,7 @@ public:
 	~RKNamespaceObject ();
 
 	QString getFullName (int) const override;
-	QString makeChildName (const QString &short_child_name, bool misplaced, int) const override;
+	QString makeChildName(const QString &short_child_name, int) const override;
 	QString namespaceName () const { return namespace_name; };
 private:
 	QString namespace_name;
@@ -65,7 +65,7 @@ public:
 	~RKOrphanNamespacesObject ();
 
 	QString getFullName (int options) const override;
-	QString makeChildName (const QString &short_child_name, bool misplaced, int options) const override;
+	QString makeChildName(const QString &short_child_name, int options) const override;
 	QString getObjectDescription () const override;
 
 	RKNamespaceObject *findOrphanNamespace (const QString &name) const;
