@@ -33,7 +33,7 @@ namespace RObjectPrivate {
  *  This is needed, because RObject is not QObject dereived. */
 class RObjectLifeTimeGuard {
 public:
-	RObjectLifeTimeGuard(RObject *object) : command_count(0), object(object) {
+	explicit RObjectLifeTimeGuard(RObject *object) : command_count(0), object(object) {
 		object->guard = this;
 	};
 	~RObjectLifeTimeGuard() {
@@ -75,7 +75,7 @@ RObject::RObject (RObject *parent, const QString &name) {
 	RObject::parent = parent;
 	RObject::name = name;
 	type = 0;
-	meta_map = 0;
+	meta_map = nullptr;
 	contained_objects = 0;
 	dimensions = RObjectPrivate::dim_null;	// safe initialization
 	guard = nullptr;
@@ -121,7 +121,7 @@ bool RObject::irregularShortName (const QString &name) {
 
 QString RObject::getFullName (int options) const {
 	RK_TRACE (OBJECTS);
-	return parent->makeChildName (RObject::name, type & Misplaced, options);
+	return parent->makeChildName(RObject::name, options);
 }
 
 QString RObject::getLabel () const {
@@ -214,7 +214,7 @@ void RObject::setMetaProperty (const QString &id, const QString &value, bool syn
 		meta_map->insert (id, value);
 	}
 
-	if (sync) writeMetaData (0);
+	if (sync) writeMetaData(nullptr);
 	RKModificationTracker::instance()->objectMetaChanged (this);
 }
 
@@ -229,7 +229,7 @@ bool RObject::inherits (const QString &class_name) const {
 	return (classnames.contains (class_name));
 }
 
-QString RObject::makeChildName (const QString &short_child_name, bool, int options) const {
+QString RObject::makeChildName(const QString &short_child_name, int options) const {
 	RK_TRACE (OBJECTS);
 	if (options & DollarExpansion) {
 		if (irregularShortName (short_child_name)) return (getFullName (options) + '$' + rQuote (short_child_name));
@@ -248,7 +248,7 @@ void RObject::writeMetaData (RCommandChain *chain) {
 		map_string.append ("NULL");
 
 		delete meta_map;	// now that it is synced, delete it
-		meta_map = 0;
+		meta_map = nullptr;
 	} else {
 		for (MetaMap::const_iterator it = meta_map->constBegin (); it != meta_map->constEnd (); ++it) {
 			if (!map_string.isEmpty ()) map_string.append (", ");
@@ -272,7 +272,7 @@ void RObject::updateFromR (RCommandChain *chain) {
 	} else if (isType(Environment)) {
 		REnvironmentObject *env = static_cast<REnvironmentObject*>(this);
 		if (isType(PackageEnv) && RKSettingsModuleObjectBrowser::isPackageBlacklisted(env->packageName())) {
-			KMessageBox::information (0, i18n ("The package '%1' (probably you just loaded it) is currently blacklisted for retrieving structure information. Practically this means, the objects in this package will not appear in the object browser, and there will be no object name completion or function argument hinting for objects in this package.\nPackages will typically be blacklisted, if they contain huge amount of data, that would take too long to load. To unlist the package, visit Settings->Configure RKWard->Workspace.", env->packageName()), i18n("Package blacklisted"), "packageblacklist" + env->packageName());
+			KMessageBox::information(nullptr, i18n ("The package '%1' (probably you just loaded it) is currently blacklisted for retrieving structure information. Practically this means, the objects in this package will not appear in the object browser, and there will be no object name completion or function argument hinting for objects in this package.\nPackages will typically be blacklisted, if they contain huge amount of data, that would take too long to load. To unlist the package, visit Settings->Configure RKWard->Workspace.", env->packageName()), i18n("Package blacklisted"), "packageblacklist" + env->packageName());
 			return;
 		}
 		commandstring = ".rk.get.structure (" + getFullName(DefaultObjectNameOptions) + ", " + rQuote(getShortName());
@@ -288,7 +288,7 @@ void RObject::updateFromR (RCommandChain *chain) {
 		if (command->failed ()) {
 			RK_DEBUG (OBJECTS, DL_INFO, "command failed while trying to update object '%s'. No longer present?", getShortName ().toLatin1 ().data ());
 			// this may happen, if the object has been removed in the workspace in between
-			RKModificationTracker::instance()->removeObject (this, 0, true);
+			RKModificationTracker::instance()->removeObject(this, nullptr, true);
 			return;
 		}
 		if (parent && parent->isContainer()) {
@@ -307,7 +307,7 @@ void RObject::fetchMoreIfNeeded (int levels) {
 
 	if (isType (Updating)) return;
 	if (isType (Incomplete)) {
-		updateFromR (0);
+		updateFromR(nullptr);
 		return;
 	}
 	RSlotsPseudoObject *spo = slotsPseudoObject ();
@@ -316,7 +316,7 @@ void RObject::fetchMoreIfNeeded (int levels) {
 	if (levels <= 0) return;
 	if (!isContainer ()) return;
 	const RObjectMap children = static_cast<RContainerObject*> (this)->childmap;
-	foreach (RObject* child, children) {
+	for (RObject* child : children) {
 		child->fetchMoreIfNeeded (levels - 1);
 	}
 }
@@ -345,12 +345,12 @@ bool RObject::updateStructure (RData *new_data) {
 	properties_change |= updateSlots (new_data_data.at (StoragePositionSlots));
 
 	if (properties_change) RKModificationTracker::instance()->objectMetaChanged (this);
-	if (type & NeedDataUpdate) updateDataFromR (0);
+	if (type & NeedDataUpdate) updateDataFromR(nullptr);
 
 	if (type & Incomplete) {
 		// If the (new!) type is "Incomplete", it means, the structure getter simply stopped at this point.
 		// In case we already have child info, we should update it (TODO: perhaps only, if anything is listening for child objects?)
-		if (numChildrenForObjectModel () && (!isType (Updating))) updateFromR (0);
+		if (numChildrenForObjectModel () && (!isType (Updating))) updateFromR(nullptr);
 		return true;
 	}
 
@@ -437,7 +437,6 @@ bool RObject::updateType (RData *new_data) {
 	bool changed = false;
 	int new_type = new_data->intVector ().at (0);
 	if (type & PseudoObject) new_type |= PseudoObject;
-	if (type & Misplaced) new_type |= Misplaced;
 	if (type & Pending) new_type |= Pending;	// NOTE: why don't we just clear the pending flag, here? Well, we don't want to generate a change notification for this. TODO: rethink the logic, and maybe use an appropriate mask
 	if (type & NeedDataUpdate) new_type |= NeedDataUpdate;
 	if (type != new_type) {
@@ -486,7 +485,7 @@ bool RObject::updateMeta (RData *new_data) {
 	} else {		// no meta data received
 		if (meta_map) {
 			delete meta_map;
-			meta_map = 0;
+			meta_map = nullptr;
 			change = true;
 		}
 	}
@@ -537,7 +536,7 @@ bool RObject::updateSlots (RData *new_data) {
 		}
 		return ret;
 	} else if (slotsPseudoObject ()) {
-		setSpecialChildObject (0, SlotsObject);
+		setSpecialChildObject(nullptr, SlotsObject);
 	}
 	return false;
 }
@@ -561,7 +560,6 @@ int RObject::getObjectModelIndexOf (RObject *child) const {
 	}
 	if (isType (Workspace)) {
 		if (child == static_cast<const RObjectList*> (this)->orphanNamespacesObject ()) return offset;
-		offset += 1;
 	}
 	return -1;
 }
@@ -592,9 +590,8 @@ RObject *RObject::findChildByObjectModelIndex (int index) const {
 	}
 	if (isType (Workspace)) {
 		if (index == 0) return static_cast<const RObjectList *> (this)->orphanNamespacesObject ();
-		--index;
 	}
-	return 0;
+	return nullptr;
 }
 
 QList <RKEditor*> RObject::editors () const {
@@ -610,7 +607,7 @@ void RObject::rename (const QString &new_short_name) {
 void RObject::setSpecialChildObject (RObject* special, PseudoObjectType special_type) {
 	RK_TRACE (OBJECTS);
 
-	RObject *old_special = 0;
+	RObject *old_special = nullptr;
 	if (special_type == SlotsObject) old_special = slotsPseudoObject ();
 	else if (special_type == NamespaceObject) old_special = namespaceEnvironment ();
 	else if (special_type == RowNamesObject) old_special = rownames_objects.value (this);
@@ -619,7 +616,7 @@ void RObject::setSpecialChildObject (RObject* special, PseudoObjectType special_
 	if (special == old_special) return;
 
 	if (old_special) {
-		RKModificationTracker::instance()->removeObject (old_special, 0, true);
+		RKModificationTracker::instance()->removeObject(old_special, nullptr, true);
 		RK_ASSERT (!hasPseudoObject (special_type));	// should have been removed in the above statement via RObject::remove()
 	}
 
@@ -840,6 +837,7 @@ REnvironmentObject* RObject::toplevelEnvironment () const {
 RObject *RObject::globalEnvSymbol() const {
 	RK_TRACE (OBJECTS);
 	RObject *o = const_cast<RObject*>(this);	// it's ok, all we need to do is find the toplevel parent
+	if (o == RObjectList::getGlobalEnv()) return o;
 	while (o->parent) {
 		if (o->parent == RObjectList::getGlobalEnv()) return o;
 		o = o->parent;
