@@ -42,7 +42,7 @@ public:
 	void updateFromR (RCommandChain *chain, const QStringList &current_searchpath, const QStringList &current_namespaces);
 	
 	QString getFullName (int) const override { return QString (); };
-	QString makeChildName (const QString &short_child_name, bool, int) const override { return short_child_name; };
+	QString makeChildName(const QString &short_child_name, int) const override { return short_child_name; };
 	/** reimplemented from RContainerObject: do nothing. The object-list has no meta data. */
 	void writeMetaData (RCommandChain *) override {};
 
@@ -54,11 +54,11 @@ public:
 
 	/** detach the given list of packages (if the packages are loaded, and safe to remove)
 	@returns a list of error messages (usually empty) */
-	QStringList detachPackages (const QStringList &packages, RCommandChain *chain = 0, RKInlineProgressControl *control = 0);
+	QStringList detachPackages (const QStringList &packages, RCommandChain *chain = nullptr, RKInlineProgressControl *control = nullptr);
 	/** A pseudo object containing as children all loaded namespaces which do not belong to a package on the search path */
 	RKOrphanNamespacesObject* orphanNamespacesObject () const { return orphan_namespaces; };
 	QString getObjectDescription () const override;
-signals:
+Q_SIGNALS:
 /// emitted when the list of objects is about to be updated	// TODO: remove me
 	void updateStarted ();
 /// emitted when the list of objects has been updated	// TODO: remove me
@@ -71,7 +71,7 @@ protected:
 	QString removeChildCommand (RObject *object) const override;
 /// reimplemented from RContainerObject to call "remove (objectname)" instead of "objectname <- NULL"
 	QString renameChildCommand (RObject *object, const QString &new_name) const override;
-/// reimplemented from RContainerObject to emit a change signal
+/// reimplemented from RContainerObject to Q_EMIT a change signal
 	void objectsChanged ();
 	bool updateStructure (RData *new_data) override;
 	void updateEnvironments (const QStringList &env_names, bool force_globalenv_update);
