@@ -22,9 +22,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "../debug.h"
 
-// warning! numbers above GET_DATA_OFFSET are used to determine, which row, the data should go to!
-#define GET_DATA_OFFSET 10
-
 RKEditorDataFrame::RKEditorDataFrame (RContainerObject* object, QWidget *parent) : TwinTable (parent) {
 	RK_TRACE (EDITOR);
 
@@ -70,7 +67,7 @@ void RKEditorDataFrame::commonInit () {
 	getPart ()->insertChildClient (this);
 	initializeActivationSignals ();
 
-	open_chain = RInterface::startChain (0);
+	open_chain = RInterface::startChain(nullptr);
 }
 
 RKEditorDataFrame::~RKEditorDataFrame () {
@@ -81,9 +78,9 @@ RKEditorDataFrame::~RKEditorDataFrame () {
 void RKEditorDataFrame::detachModel () {
 	RK_TRACE (EDITOR);
 
-	dataview->setRKModel (0);
-	metaview->setRKModel (0);
-	deleteLater ();
+	dataview->setRKModel(nullptr);
+	metaview->setRKModel(nullptr);
+	deleteLater();
 }
 
 void RKEditorDataFrame::flushChanges () {
@@ -110,6 +107,6 @@ void RKEditorDataFrame::restoreObject (RObject *object) {
 #ifdef __GNUC__
 #	warning TODO: this interface should be moved to the model for good.
 #endif
-	datamodel->restoreObject (object, 0);
+	datamodel->restoreObject(object, nullptr);
 }
 
