@@ -1,6 +1,6 @@
 /*
 rkvareditmodel - This file is part of RKWard (https://rkward.kde.org). Created: Mon Nov 05 2007
-SPDX-FileCopyrightText: 2007-2014 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2007-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,12 +23,11 @@ SPDX-License-Identifier: GPL-2.0-or-later
 RKVarEditModel::RKVarEditModel (QObject *parent) : RKVarEditModelBase (parent), RObjectListener (RObjectListener::DataModel) {
 	RK_TRACE (EDITOR);
 
-	meta_model = 0;
+	meta_model = nullptr;
 	trailing_rows = trailing_cols = 0;
 	edit_blocks = 0;
-	rownames = 0;
+	rownames = nullptr;
 	header_locked = false;
-	duplicate_check_triggered = false;
 	reset_scheduled = false;
 
 	addNotificationType (RObjectListener::ObjectRemoved);
@@ -47,7 +46,7 @@ RKVariable* RKVarEditModel::getObject (int index) const {
 
 	if (index >= trueCols ()) {
 		RK_ASSERT (false);
-		return 0;
+		return nullptr;
 	}
 	return objects[index];
 }
@@ -66,7 +65,23 @@ void RKVarEditModel::addObject (int index, RKVariable* object) {
 	if (meta_model) meta_model->endAddDataObject ();
 	endInsertColumns ();
 
-	checkDuplicates ();
+	auto name = object->getShortName();
+	if (index >= var_col_offset) {
+		for (int i = var_col_offset; i < objects.size(); ++i) {
+			if (i == index) continue;
+			if (objects[i]->getShortName() == name) {
+				addProblem(i18n("Duplicate column name '%1'", name));
+			}
+		}
+	}
+}
+
+void RKVarEditModel::addProblem(const QString &prob) {
+	RK_TRACE(EDITOR);
+	if (problem_details.isEmpty()) {
+		Q_EMIT hasProblems();
+	}
+	problem_details.append(prob);
 }
 
 void RKVarEditModel::objectRemoved (RObject* object) {
@@ -85,36 +100,7 @@ void RKVarEditModel::objectRemoved (RObject* object) {
 	if (meta_model) meta_model->endRemoveDataObject ();
 	endRemoveColumns ();
 
-	if (objects.size () <= var_col_offset) emit modelDepleted();	// editor may or may want to auto-destruct
-}
-
-void RKVarEditModel::checkDuplicates () {
-	RK_TRACE (EDITOR);
-
-	if (duplicate_check_triggered) return;
-	duplicate_check_triggered = true;
-	QTimer::singleShot (0, this, SLOT (checkDuplicatesNow()));
-}
-
-void RKVarEditModel::checkDuplicatesNow () {
-	RK_TRACE (EDITOR);
-
-	duplicate_check_triggered = false;
-
-	QStringList dupes;
-	for (int i = var_col_offset; i < objects.size (); ++i) {
-		QString name = objects[i]->getShortName ();
-		for (int j = i+1; j < objects.size (); ++j) {
-			if (objects[j]->getShortName () == name) {
-				if (objects[i]->getFullName () == objects[j]->getFullName ()) {
-					dupes.append (objects[i]->getFullName ());
-					j = objects.size ();		// break
-				}
-			}
-		}
-	}
-
-	if (!dupes.isEmpty ()) emit hasDuplicates(dupes);
+	if (objects.size () <= var_col_offset) Q_EMIT modelDepleted();	// editor may or may want to auto-destruct
 }
 
 void RKVarEditModel::objectMetaChanged (RObject* changed) {
@@ -131,8 +117,8 @@ void RKVarEditModel::scheduleReset () {
 
 	if (!reset_scheduled) {
 		reset_scheduled = true;
-		QTimer::singleShot (0, this, SLOT (doResetNow()));
-		beginResetModel ();
+		QTimer::singleShot(0, this, &RKVarEditModel::doResetNow);
+		beginResetModel();
 	}
 }
 
@@ -156,7 +142,7 @@ void RKVarEditModel::objectDataChanged (RObject* object, const RObject::ChangeSe
 		scheduleReset ();
 		return;
 	}
-	emit dataChanged(index(changes->from_index, cindex), index(changes->to_index, cindex));
+	Q_EMIT dataChanged(index(changes->from_index, cindex), index(changes->to_index, cindex));
 }
 
 void RKVarEditModel::doInsertColumns (int, int) {
@@ -278,7 +264,10 @@ QVariant RKVarEditModel::data (const QModelIndex& index, int role) const {
 
 	// a normal cell
 	RKVariable *var = objects[col];
-	RK_ASSERT (var);
+	if (!var) {
+		RK_ASSERT(var);
+		return QVariant();
+	}
 
 	if (role == Qt::EditRole) return var->getText (row, false);
 
@@ -511,8 +500,8 @@ void RKVarEditMetaModel::endRemoveDataObject () {
 void RKVarEditMetaModel::objectMetaChanged (int atcolumn) {
 	RK_TRACE (EDITOR);
 
-	emit dataChanged(index(0, atcolumn), index(RowCount - 1, atcolumn));
-	emit headerDataChanged (Qt::Horizontal, atcolumn, atcolumn);
+	Q_EMIT dataChanged(index(0, atcolumn), index(RowCount - 1, atcolumn));
+	Q_EMIT headerDataChanged (Qt::Horizontal, atcolumn, atcolumn);
 }
 
 int RKVarEditMetaModel::rowCount (const QModelIndex& parent) const {
@@ -553,7 +542,10 @@ QVariant RKVarEditMetaModel::data (const QModelIndex& index, int role) const {
 
 	if ((role == Qt::DisplayRole) || (role == Qt::EditRole)) {
 		RKVariable *var = data_model->objects[col];
-		RK_ASSERT (var);
+		if (!var) {
+			RK_ASSERT(var);
+			return QVariant();
+		}
 
 		if (row == NameRow) return var->getShortName ();
 		if (row == LabelRow) return var->getLabel ();
@@ -826,9 +818,12 @@ void RKVarEditDataFrameModel::init (RContainerObject* dataframe) {
 
 	for (int i = 0; i < dataframe->numChildren (); ++i) {
 		RObject* obj = dataframe->findChildByIndex (i);
-		RK_ASSERT (obj);
-		RK_ASSERT (obj->isVariable ());
-		addObject (i, static_cast<RKVariable*> (obj));
+		RK_ASSERT(obj);
+		if (obj->isVariable()) {
+			addObject(i, static_cast<RKVariable*>(obj));
+		} else {
+			addProblem(i18n("Object '%1' is not a vector", obj->getShortName()));
+		}
 	}
 	rownames = dataframe->rowNames ();
 	addObject (0, rownames);
@@ -912,14 +907,14 @@ void RKVarEditDataFrameModel::objectRemoved (RObject* object) {
 	if (object == dataframe) {
 		while (!objects.isEmpty ()) RKVarEditModel::objectRemoved (objects.last());		// NOTE: The rownames object (index position 0) must always go away last!
 		stopListenForObject (dataframe);
-		dataframe = 0;
+		dataframe = nullptr;
 	}
 
 	RKVarEditModel::objectRemoved (object);
 
 	// if the dataframe is gone, the editor will most certainly want to auto-destruct.
 	// since the model will be taken down as well, this has to come last in the function.
-	if (!dataframe) emit modelObjectDestroyed();
+	if (!dataframe) Q_EMIT modelObjectDestroyed();
 }
 
 void RKVarEditDataFrameModel::childAdded (int index, RObject* parent) {
