@@ -82,11 +82,11 @@ public:
 	void objectDataChanged (RObject* object, const RObject::ChangeSet *changes) override;
 
 	RKVariable* getObject (int index) const;
-signals:
+	QStringList problems() const { return problem_details; };
+Q_SIGNALS:
 	void modelDepleted ();
-	void hasDuplicates (const QStringList& dupes);
-private slots:
-	void checkDuplicatesNow ();
+	void hasProblems();
+private Q_SLOTS:
 	void doResetNow ();
 private:
 	bool reset_scheduled;
@@ -94,7 +94,9 @@ private:
 protected:
 friend class RKVarEditMetaModel;
 	QList<RKVariable*> objects;
+	QStringList problem_details;
 	RKRowNames *rownames;
+	void addProblem(const QString &desc);
 
 	/** very simple convenience function to return the number of true cols + trailing cols */
 	int apparentCols () const { return (trueCols () + trailing_cols); };
@@ -110,10 +112,6 @@ friend class RKVarEditMetaModel;
 	virtual void doInsertRowsInBackend (int row, int count);
 	virtual void doRemoveRowsInBackend (int row, int count);
 
-	/** Check whether there are any duplicate names in the model. Actual check is delayed until the next iteration of the event loop. If a duplicate is found, hasDuplicates(const QStringList&) is emitted. */
-	void checkDuplicates ();
-	bool duplicate_check_triggered;
-
 	int trailing_rows;
 	int trailing_cols;
 
@@ -159,8 +157,8 @@ public:
 	RKVarEditModel* getDataModel () const { return data_model; };
 protected:
 friend class RKVarEditModel;
-	RKVarEditMetaModel (RKVarEditModel* data_model);
-	~RKVarEditMetaModel ();
+	explicit RKVarEditMetaModel(RKVarEditModel* data_model);
+	~RKVarEditMetaModel();
 
 	void beginAddDataObject (int index);
 	void endAddDataObject ();
@@ -186,7 +184,7 @@ public:
 	RContainerObject* getObject () const { return dataframe; };
 
 	void restoreObject (RObject* object, RCommandChain* chain) override;
-signals:
+Q_SIGNALS:
 	void modelObjectDestroyed ();
 protected:
 	void doInsertColumns (int index, int count) override;
