@@ -1,6 +1,6 @@
 /*
 twintable.cpp - This file is part of RKWard (https://rkward.kde.org). Created: Tue Oct 29 2002
-SPDX-FileCopyrightText: 2002-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2002-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +12,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <kactioncollection.h>
 #include <kxmlguifactory.h>
 #include <kmessagebox.h>
+#include <KMessageWidget>
 #include <ktoggleaction.h>
 
 #include <qvariant.h>
@@ -21,6 +22,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QVBoxLayout>
 #include <QHeaderView>
 #include <QApplication>
+#include <QActionGroup>
 
 #include "twintablemember.h"
 #include "rkvareditmodel.h"
@@ -30,13 +32,19 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "../debug.h"
 
-TwinTable::TwinTable (QWidget *parent) : RKEditor (parent), RObjectListener (RObjectListener::Other), KXMLGUIClient () {
+TwinTable::TwinTable (QWidget *parent) :
+	RKEditor(parent),
+	RObjectListener(RObjectListener::Other),
+	KXMLGUIClient(),
+	datamodel(nullptr),
+	problems_note(nullptr),
+	main_object(nullptr)
+{
 	RK_TRACE (EDITOR);
 
-	main_object = 0;
-
+	// NOTE: Must have an outer QVBoxLayout! Assumed in hasProblems()
 	QVBoxLayout *layout = new QVBoxLayout(this);
-	layout->setContentsMargins (0, 0, 0, 0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	
 	splitter = new QSplitter (this);
 	splitter->setOrientation (Qt::Vertical);
@@ -62,20 +70,20 @@ TwinTable::TwinTable (QWidget *parent) : RKEditor (parent), RObjectListener (ROb
 	// Note that the disconnects are on connections already set up by Qt. Since we don't want to worry about how these were set, we're disconnecting
 	// each in both old and new syntax.
 	disconnect (metaview->horizontalHeader (), SIGNAL (sectionClicked(int)));
-	disconnect (metaview->horizontalHeader (), &QHeaderView::sectionClicked, 0, 0);
+	disconnect (metaview->horizontalHeader (), &QHeaderView::sectionClicked, nullptr, nullptr);
 	connect (metaview->horizontalHeader (), &QHeaderView::sectionClicked, this, &TwinTable::metaHeaderClicked);
 	disconnect (metaview->horizontalHeader (), SIGNAL (sectionPressed(int)));
-	disconnect (metaview->horizontalHeader (), &QHeaderView::sectionPressed, 0, 0);
+	disconnect (metaview->horizontalHeader (), &QHeaderView::sectionPressed, nullptr, nullptr);
 	connect (metaview->horizontalHeader (), &QHeaderView::sectionPressed, this, &TwinTable::metaHeaderPressed);
 	disconnect (metaview->horizontalHeader (), SIGNAL (sectionEntered(int)));
-	disconnect (metaview->horizontalHeader (), &QHeaderView::sectionEntered, 0, 0);
+	disconnect (metaview->horizontalHeader (), &QHeaderView::sectionEntered, nullptr, nullptr);
 	connect (metaview->horizontalHeader (), &QHeaderView::sectionEntered, this, &TwinTable::metaHeaderEntered);
 	meta_header_anchor_section = -1;
 
 	// catch header context menu requests
 	connect (dataview, &TwinTableMember::contextMenuRequest, this, &TwinTable::contextMenu);
 	connect (metaview, &TwinTableMember::contextMenuRequest, this, &TwinTable::contextMenu);
-	context_menu_table = 0;
+	context_menu_table = nullptr;
 	context_menu_row = context_menu_column = -2;
 
 	setXMLFile ("rkeditordataframepart.rc");
@@ -95,48 +103,48 @@ TwinTable::~TwinTable() {
 void TwinTable::initActions () {
 	RK_TRACE (EDITOR);
 
-	editCut = actionCollection ()->addAction (KStandardAction::Cut, "cut", this, SLOT(cut()));
+	editCut = actionCollection()->addAction(KStandardAction::Cut, "cut", this, &TwinTable::cut);
 	editCut->setWhatsThis(i18n("Cuts the selected section and puts it to the clipboard"));
-	editCopy = actionCollection ()->addAction (KStandardAction::Copy, "copy", this, SLOT(copy()));
+	editCopy = actionCollection()->addAction (KStandardAction::Copy, "copy", this, &TwinTable::copy);
 	editCopy->setWhatsThis(i18n("Copies the selected section to the clipboard"));
 //	editor->editActions ()->addAction (editCopy);	// this is a read-only action, not an "edit" action
-	editPaste = actionCollection ()->addAction (KStandardAction::Paste, "paste", this, SLOT(paste()));
+	editPaste = actionCollection()->addAction(KStandardAction::Paste, "paste", this, qOverload<>(&TwinTable::paste));
 	editPaste->setWhatsThis(i18n("Pastes the clipboard contents to current position"));
 
-	editPasteToTable = actionCollection ()->addAction ("paste_to_table", this, SLOT(pasteToTable()));
-	editPasteToTable->setText (i18n("Paste inside table"));
-	editPasteToTable->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionPasteInsideTable));
+	editPasteToTable = actionCollection()->addAction("paste_to_table", this, &TwinTable::pasteToTable);
+	editPasteToTable->setText(i18n("Paste inside table"));
+	editPasteToTable->setIcon(RKStandardIcons::getIcon(RKStandardIcons::ActionPasteInsideTable));
 	editPasteToTable->setWhatsThis(i18n("Pastes the clipboard contents to current position, but not beyond the table's boundaries"));
 
-	editPasteToSelection = actionCollection ()->addAction ("paste_to_selection", this, SLOT(pasteToSelection()));
-	editPasteToSelection->setText (i18n("Paste inside selection"));
-	editPasteToSelection->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionPasteInsideSelection));
+	editPasteToSelection = actionCollection()->addAction("paste_to_selection", this, &TwinTable::pasteToSelection);
+	editPasteToSelection->setText(i18n("Paste inside selection"));
+	editPasteToSelection->setIcon(RKStandardIcons::getIcon (RKStandardIcons::ActionPasteInsideSelection));
 	editPasteToSelection->setWhatsThis(i18n("Pastes the clipboard contents to current position, but not beyond the boundaries of the current selection"));
 
 	// header menus
-	action_insert_col_left = actionCollection ()->addAction ("insert_col_left", this, SLOT (insertColumn()));
-	action_insert_col_left->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionInsertVar));
-	action_delete_col = actionCollection ()->addAction ("delete_col", this, SLOT (deleteColumn()));
-	action_delete_col->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionDeleteVar));
+	action_insert_col_left = actionCollection()->addAction("insert_col_left", this, &TwinTable::insertColumn);
+	action_insert_col_left->setIcon(RKStandardIcons::getIcon(RKStandardIcons::ActionInsertVar));
+	action_delete_col = actionCollection()->addAction("delete_col", this, &TwinTable::deleteColumn);
+	action_delete_col->setIcon(RKStandardIcons::getIcon(RKStandardIcons::ActionDeleteVar));
 
-	action_insert_row_above = actionCollection ()->addAction ("insert_row_above", this, SLOT (insertRow()));
-	action_insert_row_above->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionInsertRow));
-	action_delete_row = actionCollection ()->addAction ("delete_row", this, SLOT (deleteRow()));
-	action_delete_row->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionDeleteRow));
-	action_delete_rows = actionCollection ()->addAction ("delete_rows", this, SLOT (deleteSelectedRows()));
-	action_delete_rows->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionDeleteRow));
+	action_insert_row_above = actionCollection()->addAction("insert_row_above", this, &TwinTable::insertRow);
+	action_insert_row_above->setIcon(RKStandardIcons::getIcon(RKStandardIcons::ActionInsertRow));
+	action_delete_row = actionCollection()->addAction("delete_row", this, &TwinTable::deleteRow);
+	action_delete_row->setIcon(RKStandardIcons::getIcon (RKStandardIcons::ActionDeleteRow));
+	action_delete_rows = actionCollection()->addAction("delete_rows", this, &TwinTable::deleteSelectedRows);
+	action_delete_rows->setIcon(RKStandardIcons::getIcon(RKStandardIcons::ActionDeleteRow));
 
 	// global actions
-	action_show_rownames = actionCollection ()->addAction ("show_rownames", this, SLOT (showRownames(bool)));
-	action_show_rownames->setText (i18n("Show / Edit row names"));
-	action_show_rownames->setCheckable (true);
-	action_enable_editing = actionCollection ()->addAction ("enable_editing", this, SLOT (enableEditing(bool)));
-	action_enable_editing->setText (i18n("Enable editing"));
-	action_enable_editing->setCheckable (true);
+	action_show_rownames = actionCollection()->addAction("show_rownames", this, &TwinTable::showRownames);
+	action_show_rownames->setText(i18n("Show / Edit row names"));
+	action_show_rownames->setCheckable(true);
+	action_enable_editing = actionCollection()->addAction ("enable_editing", this, &TwinTable::enableEditing);
+	action_enable_editing->setText(i18n("Enable editing"));
+	action_enable_editing->setCheckable(true);
 	// these actually do the same thing, but are designed to work well in the toolbar
-	QActionGroup *lockactions = new QActionGroup (this);
-	lockactions->setExclusive (true);
-	action_tb_lock_editing = new KToggleAction (i18nc ("verb: switch to read-only state. Make this short.", "Lock"), this);
+	QActionGroup *lockactions = new QActionGroup(this);
+	lockactions->setExclusive(true);
+	action_tb_lock_editing = new KToggleAction(i18nc("verb: switch to read-only state. Make this short.", "Lock"), this);
 	action_tb_lock_editing->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionLock));
 	action_tb_lock_editing->setActionGroup (lockactions);
 	action_tb_lock_editing->setWhatsThis(i18n ("Disable editing (to prevent accidental modification of data)"));
@@ -167,10 +175,11 @@ void TwinTable::initActions () {
 void TwinTable::initTable (RKVarEditModel* model, RObject* object) {
 	RK_TRACE (EDITOR);
 
+	auto problems = model->problems();
 	datamodel = model;
 	main_object = object;
-	action_enable_editing->setEnabled (object->canWrite ());
-	action_tb_unlock_editing->setEnabled (object->canWrite ());
+	action_enable_editing->setEnabled(object->canWrite() && problems.isEmpty());
+	action_tb_unlock_editing->setEnabled(object->canWrite() && problems.isEmpty());
 	dataview->setRKModel (model);
 	metaview->setRKModel (model->getMetaModel ());
 	model->setEditor (this);
@@ -186,7 +195,8 @@ void TwinTable::initTable (RKVarEditModel* model, RObject* object) {
 	addNotificationType (RObjectListener::MetaChanged);
 	listenForObject (object);
 	objectMetaChanged (object);
-	connect (model, &RKVarEditModel::hasDuplicates, this, &TwinTable::containsDuplicates);
+	connect (model, &RKVarEditModel::hasProblems, this, &TwinTable::hasProblems);
+	if (!problems.isEmpty()) hasProblems();
 }
 
 void TwinTable::setWindowStyleHint (const QString& hint) {
@@ -201,12 +211,24 @@ void TwinTable::setWindowStyleHint (const QString& hint) {
 	RKMDIWindow::setWindowStyleHint (hint);
 }
 
-void TwinTable::containsDuplicates (const QStringList& dupes) {
+void TwinTable::hasProblems() {
 	RK_TRACE (EDITOR);
 
-	if (!rw) return;
-	KMessageBox::informationList (this, i18n ("The editor '%1' contains the following duplicate columns. Editing this table may not be safe, and has been disabled. You may re-enable editing if you know what you are doing, but you are strongly advised to fix the table, and/or backup your data, first.", windowTitle ()), dupes, i18n ("Duplicate columns detected"));
-	enableEditing (false);
+	if (!problems_note) {
+		const QString &msg = i18n("The object's internal structure does not conform to a regular <tt>data.frame</tt>. Editing this table may not be safe, and has been disabled. Some columns may not be shown.");
+		problems_note = new KMessageWidget(msg);
+		problems_note->setMessageType(KMessageWidget::Error);
+		static_cast<QVBoxLayout*>(layout())->insertWidget(0, problems_note);
+		auto a = new QAction(problems_note);
+		a->setText(i18n("Show details"));
+		problems_note->addAction(a);
+		connect(a, &QAction::triggered, datamodel, [this, msg]() {
+			// NOTE: Not caching the problems in the lambda, as additional problem may yet be detected
+			KMessageBox::detailedError(this, msg + "<br/>" + i18n("You may want to create an editable subset using Data->Subset data.frame."), datamodel->problems().join("\n"), i18n("Problem detected"));
+		});
+	}
+	problems_note->animatedShow();
+	enableEditing(false);
 }
 
 void TwinTable::objectMetaChanged (RObject* changed) {
@@ -249,7 +271,7 @@ void TwinTable::metaHeaderEntered (int section) {
 void TwinTable::contextMenu (int row, int col, const QPoint& pos) {
 	RK_TRACE (EDITOR);
 
-	RK_ASSERT (context_menu_table == 0);
+	RK_ASSERT (context_menu_table == nullptr);
 	context_menu_row = row;
 	context_menu_column = col;
 	QString container_name;
@@ -310,7 +332,7 @@ void TwinTable::contextMenu (int row, int col, const QPoint& pos) {
 		RK_ASSERT (false);	// but may happen, if ui.rc-file was not found
 	}
 
-	context_menu_table = 0;
+	context_menu_table = nullptr;
 	context_menu_row = context_menu_column = -2;
 }
 
@@ -441,7 +463,7 @@ TwinTableMember *TwinTable::activeTable () {
 	} else if (dataview->hasFocus ()) {
 		return dataview;
 	} else {
-		return 0;
+		return nullptr;
 	}
 }
 
@@ -474,27 +496,31 @@ void TwinTable::flushEdit () {
 void TwinTable::enableEditing (bool on) {
 	RK_TRACE (EDITOR);
 
-	flushEdit ();
-
-	rw = main_object ? on && main_object->canWrite () : on;  // NOTE: File->New->Dataset creates an Editor window, first, then sets the object to edit afterwards (TODO which looks like silly design)
+	flushEdit();
+	// NOTE: File->New->Dataset creates an Editor window, first, then sets the object to edit afterwards (TODO which looks like silly design)
+	bool prevent_edit = (main_object && !main_object->canWrite()) || (datamodel && !datamodel->problems().isEmpty());
+	rw = on && !prevent_edit;
 	metaview->rw = rw;
 	dataview->rw = rw;
 
-	QPalette palette = metaview->palette ();
-	if (on) palette.setColor (QPalette::Base, QApplication::palette ().color (QPalette::Active, QPalette::Base));
-	else palette.setColor (QPalette::Base, QApplication::palette ().color (QPalette::Disabled, QPalette::Base));
-	metaview->setPalette (palette);
-	dataview->setPalette (palette);
+	QPalette palette = metaview->palette();
+	if (rw) palette.setColor(QPalette::Base, QApplication::palette().color(QPalette::Active, QPalette::Base));
+	else palette.setColor(QPalette::Base, QApplication::palette().color(QPalette::Disabled, QPalette::Base));
+	metaview->setPalette(palette);
+	dataview->setPalette(palette);
 
 	QAbstractItemView::EditTriggers triggers = QAbstractItemView::NoEditTriggers;
 	if (rw) triggers = QAbstractItemView::DoubleClicked | QAbstractItemView::EditKeyPressed | QAbstractItemView::AnyKeyPressed;
 	metaview->setEditTriggers (triggers);
 	dataview->setEditTriggers (triggers);
 
-	edit_actions->setEnabled (rw);
-	action_enable_editing->setChecked (rw);
-	action_tb_lock_editing->setChecked (!rw);
-	action_tb_unlock_editing->setChecked (rw);
+	edit_actions->setEnabled(rw);
+	action_enable_editing->setChecked(rw);
+	action_enable_editing->setEnabled(!prevent_edit);
+	action_tb_lock_editing->setChecked(!rw);
+	action_tb_lock_editing->setEnabled(!prevent_edit);
+	action_tb_unlock_editing->setChecked(rw);
+	action_tb_unlock_editing->setEnabled(!prevent_edit);
 
 	if (main_object) objectMetaChanged (main_object);	// update_caption;
 }
