@@ -22,6 +22,7 @@ class RKVarEditModel;
 class QActionGroup;
 class QAction;
 class QSplitter;
+class KMessageWidget;
 
 /**
   *@author Thomas Friedrichsmeier
@@ -30,7 +31,7 @@ class QSplitter;
 class TwinTable : public RKEditor, public RObjectListener, public KXMLGUIClient {
 	Q_OBJECT
 public: 
-	explicit TwinTable (QWidget *parent=0);
+	explicit TwinTable(QWidget *parent=nullptr);
 	~TwinTable ();
 /** Pastes clipboard content to the current table */
 	void paste (RKEditor::PasteMode paste_mode);
@@ -46,7 +47,7 @@ public:
 
 	QActionGroup* editActions () const { return edit_actions; };
 	void setWindowStyleHint (const QString& hint) override;
-public slots:
+public Q_SLOTS:
 	void metaHeaderPressed (int section);
 	void metaHeaderEntered (int section);
 	void metaHeaderClicked (int section);
@@ -64,8 +65,8 @@ public slots:
 	void pasteToTable();
 /** paste the clipboard into the table, but not beyond selection boundaries	*/
 	void pasteToSelection();
-/** connected to RKVarEditModel::hasDuplicates() */
-	void containsDuplicates (const QStringList& dupes);
+/** connected to RKVarEditModel::hasProblems() */
+	void hasProblems();
 private:
 	int meta_header_anchor_section;
 /** read-write */
@@ -83,6 +84,7 @@ protected:
 /** Returns the active Table (of the two members), 0 if no table active */
 	TwinTableMember *activeTable ();
 
+	KMessageWidget* problems_note;
 	TwinTableMember* metaview;
 	TwinTableMember* dataview;
 
@@ -109,7 +111,7 @@ protected:
 	void initActions ();
 
 	RObject* main_object;
-private slots:
+private Q_SLOTS:
 /** inserts a new column (NOTE the action connected to this signal carries the info, where the column is to be inserted) */
 	void insertColumn ();
 /** inserts a new row in the dataview (NOTE the action connected to this signal carries the info, where the column is to be inserted) */
