@@ -36,10 +36,9 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 class RKBugzillaReportDialog : public QDialog {
 public:
-	RKBugzillaReportDialog (QWidget* parent, const QString& report_template) : QDialog (parent) {
+	RKBugzillaReportDialog(QWidget* parent, const QString& report_template) : QDialog(parent), report_template(report_template) {
 		RK_TRACE (DIALOGS);
 
-		RKBugzillaReportDialog::report_template = report_template;
 		setWindowTitle (i18n ("Reporting bugs in RKWard"));
 		QVBoxLayout *layout = new QVBoxLayout (this);
 		QLabel *label = RKCommonFunctions::wordWrappedLabel (i18n ("<p><b>Where should I report bugs or wishes?</b></p><p>Thank you for taking the time to help improve RKWard. To help us "
@@ -109,7 +108,7 @@ void RKErrorDialog::reportableErrorMessage (QWidget* parent_widget, const QStrin
 	KMessageBox::Options options = KMessageBox::Notify | KMessageBox::AllowLink;
 	dialog->setModal (true);
 
-	int ret = KMessageBox::createKMessageBox (dialog, buttonbox, QMessageBox::Critical, user_message, QStringList(), QString(), 0, options, details);
+	int ret = KMessageBox::createKMessageBox(dialog, buttonbox, QMessageBox::Critical, user_message, QStringList(), QString(), nullptr, options, details);
 
 	if (ret == QDialogButtonBox::No) {
 		reportBug (parent_widget, (message_code.isEmpty () ? QString () : i18n ("Message code: %1\n", message_code)) + user_message);
