@@ -8,15 +8,17 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #ifndef RKIMPORTDIALOG_H
 #define RKIMPORTDIALOG_H
 
-#include <qstringlist.h>
-#include <QFileDialog>
+#include <QStringList>
+#include <KAssistantDialog>
 
-class QComboBox;
 class RKComponentGUIXML;
+class KPageWidgetitem;
+class QButtonGroup;
+class RKComponentHandle;
 
 /** This dialog is designed to allow the user to select a file, and file format. After that a suitable plugin
 is opened automatically to deal with this type of file . */
-class RKImportDialog : public QFileDialog {
+class RKImportDialog : public KAssistantDialog {
 	Q_OBJECT
 public:
 /** constructor
@@ -25,16 +27,22 @@ public:
 	RKImportDialog (const QString &context_id, QWidget *parent);
 /** dtor */
 	~RKImportDialog ();
-protected:
-/** reimplemented to a) invoke the relevant plugin, b) trigger self-destruction of the dialog */
-	void accept () override;
-/** reimplemented to trigger self-destruction of the dialog */
-	void reject () override;
+	void accept() override;
 private:
-	int format_count;
+	void updateState();
+
 	QStringList filters;
 	QStringList component_ids;
+	RKComponentHandle *rio_handle;
 	RKComponentGUIXML *context;
+	KPageWidgetItem *select_format;
+	QButtonGroup *select_format_group;
+	KPageWidgetItem *select_rio;
+	QButtonGroup *select_rio_group;
+	KPageWidgetItem *select_clipboard;
+	QButtonGroup *select_clipboard_group;
+	KPageWidgetItem *end_with_selection;
+	KPageWidgetItem *end_without_selection;
 };
 
 #endif
