@@ -7,9 +7,11 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "rkreadlinedialog.h"
 
-#include <qlineedit.h>
+#include <QApplication>
+#include <QScreen>
+#include <QLineEdit>
 #include <QTextEdit>
-#include <qlabel.h>
+#include <QLabel>
 #include <QScrollBar>
 #include <QTimer>
 #include <QVBoxLayout>
@@ -20,7 +22,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../rbackend/rcommand.h"
 #include "../misc/rkdialogbuttonbox.h"
 #include "../misc/rkcommonfunctions.h"
-#include "../misc/rkcompatibility.h"
 
 #include "../debug.h"
 
@@ -36,7 +37,7 @@ RKReadLineDialog::RKReadLineDialog (QWidget *parent, const QString &caption, con
 
 	layout->addWidget (new QLabel (caption, this));
 
-	int screen_width = RKCompatibility::availableGeometry(this).width();
+	int screen_width = screen() ? screen()->availableGeometry().width() : QApplication::primaryScreen()->availableGeometry().width();
 
 	QString context = command->fullOutput ();
 	if (!context.isEmpty ()) {
@@ -81,7 +82,7 @@ bool RKReadLineDialog::readLine (QWidget *parent, const QString &caption, const
 
 	RKReadLineDialog *dialog = new RKReadLineDialog (parent, caption, prompt, command);
 	if (!stored_geom.isNull ()) dialog->restoreGeometry (stored_geom);
-	QTimer::singleShot (0, dialog->input, SLOT(setFocus()));
+	QTimer::singleShot(0, dialog, [dialog](){ dialog->input->setFocus(); });
 	int res = dialog->exec ();
 	*result = dialog->input->text ();
 	stored_geom = dialog->saveGeometry ();
