@@ -18,14 +18,19 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QTimer>
 #include <QFileInfo>
 #include <QStandardPaths>
+#include <QRadioButton>
+#include <QGroupBox>
+#include <QButtonGroup>
 
 #include <KLocalizedString>
+#include <KUrlRequester>
 #include <KMessageBox>
 
 #include "../settings/rksettingsmoduleplugins.h"
 #include "../settings/rksettingsmodulegeneral.h"
 #include "../settings/rksettings.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkcommandlineargs.h"
 #include "../misc/rkstandardicons.h"
 #include "../dialogs/rkloadlibsdialog.h"
 #include "../windows/katepluginintegration.h"
@@ -36,17 +41,201 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "../debug.h"
 
+class RKSetupWizardPage : public QWidget {
+public:
+	RKSetupWizardPage(RKSetupWizard* wizard, const QString& caption) : QWidget(), wizard(wizard), current_row(-1), glayout(nullptr) {
+		RK_TRACE (DIALOGS);
+		ref = wizard->addPage(this, caption);
+	};
+
+	void lazyInitOnce(std::function<void(RKSetupWizardPage*)> initfun) {
+		auto refcopy = ref;
+		QObject::connect(wizard, &KPageDialog::currentPageChanged, this, [this, refcopy, initfun](KPageWidgetItem* current, KPageWidgetItem*) mutable {
+			if (current && current == refcopy) {
+				initfun(this);
+				refcopy = nullptr;
+			}
+		});
+	}
+	void lazyInitRepeated(std::function<void(RKSetupWizardPage*)> initfun) {
+		QObject::connect(wizard, &KPageDialog::currentPageChanged, this, [this, initfun](KPageWidgetItem* current, KPageWidgetItem*) {
+			if (current && current == ref) {
+				initfun(this);
+			}
+		});
+	}
+
+	RKSetupWizard *wizard;
+	int current_row;
+	QGridLayout *glayout;
+	KPageWidgetItem *ref;
+	void appendItem(RKSetupWizardItem* item) {
+		RK_TRACE (DIALOGS);
+
+		if (!glayout) {
+			RK_ASSERT(!layout());  // must now mix with different type of layout
+			glayout = new QGridLayout(this);
+			glayout->setColumnStretch(1, 2);
+			glayout->setColumnStretch(2, 1);
+		}
+
+		item->createWidget(glayout, ++current_row);
+		wizard->items.append(item);
+	};
+	void addStretch() {
+		RK_ASSERT(glayout); // Offered for grid-layout pages, only, for now
+		glayout->setRowStretch(++current_row, 1);
+	}
+};
+
 bool RKSetupWizard::has_been_run = false;
+bool RKSetupWizard::wizard_active = false;
+
+static auto iconForStatus(RKSetupWizardItem::Status status) {
+	QString icon_id;
+	if (status == RKSetupWizardItem::Good) icon_id = QLatin1String("dialog-positive");
+	else if (status == RKSetupWizardItem::Warning) icon_id = QLatin1String("dialog-warning");
+	else icon_id = QLatin1String("dialog-error");
+	return (QIcon::fromTheme(icon_id).pixmap(32, 32));  // TODO: Correct way to not hardcode size?
+}
+
+class RBackendStatusWidget : public QWidget {
+public:
+	RBackendStatusWidget(QWidget *parent) : QWidget(parent), anim(nullptr) {
+		auto l = new QVBoxLayout(this);
+		rinst_label = new QLabel();
+		l->addWidget(rinst_label);
+		auto h = new QHBoxLayout();
+		l->addLayout(h);
+		rstatus_label = RKCommonFunctions::wordWrappedLabel(QString());
+		rstatus_icon = new QLabel();
+		h->addWidget(rstatus_icon);
+		h->addWidget(rstatus_label);
+		h->setStretch(1, 2);
+		detail_button = new QPushButton(i18n("Show problem details"));
+		connect(detail_button, &QPushButton::clicked, this, [this]() {
+			if (!backend_error.details.isEmpty()) {
+				// WORKAROUND for silly KMessageBox behavior. (still needed in KF6 6.3.0)
+				// If length of details <= 512, it tries to show the details as a QLabel.
+				backend_error.details = backend_error.details.leftJustified(513);
+			}
+			KMessageBox::detailedError(nullptr, backend_error.message, backend_error.details, backend_error.title, KMessageBox::Notify | KMessageBox::AllowLink);
+		});
+		h->addWidget(detail_button);
+		update();
+	}
+	void update() {
+		if (RKSessionVars::RBinary().isEmpty()) {
+			rinst_label->setText(i18n("RKWard <b>failed to detect an R installation</b> on this system"));
+		} else {
+			rinst_label->setText(i18n("RKWard is currently using the R installation at <nobr>%1</nobr>.", RKSessionVars::RBinary()));
+		}
+		detail_button->hide();
+		if (RInterface::instance()->backendIsDead()) {
+			rstatus_icon->setPixmap(iconForStatus(RKSetupWizardItem::Error));
+			backend_error = RInterface::instance()->backendError();
+			detail_button->show();
+			if (RInterface::instance()->backendFailedToStart()) {
+				rstatus_label->setText(i18n("<b>R backend has failed to start.</b>"));
+			} else {
+				rstatus_label->setText(i18n("<b>R backend has crashed.</b>"));
+			}
+			if (anim) {
+				delete anim;
+				anim = nullptr;
+			}
+		} else if (RInterface::instance()->backendIsIdle()) {
+			QString statustext = i18n("<b>R version %1 started, successfully.</b>", RKSessionVars::RVersion(false));
+			if (RKSessionVars::isPathInAppImage(RKSessionVars::RBinary())) {
+				rstatus_icon->setPixmap(iconForStatus(RKSetupWizardItem::Warning));
+				statustext.append(i18n("<p>You are using the R version bundled inside the RKWard AppImage.</p>"
+				                       "<p>This version comes with several technical limitations. Importantly, "
+				                       "you will not be able to install most R addon packages. "
+				                       "In general, it is therefore recommended to select a system-installed "
+				                       "version of R, instead, below.</p>"));
+			} else {
+				rstatus_icon->setPixmap(iconForStatus(RKSetupWizardItem::Good));
+			}
+			rstatus_label->setText(statustext);
+			if (anim) {
+				delete anim;
+				anim = nullptr;
+			}
+		} else {
+			rstatus_label->setText(i18n("<b>Waiting for R backend...</b>"));
+			if (!anim) anim = RKStandardIcons::busyAnimation(this, [this](const QIcon& icon) {
+				rstatus_icon->setPixmap(icon.pixmap(32, 32));
+			});
+		}
+	}
+private:
+	QLabel *rstatus_label, *rstatus_icon, *rinst_label;
+	QPushButton *detail_button;
+	QTimer *anim;
+	RInterface::BackendError backend_error;
+};
+
+class RBackendSelectionWidget : public QGroupBox {
+public:
+	RBackendSelectionWidget(QWidget *parent) : QGroupBox(parent) {
+		group = new QButtonGroup(this);
+		auto l = new QVBoxLayout(this);
+		bl = new QVBoxLayout();
+		l->addLayout(bl);
+
+		auto button = new QRadioButton(i18n("Use R at:")); l->addWidget(button); group->addButton(button, -1);
+		req = new KUrlRequester(); l->addWidget(req);
+		req->setPlaceholderText(i18n("Select another R executable"));
+		req->setEnabled(false);
+		req->setWindowTitle(i18n("Select R executable"));
+		connect(button, &QAbstractButton::toggled, req, &QWidget::setEnabled);
+	}
+
+	void updateOptions() {
+		// clear previous buttons, if any
+		for (int i = 0; i < r_installations.size(); ++i) {
+			delete (group->button(i));
+		}
+
+		r_installations = RKSessionVars::findRInstallations();
+		if (!RKSessionVars::RBinary().isEmpty()) {
+			r_installations.removeAll(RKSessionVars::RBinary());
+			r_installations.prepend(RKSessionVars::RBinary());
+		}
+		for(int i = 0; i < r_installations.size(); ++i) {
+			addButton(i18n("Use R at %1", r_installations[i]), i);
+		}
+		auto button = group->button(0);
+		if (RInterface::instance()->backendIsDead()) button->setText(i18n("Attempt to restart R at %1", RKSessionVars::RBinary()));
+		else button->setText(i18n("Keep current version (%1)", RKSessionVars::RBinary()));
+		if (RKSessionVars::isPathInAppImage(RKSessionVars::RBinary()) && (r_installations.size() > 1)) {
+			group->button(1)->setChecked(true);
+		} else {
+			button->setChecked(true);
+		}
+	}
+	QRadioButton *addButton(const QString &text, int index) {
+		auto button = new QRadioButton(text);
+		bl->addWidget(button);
+		group->addButton(button, index);
+		return button;
+	}
+	QString selectedOpt() {
+		int index = group->checkedId();
+		if (index >= 0) return r_installations[index];
+		return req->text();
+	}
+	QButtonGroup *group;
+private:
+	QVBoxLayout *bl;
+	QStringList r_installations;
+	KUrlRequester *req;
+};
 
 void RKSetupWizardItem::createWidget(QGridLayout *layout, int row) {
-	QString icon_id;
-	if (status == Good) icon_id = QLatin1String("dialog-positive");
-	else if (status == Warning) icon_id = QLatin1String("dialog-warning");
-	else icon_id = QLatin1String("dialog-error");
 	auto label = new QLabel();
-	label->setPixmap(QIcon::fromTheme(icon_id).pixmap(32, 32));  // TODO: Correct way to not hardcode size?
+	label->setPixmap(iconForStatus(status));
 	layout->addWidget(label, row, 0);
-
 	layout->addWidget(new QLabel(shortlabel + ": " + shortstatuslabel), row, 1);
 
 	if (options.isEmpty()) {
@@ -114,29 +303,33 @@ RKSetupWizardItem* makeSoftwareCheck(const QString &exename, const QString& expl
 	return ret;
 }
 
-RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QList<RKSetupWizardItem*> &settings_items) : KAssistantDialog(parent) {
+RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QList<RKSetupWizardItem*> &settings_items) : KAssistantDialog(parent), reason(reason) {
 	RK_TRACE (DIALOGS);
+	RK_ASSERT(!wizard_active);
+	wizard_active = true;
 
 	// Cover page
-	auto firstpage = new QWidget();
-	auto l = new QVBoxLayout(firstpage);
-	QString intro = i18n("<p>This dialog will guide you through a quick check of the basic setup of the required (or recommended) components.</p>");
+	auto page = new RKSetupWizardPage(this, i18n("RKWard Setup Assistant"));
+	auto l = new QVBoxLayout(page);
+	l->addWidget(RKCommonFunctions::wordWrappedLabel(i18n("<p>This dialog will guide you through a quick check of the basic setup of the required (or recommended) components.</p>")));
 	if (reason == NewVersionRKWard) {
-		intro += i18n("<p>The setup assistant has been invoked, automatically, because a new version of RKWard has been detected.</p>");
+		l->addWidget(RKCommonFunctions::wordWrappedLabel(i18n("<p>The setup assistant has been invoked, automatically, because a new version of RKWard has been detected.</p>")));
 	} else if (reason == NewVersionR) {
 		// TODO: invoke this!
-		intro += i18n("<p>The setup assistant has been invoked, automatically, because a new version of R has been detected.</p>");
+		l->addWidget(RKCommonFunctions::wordWrappedLabel(i18n("<p>The setup assistant has been invoked, automatically, because a new version of R has been detected.</p>")));
 	} else if (reason == ProblemsDetected) {
-		intro += i18n("<p>The setup assistant has been invoked, automatically, because a problem has been detected in your setup.</p>");
+		auto hl = new QHBoxLayout();
+		l->addLayout(hl);
+		auto lab = new QLabel();
+		lab->setPixmap(iconForStatus(RKSetupWizardItem::Error));
+		hl->addWidget(lab);
+		hl->addWidget(RKCommonFunctions::wordWrappedLabel("<p>The setup assistant has been invoked, automatically, because a problem has been detected in your setup.</p>"));
+		hl->setStretch(1,2);
 	}
-	l->addWidget(RKCommonFunctions::wordWrappedLabel(intro));
-	waiting_to_start_label = RKCommonFunctions::wordWrappedLabel(i18n("<b>Waiting for R backend...</b>") + "<p>&nbsp;</p><p>&nbsp;</p>");
-	l->addWidget(waiting_to_start_label);
-	firstpageref = addPage (firstpage, i18n("RKWard Setup Assistant"));
-	setValid(firstpageref, false);
+	l->addStretch();
 
 	// Basic installation page
-	createStandardPage();
+	page = new RKSetupWizardPage(this, i18n("Basic installation"));
 	reinstallation_required = false;
 	auto idir = new RKSetupWizardItem(i18n("Installation directory"));
 	if (RKCommonFunctions::getRKWardDataDir ().isEmpty ()) {
@@ -147,7 +340,7 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	} else {
 		idir->setStatus(RKSetupWizardItem::Good, i18n("Found."));
 	}
-	appendItem(idir);
+	page->appendItem(idir);
 
 	auto pluginmaps = new RKSetupWizardItem(i18n("RKWard plugins"));
 	if (RKSettingsModulePlugins::pluginMaps().isEmpty()) {
@@ -160,7 +353,7 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	} else {
 		pluginmaps->setStatus(RKSetupWizardItem::Good, i18n("Found."));
 	}
-	appendItem(pluginmaps);
+	page->appendItem(pluginmaps);
 
 	auto kateplugins = new RKSetupWizardItem(i18n("Kate plugins"));
 	int kateplugincount = RKWardMainWindow::getMain()->katePluginIntegration()->knownPluginCount();
@@ -171,7 +364,7 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	} else {
 		kateplugins->setStatus(RKSetupWizardItem::Good, i18np("Found %1 plugin.", "Found %1 plugins.", kateplugincount));
 	}
-	appendItem(kateplugins);
+	page->appendItem(kateplugins);
 
 	// TODO: Remove, eventually
 	auto legacy_output = new RKSetupWizardItem(i18n("Pre 0.7.3 output file"));
@@ -184,73 +377,86 @@ RKSetupWizard::RKSetupWizard(QWidget* parent, InvokationReason reason, const QLi
 	} else {
 		legacy_output->setStatus(RKSetupWizardItem::Good, i18n("Found."));
 	}
-	appendItem(legacy_output);
+	page->appendItem(legacy_output);
 
 	for (int i = 0; i < settings_items.size(); ++i) {
-		appendItem(settings_items[i]);
+		page->appendItem(settings_items[i]);
 	}
+	page->addStretch();
 
-	current_layout->setRowStretch(++current_row, 1);
-	addPage(current_page, i18n("Basic installation"));
+	// The following pages need the R backend, and are thus initialized lazily
+	// R backend page
+	page = new RKSetupWizardPage(this, i18n("R Backend"));
+	page->lazyInitOnce([this](RKSetupWizardPage *p) {
+		auto l = new QVBoxLayout(p);
+		auto status = new RBackendStatusWidget(p);
+		auto select = new RBackendSelectionWidget(p);
+		l->addWidget(status);
+		l->addWidget(select);
+		l->addStretch();
+		auto pageref = p->ref;
+		setValid(pageref, false);
 
-	// Next we'll want to wait for the R backend to start up. Previous solution was to set Qt::ApplicationModal, and wait, calling processEvents().
-	// This does not seem to work well on mac, however, so instead we return, here, so exec will be called from outside, then fire a timer to finish constuction.
-	QTimer::singleShot(10, this, &RKSetupWizard::setupWizardPhase2);
-}
+		auto statuslambda = [this, pageref, status, select]() {
+			status->update();
+			if (!(RInterface::instance()->backendIsDead() || RInterface::instance()->backendIsIdle())) {
+				select->hide();
+				setValid(pageref, false);
+				return;
+			}
+			select->updateOptions();
+			select->show();
+			setValid(pageref, true);
 
-void RKSetupWizard::setupWizardPhase2() {
-	// Wait for R Interface, then enable dialog
-	if (!RInterface::instance()->backendIsIdle()) {
-		if (RInterface::instance()->backendIsDead()) {
-			waiting_to_start_label->setText(i18n("<b>R backend has crashed. Click \"Cancel\" to exit setup assistant.</b>"));
-		} else {
-			QTimer::singleShot(100, this, &RKSetupWizard::setupWizardPhase2);
-		}
-		return;
-	}
-	RK_TRACE(APP);
-
-	waiting_to_start_label->setText(i18n("<b>R backend has started. Click \"Next\" to continue.</b>"));
-	setValid(firstpageref, true);
+			next_callbacks.insert(pageref, [select, pageref, this]() -> bool {
+				bool restart_needed = (select->group->checkedId() != 0) || RInterface::instance()->backendIsDead();
+				if (restart_needed) {
+					RKSessionVars::r_binary = select->selectedOpt();
+					RKCommandLineArgs::instance->set(RKCommandLineArgs::Setup, QVariant(true));
+					if (RKWardMainWindow::getMain()->triggerBackendRestart(this->reason == ManualCheck)) {
+						select->hide();
+						setValid(pageref, false);
+					}
+				}
+				return !restart_needed;
+			});
+		};
+		connect(RInterface::instance(), &RInterface::backendStatusChanged, this, statuslambda);
+		// when restarting the backend, the RInterface::instance() itself is exchanged
+		connect(RKWardMainWindow::getMain(), &RKWardMainWindow::backendCreated, this, [this, statuslambda]() {
+			connect(RInterface::instance(), &RInterface::backendStatusChanged, this, statuslambda);
+			statuslambda();
+		});
+		statuslambda();
+	});
 
 	// R packages page
-	// This must be created _after_ the backend has started, for obvious reasons.
-	createStandardPage();
-
-	appendItem(makeRPackageCheck("R2HTML", i18n("The R2HTML package is used by nearly all RKWard output functions, and thus required."), RKSetupWizardItem::Error));
-	appendItem(makeRPackageCheck("rmarkdown", i18n("The rmarkdown package is required for rendering .Rmd files (including preview rendering), which is an optional but recommended feature."), RKSetupWizardItem::Warning));
-
-	current_layout->setRowStretch(++current_row, 1);
-	addPage(current_page, i18n("R Packages"));
+	page = new RKSetupWizardPage(this, i18n("R Packages"));
+	page->lazyInitOnce([](RKSetupWizardPage *p) {
+		p->appendItem(makeRPackageCheck("R2HTML", i18n("The R2HTML package is used by nearly all RKWard output functions, and thus required."), RKSetupWizardItem::Error));
+		p->appendItem(makeRPackageCheck("rmarkdown", i18n("The rmarkdown package is required for rendering .Rmd files (including preview rendering), which is an optional but recommended feature."), RKSetupWizardItem::Warning));
+		p->addStretch();
+	});
 
 	// external software page
-	createStandardPage();
-
-	appendItem(makeSoftwareCheck("pandoc", i18n("The pandoc software is needed for rendering (or previewing) R markdown (.Rmd) files. This is optional but recommended."), "https://pandoc.org/installing.html", RKSetupWizardItem::Warning));
-	appendItem(makeSoftwareCheck("kbibtex", i18n("The kbibtex software is useful for managing citations while writing articles. It integrates into RKWard via the Document Preview kate plugin."), "https://userbase.kde.org/KBibTeX", RKSetupWizardItem::Warning));
-
-	current_layout->setRowStretch(++current_row, 1);
-	second_to_last_page_ref = addPage(current_page, i18n("External software"));
+	page = new RKSetupWizardPage(this, i18n("External software"));
+	page->lazyInitOnce([](RKSetupWizardPage *p) {
+		p->appendItem(makeSoftwareCheck("pandoc", i18n("The pandoc software is needed for rendering (or previewing) R markdown (.Rmd) files. This is optional but recommended."), "https://pandoc.org/installing.html", RKSetupWizardItem::Warning));
+		p->appendItem(makeSoftwareCheck("kbibtex", i18n("The kbibtex software is useful for managing citations while writing articles. It integrates into RKWard via the Document Preview kate plugin."), "https://userbase.kde.org/KBibTeX", RKSetupWizardItem::Warning));
+		p->addStretch();
+	});
 
 	// summary page
-	createStandardPage();
-	last_page_label = RKCommonFunctions::linkedWrappedLabel("");
-	current_layout->addWidget(last_page_label, 0, 0, 0, 3);
-	current_layout->setRowStretch(1, 1);
-	addPage(current_page, i18n("Summary of the next steps"));
-}
+	page = new RKSetupWizardPage(this, i18n("Summary of the next steps"));
+	l = new QVBoxLayout(page);
+	auto last_page_label = RKCommonFunctions::linkedWrappedLabel("");
+	l->addWidget(last_page_label);
+	l->addStretch();
+	page->lazyInitRepeated([this, last_page_label](RKSetupWizardPage *page) {
+		software_to_install.clear();
+		packages_to_install.clear();
+		r_commands_to_run.clear();;
 
-RKSetupWizard::~RKSetupWizard() {
-	RK_TRACE (DIALOGS);
-	for(int i = 0; i < items.size(); ++i) {
-		delete items[i];
-	}
-}
-
-void RKSetupWizard::next() {
-	RK_TRACE (DIALOGS);
-
-	if (currentPage() == second_to_last_page_ref) {
 		// NOTE: This is not quite clean: Some settings get applied before clicking finish, this way.
 		//       However, I don't really want to pop up a separate dialog for a summary page, either.
 		for(int i = 0; i < items.size(); ++i) {
@@ -281,12 +487,25 @@ void RKSetupWizard::next() {
 		} else {
 			label_text.append(i18n("No R packages to install"));
 		}
-
-		// TODO: This height calculation is not quite correct, somehow, but good enough for now.
-		int spare_height = height() - last_page_label->parentWidget()->sizeHint().height();
 		last_page_label->setText(label_text);
-		int new_height = qMax(height(), spare_height+last_page_label->minimumSizeHint().height());
-		resize(width(), new_height);
+		// Somehow we need to help the geometry along, or height will not take line-wraps into account
+		last_page_label->setMinimumHeight(last_page_label->heightForWidth(page->width()));
+	});
+}
+
+RKSetupWizard::~RKSetupWizard() {
+	RK_TRACE (DIALOGS);
+	for(int i = 0; i < items.size(); ++i) {
+		delete items[i];
+	}
+	wizard_active = false;
+}
+
+void RKSetupWizard::next() {
+	RK_TRACE (DIALOGS);
+
+	if (next_callbacks.contains(currentPage())) {
+		if (!next_callbacks[currentPage()]()) return;
 	}
 	KAssistantDialog::next();
 }
@@ -297,7 +516,7 @@ void RKSetupWizard::doAutoCheck() {
 	// query settings modules for any problems
 	QList<RKSetupWizardItem*> settings_items = RKSettings::validateSettingsInteractive();
 	// check for those, and some cheap-but-important basics
-	if (RKCommonFunctions::getRKWardDataDir ().isEmpty () || RKSettingsModulePlugins::pluginMaps().isEmpty() || (RKWardMainWindow::getMain()->katePluginIntegration()->knownPluginCount() == 0) || !settings_items.isEmpty()) {
+	if (RInterface::instance()->backendIsDead() || RKCommonFunctions::getRKWardDataDir().isEmpty () || RKSettingsModulePlugins::pluginMaps().isEmpty() || (RKWardMainWindow::getMain()->katePluginIntegration()->knownPluginCount() == 0) || !settings_items.isEmpty()) {
 		fullInteractiveCheck(ProblemsDetected, settings_items);
 	} else if (RKSettingsModuleGeneral::rkwardVersionChanged()) {
 		fullInteractiveCheck(NewVersionRKWard, settings_items);
@@ -312,15 +531,17 @@ void RKSetupWizard::manualCheck() {
 void RKSetupWizard::fullInteractiveCheck(InvokationReason reason, const QList<RKSetupWizardItem*> &settings_items) {
 	RK_TRACE (DIALOGS);
 
+	if (wizard_active) return; // This can actually happen: In particular, if backend fails to start
 	if (has_been_run && reason != ManualCheck) return;
 	has_been_run = true;
 
+	QString old_r_binary = RKSessionVars::RBinary();
 	auto wizard = new RKSetupWizard(RKWardMainWindow::getMain(), reason, settings_items);
-
 	auto res = wizard->exec();
+
 	if (res == QDialog::Accepted) {
 		if (!wizard->packages_to_install.isEmpty()) {
-			RKLoadLibsDialog::showInstallPackagesModal(wizard, 0, wizard->packages_to_install);
+			RKLoadLibsDialog::showInstallPackagesModal(wizard, nullptr, wizard->packages_to_install);
 		}
 
 #if 0 && (defined(Q_OS_LINUX) || defined(Q_OS_UNIX))  // D'uh: muon (5.8.0) does not have an "install" command line option or equivalent
@@ -334,26 +555,21 @@ void RKSetupWizard::fullInteractiveCheck(InvokationReason reason, const QList<RK
 		for(int i = 0; i < wizard->r_commands_to_run.size(); ++i) {
 			RInterface::issueCommand(wizard->r_commands_to_run[i], RCommand::App);
 		}
+
+		// save backend selection (if one was made)
+		if (!RInterface::instance()->backendIsDead() && (RKSessionVars::RBinary() != old_r_binary)) {
+			if (RKSessionVars::isPathInAppImage(RKSessionVars::RBinary())) {
+				// the appimage path isn't stable, but an empty setting causes it to be used by default (via rkward.ini)
+				RKSettingsModuleR::options_r_binary = QString();;
+			} else {
+				RKSettingsModuleR::options_r_binary = RKSessionVars::RBinary();
+			}
+		}
 	}
 
 	delete wizard;
 }
 
-void RKSetupWizard::createStandardPage() {
-	RK_TRACE (DIALOGS);
-	current_page = new QWidget();
-	current_layout = new QGridLayout(current_page);
-	current_layout->setColumnStretch(1, 2);
-	current_layout->setColumnStretch(2, 1);
-	current_row = -1;
-}
-
-void RKSetupWizard::appendItem(RKSetupWizardItem* item) {
-	RK_TRACE (DIALOGS);
-	item->createWidget(current_layout, ++current_row);
-	items.append(item);
-}
-
 void RKSetupWizard::markSoftwareForInstallation(const QString& name, const QString& downloadurl, bool install) {
 	RK_TRACE (DIALOGS);
 	bool present = software_to_install.contains(name);
