@@ -1,6 +1,6 @@
 /*
-rksetupwizard - This file is part of the RKWard project. Created: Fri May 25 20200
-SPDX-FileCopyrightText: 2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+rksetupwizard - This file is part of the RKWard project. Created: Fri May 25 2020
+SPDX-FileCopyrightText: 2020-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,6 +14,8 @@ SPDX-License-Identifier: GPL-2.0-or-later
 class QGridLayout;
 class QLabel;
 class RKSetupWizardItem;
+class RKSetupWizardPage;
+
 class RKSetupWizard : public KAssistantDialog {
 protected:
 	enum InvokationReason {
@@ -34,26 +36,18 @@ public:
 
 	void markSoftwareForInstallation(const QString &name, const QString &download_url, bool install);
 	void markRPackageForInstallation(const QString &name, bool install);
+	void next() override;
 private:
-	void setupWizardPhase2();
-	KPageWidgetItem* firstpageref;
-	QLabel* waiting_to_start_label;
-
 	QStringList software_to_install;
 	QStringList software_to_install_urls;
 	QStringList packages_to_install;
 	QStringList r_commands_to_run;
-	void createStandardPage();
-	QWidget *current_page;
-	int current_row;
-	QGridLayout* current_layout;
-	void appendItem(RKSetupWizardItem* item);
+friend class RKSetupWizardPage;
+	QMap<KPageWidgetItem*, std::function<bool()>> next_callbacks;
 	QList<RKSetupWizardItem*> items;
 	bool reinstallation_required;
-
-	void next() override;
-	KPageWidgetItem *second_to_last_page_ref;
-	QLabel* last_page_label;
+	InvokationReason reason;
+	static bool wizard_active;
 };
 
 class QComboBox;
@@ -64,7 +58,7 @@ public:
 		Warning,
 		Good
 	};
-	RKSetupWizardItem(const QString &shortlabel, const QString &longlabel=QString(), Status status=Good, const QString &shortstatuslabel=QString()) : status(status), shortlabel(shortlabel), longlabel(longlabel), shortstatuslabel(shortstatuslabel), box(nullptr) {};
+	explicit RKSetupWizardItem(const QString &shortlabel, const QString &longlabel=QString(), Status status=Good, const QString &shortstatuslabel=QString()) : status(status), shortlabel(shortlabel), longlabel(longlabel), shortstatuslabel(shortstatuslabel), box(nullptr) {};
 	~RKSetupWizardItem() {};
 	void addOption(const QString &shortlabel, const QString &longlabel, std::function<void(RKSetupWizard*)> callback) {
 		options.append(Option(shortlabel, longlabel, callback));
@@ -73,6 +67,7 @@ public:
 	void setShortLabel(const QString &label) { shortlabel = label; };
 	void setLongLabel(const QString &label) { longlabel = label; };
 private:
+friend class RKSetupWizardPage;
 friend class RKSetupWizard;
 	void createWidget(QGridLayout *layout, int row);
 	void apply(RKSetupWizard *wizard);
