@@ -105,7 +105,7 @@ void EditFormatDialog::precisionFieldChanged (int) {
 EditFormatDialogProxy::EditFormatDialogProxy (QWidget* parent) : QWidget (parent) {
 	RK_TRACE (EDITOR);
 
-	dialog = 0;
+	dialog = nullptr;
 }
 
 EditFormatDialogProxy::~EditFormatDialogProxy () {
@@ -122,7 +122,7 @@ void EditFormatDialogProxy::initialize (const RKVariable::FormattingOptions& opt
 	dialog->initialize (options, varname);
 
 	connect (dialog, &QDialog::finished, this, &EditFormatDialogProxy::dialogDone);
-	QTimer::singleShot (0, dialog, SLOT (exec()));
+	QTimer::singleShot(0, dialog, &EditFormatDialog::exec);
 }
 
 void EditFormatDialogProxy::dialogDone (int result) {
@@ -131,11 +131,11 @@ void EditFormatDialogProxy::dialogDone (int result) {
 
 	if (result == QDialog::Accepted) {
 		options = dialog->options;
-		emit done(this, RKItemDelegate::EditorExit);
+		Q_EMIT done(this, RKItemDelegate::EditorExit);
 	} else {
-		emit done(this, RKItemDelegate::EditorReject);
+		Q_EMIT done(this, RKItemDelegate::EditorReject);
 	}
 	dialog->deleteLater ();
-	dialog = 0;
+	dialog = nullptr;
 }
 
