@@ -35,9 +35,9 @@ RKVarLevelsTable::RKVarLevelsTable (QWidget *parent, const RObject::ValueLabels&
 	verticalHeader ()->setFixedWidth (40);
 	setMinimumWidth (80);
 
-	addAction (KStandardAction::cut (this, SLOT (cut()), this));
-	addAction (KStandardAction::copy (this, SLOT (copy()), this));
-	addAction (KStandardAction::paste (this, SLOT (paste()), this));
+	addAction(KStandardAction::cut(this, &RKVarLevelsTable::cut, this));
+	addAction(KStandardAction::copy(this, &RKVarLevelsTable::copy, this));
+	addAction(KStandardAction::paste(this, &RKVarLevelsTable::paste, this));
 	setContextMenuPolicy (Qt::ActionsContextMenu);
 
 	setModel (lmodel = new RKVarLevelsTableModel (labels, this));
@@ -172,7 +172,7 @@ bool RKVarLevelsTableModel::setData (const QModelIndex& index, const QVariant& v
 		endInsertRows ();
 	} else {
 		labels.insert (QString::number (index.row () + 1), text);
-		emit dataChanged(index, index);
+		Q_EMIT dataChanged(index, index);
 	}
 
 	if (text.isEmpty ()) {	// remove trailing empty rows
@@ -228,7 +228,7 @@ void EditLabelsDialog::accept () {
 
 EditLabelsDialogProxy::EditLabelsDialogProxy (QWidget* parent) : QWidget (parent) {
 	RK_TRACE (EDITOR);
-	dialog = 0;
+	dialog = nullptr;
 }
 
 EditLabelsDialogProxy::~EditLabelsDialogProxy () {
@@ -244,7 +244,7 @@ void EditLabelsDialogProxy::initialize (const RObject::ValueLabels& labels, cons
 
 	dialog = new EditLabelsDialog (this, labels, varname);
 	connect (dialog, &QDialog::finished, this, &EditLabelsDialogProxy::dialogDone);
-	QTimer::singleShot (0, dialog, SLOT (exec()));
+	QTimer::singleShot(0, dialog, &EditLabelsDialog::exec);
 }
 
 void EditLabelsDialogProxy::dialogDone (int result) {
@@ -253,12 +253,12 @@ void EditLabelsDialogProxy::dialogDone (int result) {
 
 	if (result == QDialog::Accepted) {
 		labels = dialog->table->lmodel->labels;
-		emit done(this, RKItemDelegate::EditorExit);
+		Q_EMIT done(this, RKItemDelegate::EditorExit);
 	} else {
-		emit done(this, RKItemDelegate::EditorReject);
+		Q_EMIT done(this, RKItemDelegate::EditorReject);
 	}
 	dialog->deleteLater ();
-	dialog = 0;
+	dialog = nullptr;
 }
 
 
