@@ -28,7 +28,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 class RKAccordionDummyModel : public QAbstractProxyModel {
 	Q_OBJECT
 public:
-	RKAccordionDummyModel (QObject *parent) : QAbstractProxyModel (parent) {
+	explicit RKAccordionDummyModel(QObject *parent) : QAbstractProxyModel(parent) {
 		add_trailing_columns = 1;
 		add_trailing_rows = 1;
 	};
@@ -156,7 +156,7 @@ public:
 	static const quint32 trailing_item_id = 0xFFFFFFFE;
 	int add_trailing_columns;
 	int add_trailing_rows;
-public slots:
+public Q_SLOTS:
 	void r_rowsInserted (const QModelIndex& parent, int start, int end) {
 		RK_TRACE (MISC);
 		RK_ASSERT (!parent.isValid ());
@@ -172,13 +172,13 @@ public slots:
 		endRemoveRows ();
 	}
 	void r_dataChanged (const QModelIndex& from, const QModelIndex& to) {
-		emit dataChanged(mapFromSource(from), mapFromSource(to));
+		Q_EMIT dataChanged(mapFromSource(from), mapFromSource(to));
 	}
 	void r_headerDataChanged(Qt::Orientation o,int from,int to) {
-		emit headerDataChanged(o, from, to);
+		Q_EMIT headerDataChanged(o, from, to);
 	}
 	void r_layoutChanged () {
-		emit layoutChanged();
+		Q_EMIT layoutChanged();
 	}
 };
 
@@ -214,7 +214,7 @@ private:
 /** Responsible for drawing expand / collapse indicators in first column */
 class RKAccordionDelegate : public QStyledItemDelegate {
 public:
-	RKAccordionDelegate (RKAccordionTable* parent) : QStyledItemDelegate (parent) {
+	explicit RKAccordionDelegate(RKAccordionTable* parent) : QStyledItemDelegate(parent) {
 		table = parent;
 		expanded = RKStandardIcons::getIcon (RKStandardIcons::ActionCollapseUp);
 		collapsed = RKStandardIcons::getIcon (RKStandardIcons::ActionExpandDown);
@@ -262,7 +262,7 @@ RKAccordionTable::RKAccordionTable (QWidget* parent) : QTreeView (parent) {
 	setItemsExpandable (false);        // custom handling
 	setSizePolicy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 
-	pmodel = new RKAccordionDummyModel (0);
+	pmodel = new RKAccordionDummyModel(nullptr);
 	RKAccordionDelegate* delegate = new RKAccordionDelegate (this);
 	delegate->pmodel = pmodel;
 	setItemDelegateForColumn (0, delegate);
@@ -382,7 +382,7 @@ void RKAccordionTable::rowClicked (QModelIndex row) {
 	}
 	if (!row.parent ().isValid ()) {
 		if (row.row () >= pmodel->rowCount () - pmodel->add_trailing_rows) {
-			emit addRow(row.row());
+			Q_EMIT addRow(row.row());
 		}
 	}
 }
@@ -394,7 +394,7 @@ void RKAccordionTable::currentChanged (const QModelIndex& current, const QModelI
 	if (handling_a_click) return;
 	if (!pmodel->isFake (current)) {
 		setExpanded (current, true);
-		emit activated(current.row());
+		Q_EMIT activatedRow(current.row());
 	}
 }
 
@@ -404,12 +404,12 @@ void RKAccordionTable::rowExpanded (QModelIndex row) {
 	for (int i = 0; i < pmodel->rowCount () - pmodel->add_trailing_rows; ++i) {
 		QModelIndex _row = model ()->index (i, 0);
 		if (i != row.row ()) {
-			setIndexWidget (model ()->index (0, 0, _row), 0);
-			setExpanded (_row, false);
+			setIndexWidget(model()->index(0, 0, _row), nullptr);
+			setExpanded(_row, false);
 		}
 	}
 	setFirstColumnSpanned (0, row, true);
-	setIndexWidget (model ()->index (0, 0, row), new RKWidgetGuard (0, editor_widget_container, this));
+	setIndexWidget(model()->index(0, 0, row), new RKWidgetGuard(nullptr, editor_widget_container, this));
 	setCurrentIndex (row);
 	scrollTo (row, EnsureVisible);                          // yes, we want both scrolls: We want the header row above the widget, if possible at all,
 	scrollTo (model ()->index (0, 0, row), EnsureVisible);  // but of course, having the header row visible without the widget is not enough...
@@ -483,7 +483,7 @@ void RKAccordionTable::removeClicked () {
 		RK_ASSERT (row >= 0);
 		return;
 	}
-	emit removeRow(row);
+	Q_EMIT removeRow(row);
 }
 
 void RKAccordionTable::setModel (QAbstractItemModel* model) {
