@@ -80,12 +80,7 @@ RKOutputDirectory* RKOutputDirectory::findOutputByWorkPath(const QString& workpa
 
 	if (workpath.endsWith("index.html")) {
 		QString wp = workpath;
-#if QT_VERSION >= QT_VERSION_CHECK(5,10,0)
 		return(outputs.value(wp.chopped(11)));  // index.html, including pathsep
-#else
-		wp.chop(11);
-		return(outputs.value(wp));
-#endif
 	}
 	return nullptr;
 }
@@ -335,11 +330,11 @@ GenericRRequestResult RKOutputDirectory::purge(RKOutputDirectory::OverwriteBehav
 			return GenericRRequestResult::makeError(i18n("Output has been modified. Not closing it."));
 		}
 		if (discard == Ask) {
-			auto res = KMessageBox::questionYesNoCancel(RKWardMainWindow::getMain(), i18n("The output has been modified, and closing it will discard all changes. What do you want to do?"), i18n("Discard unsaved changes?"), KStandardGuiItem::discard(), KStandardGuiItem::save(), KStandardGuiItem::cancel());
+			auto res = KMessageBox::questionTwoActionsCancel(RKWardMainWindow::getMain(), i18n("The output has been modified, and closing it will discard all changes. What do you want to do?"), i18n("Discard unsaved changes?"), KStandardGuiItem::discard(), KStandardGuiItem::save(), KStandardGuiItem::cancel());
 			if (res == KMessageBox::Cancel) {
 				return GenericRRequestResult::makeError(i18n("User canceled"));
 			}
-			if (res == KMessageBox::No) {
+			if (res == KMessageBox::SecondaryAction) {
 				auto ret = save(save_filename);
 				if (ret.failed()) return ret;
 			}
@@ -415,7 +410,7 @@ RKOutputDirectoryCallResult RKOutputDirectory::getCurrentOutput(RCommandChain* c
 	if (outputs.isEmpty()) {
 		if (RKSettingsModuleOutput::sharedDefaultOutput()) {
 			QString filename = RKSettingsModuleGeneral::filesPath() + "default.rko";
-			auto ret = get(filename, !QFileInfo::exists(filename), chain);
+			ret = get(filename, !QFileInfo::exists(filename), chain);
 			if (ret.dir()) {
 				ret.dir()->activate(chain);
 				return ret;
@@ -597,7 +592,7 @@ void RKOutputDirectory::setKnownModified(bool modified) {
 	RK_TRACE(APP);
 	if (known_modified != modified) {
 		known_modified = modified;
-		emit stateChange(isActive(), modified);
+		Q_EMIT stateChange(isActive(), modified);
 	}
 }
 
