@@ -29,11 +29,17 @@ void RKPasteSpecialAction::doSpecialPaste() {
 	RK_TRACE(MISC);
 
 	QWidget *pwin = nullptr;
-	if (!associatedWidgets().isEmpty()) pwin = associatedWidgets().at(0);
+	const auto objs = associatedObjects();
+	for(auto obj : objs) {
+		if (qobject_cast<QWidget*>(obj)) {
+			pwin = static_cast<QWidget*>(obj);
+			break;
+		}
+	}
 	RKPasteSpecialDialog* dialog = new RKPasteSpecialDialog(pwin);
 	int res = dialog->exec();
 	if (res == QDialog::Accepted) {
-		emit pasteText(dialog->resultingText());
+		Q_EMIT pasteText(dialog->resultingText());
 	}
 	dialog->deleteLater();
 }
@@ -56,7 +62,6 @@ void RKPasteSpecialAction::doSpecialPaste() {
 #include "rksaveobjectchooser.h"
 #include "../rbackend/rkrinterface.h"
 #include "../misc/rkprogresscontrol.h"
-#include "../misc/rkcompatibility.h"
 
 RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : QDialog(parent) {
 	RK_TRACE (MISC);
@@ -94,7 +99,7 @@ RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : Q
 	dimensionality_group->addButton (rbutton, DimDataFrame);
 	rbutton->setChecked (true);
 	group_layout->addWidget (rbutton);
-	connect (dimensionality_group, RKCompatibility::groupButtonClicked(), this, &RKPasteSpecialDialog::updateState);
+	connect (dimensionality_group, &QButtonGroup::idClicked, this, &RKPasteSpecialDialog::updateState);
 	rowlayout->addWidget (box);
 
 	const QMimeData* clipdata = QApplication::clipboard ()->mimeData ();
@@ -124,7 +129,7 @@ RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : Q
 	separator_freefield = new QLineEdit (";", box);
 	h_layout->addWidget (separator_freefield);
 	group_layout->addLayout (h_layout);
-	connect (separator_group, RKCompatibility::groupButtonClicked(), this, &RKPasteSpecialDialog::updateState);
+	connect (separator_group, &QButtonGroup::idClicked, this, &RKPasteSpecialDialog::updateState);
 	rowlayout->addWidget (box);
 
 	rowlayout = new QHBoxLayout;
@@ -144,7 +149,7 @@ RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : Q
 	rbutton = new QRadioButton (i18n ("Quote all values"), box);
 	quoting_group->addButton (rbutton, QuoteAll);
 	group_layout->addWidget (rbutton);
-	connect (quoting_group, RKCompatibility::groupButtonClicked(), this, &RKPasteSpecialDialog::updateState);
+	connect (quoting_group, &QButtonGroup::idClicked, this, &RKPasteSpecialDialog::updateState);
 	rowlayout->addWidget (box);
 
 	// Labels
@@ -225,7 +230,7 @@ QString RKPasteSpecialDialog::resultingText () {
 
 	if (dim == DimSingleString) return prepString(clip, quot);
 
-	QRegExp fieldsep;
+	QRegularExpression fieldsep;
 	if (sep == SepCustom) fieldsep.setPattern (separator_freefield->text ());
 	else if (sep == SepWhitespace) fieldsep.setPattern ("\\s+");
 	else if (sep == SepSpace) fieldsep.setPattern (" ");
