@@ -16,24 +16,18 @@ SPDX-License-Identifier: GPL-2.0-or-later
 KColorScheme* RKStyle::_view_scheme = nullptr;
 
 int RKStyle::marginHint() {
-	return QApplication::style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+	return QApplication::style()->pixelMetric(QStyle::PM_LayoutTopMargin);
 }
 
 int RKStyle::spacingHint() {
-	return QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+	return QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing);
 }
 
 KColorScheme* RKStyle::viewScheme() {
 	if (!_view_scheme) {
 		RK_TRACE(MISC);
+		// Note: Will be updated on changes with RKWardMainWindow::event
 		_view_scheme = new KColorScheme(QPalette::Normal);
-		QObject::connect(qApp, &QGuiApplication::paletteChanged, cleanResources);  // will be re-initialized when needed, again; NOTE: Not emitted before Qt 5.13.0, so quirky, before
 	}
 	return _view_scheme;
 }
-
-void RKStyle::cleanResources() {
-	RK_TRACE(MISC);
-	delete _view_scheme;
-	_view_scheme = nullptr;
-}
