@@ -29,12 +29,12 @@ public:
 	int type () override { return ComponentMatrixInput; };
 	bool isValid () override { return is_valid; };
 	QVariant value (const QString &modifier=QString ()) override;
-public slots:
+public Q_SLOTS:
 	void cut ();
 	void copy ();
 	void paste ();
 	void clearSelectedCells ();
-private slots:
+private Q_SLOTS:
 	void dimensionPropertyChanged (RKComponentPropertyBase *property);
 	void tsvPropertyChanged ();
 private:
@@ -94,8 +94,8 @@ private:
 class RKMatrixInputModel : public QAbstractTableModel {
 private:
 friend class RKMatrixInput;
-	RKMatrixInputModel (RKMatrixInput *matrix);
-	virtual ~RKMatrixInputModel ();
+	explicit RKMatrixInputModel(RKMatrixInput *matrix);
+	virtual ~RKMatrixInputModel();
 	int rowCount (const QModelIndex &parent = QModelIndex()) const override; // implemented for QAbstractTableModel
 	int columnCount (const QModelIndex &parent = QModelIndex()) const override; // implemented for QAbstractTableModel
 	QVariant data (const QModelIndex &index, int role = Qt::DisplayRole) const override; // re-implemented for QAbstractTableModel
