@@ -50,17 +50,15 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../debug.h"
 
 
-RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget *parent_widget, const QString &filename, const QString &id) : RKComponent (parent_component, parent_widget) {
+RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget *parent_widget, const QString &filename, const QString &id) : RKComponent (parent_component, parent_widget), filename(filename), id(id) {
 	RK_TRACE (PLUGIN);
 
-	RKStandardComponent::filename = filename;
-	RKStandardComponent::id = id;
-	command_chain = 0;
-	backend = 0;
-	scripting = 0;
-	gui = 0;
-	wizard = 0;
-	xml = 0;
+	command_chain = nullptr;
+	backend = nullptr;
+	scripting = nullptr;
+	gui = nullptr;
+	wizard = nullptr;
+	xml = nullptr;
 	created = false;
 	killed = false;
 	addChild ("code", code = new RKComponentPropertyCode (this, true));		// do not change this name!
@@ -108,7 +106,7 @@ RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget
 	connect (backend, &ScriptBackend::idle, this, &RKStandardComponent::backendIdle);
 	connect (backend, &ScriptBackend::requestValue, this, &RKStandardComponent::getValue);
 	connect (backend, &ScriptBackend::haveError, this, &RKStandardComponent::kill);
-	if (!backend->initialize (code, parent_component == 0)) return;
+	if (!backend->initialize (code, parent_component == nullptr)) return;
 
 	// check for existence of help file
 	element = xml->getChildElement(doc_element, "help", DL_WARNING);
@@ -221,7 +219,7 @@ XMLHelper* RKStandardComponent::getXmlHelper () {
 
 	if (!xml) {
 		RKComponentHandle *handle = RKComponentMap::getComponentHandle (id);
-		xml = new XMLHelper (filename, handle ? handle->messageCatalog () : 0);
+		xml = new XMLHelper(filename, handle ? handle->messageCatalog() : nullptr);
 	}
 	return xml;
 }
@@ -309,11 +307,11 @@ void RKStandardComponent::discard () {
 	created = false;
 	gui->hide ();
 	gui->deleteLater ();
-	gui = 0;
-	wizard = 0;
+	gui = nullptr;
+	wizard = nullptr;
 
 	// clear all properties. Not the code property, as the script backend relies on it
-	for (QHash<QString, RKComponentBase*>::const_iterator it = child_map.constBegin (); it != child_map.constEnd (); ++it) {
+	for (auto it = child_map.constBegin (); it != child_map.constEnd (); ++it) {
 		if (it.value () != code) {
 			if (it.value ()->isProperty ()) {
 				static_cast<RKComponentPropertyBase *> (it.value ())->deleteLater ();
@@ -350,18 +348,18 @@ void RKStandardComponent::buildAndInitialize (const QDomElement &doc_element, co
 	if (gui && (!enslaved)) {
 		// somehow, when switching the interface, and we show before the old GUI has been fully deleted (it is deleted via deleteLater (), then there may be strange graphical glitches until the GUI is first redrawn completely.
 		// Likely a difficult bug in Qt. Delaying the show until the next event loop solves the problem.
-		QTimer::singleShot (0, gui, SLOT (show()));
+		QTimer::singleShot(0, gui, [this]() { gui->show(); });
 	}
 	changed ();
-	emit standardInitializationComplete();
+	Q_EMIT standardInitializationComplete();
 }
 
-RKXMLGUIPreviewArea* RKStandardComponent::addDockedPreview (RKComponentPropertyBool* controller, const QString& label, const QString &id) {
-	RK_TRACE (PLUGIN);
+RKXMLGUIPreviewArea* RKStandardComponent::addDockedPreview(RKComponentPropertyBool* controller, const QString& label, RKPreviewManager *manager) {
+	RK_TRACE(PLUGIN);
 
-	RK_ASSERT (gui);
-	if (!gui) return 0;
-	return gui->addDockedPreview (controller, label, id);
+	RK_ASSERT(gui);
+	if (!gui) return nullptr;
+	return gui->addDockedPreview(controller, label, manager);
 }
 
 RKComponentBase::ComponentStatus RKStandardComponent::recursiveStatus () {
@@ -388,7 +386,7 @@ void RKStandardComponent::close () {
 	RK_TRACE (PLUGIN);
 
 	if (gui && (!parentComponent ())) {
-		QTimer::singleShot (0, gui, SLOT (close()));
+		QTimer::singleShot(0, gui, [this]() { gui->close(); });
 	} else {
 		RK_ASSERT (false);
 	}
@@ -403,7 +401,7 @@ void RKStandardComponent::changed () {
 	// don't trigger update twice
 	if (!update_pending) {
 		update_pending = true;
-		QTimer::singleShot (0, this, SLOT (handleChange()));
+		QTimer::singleShot(0, this, [this](){ handleChange(); });
 	}
 }
 
@@ -445,7 +443,7 @@ void RKStandardComponent::getValue (const QString &id, const int hint) {
 bool RKStandardComponent::isWizardish () {
 	RK_TRACE (PLUGIN);
 
-	if (gui) return (wizard != 0);
+	if (gui) return (wizard != nullptr);
 	if (parentComponent ()) return (parentComponent ()->isWizardish ());
 	return false;
 }
@@ -571,7 +569,7 @@ void RKComponentBuilder::buildElement (const QDomElement &element, XMLHelper &xm
 	XMLChildList::const_iterator it;
 	for (it = children.constBegin (); it != children.constEnd (); ++it) {
 		bool add_to_layout = true;
-		RKComponent *widget = 0;
+		RKComponent *widget = nullptr;
 		QDomElement e = *it;		// shorthand
 		QString id = xml.getStringAttribute (e, "id", QString (), DL_INFO);
 
@@ -670,7 +668,7 @@ void RKComponentBuilder::buildElement (const QDomElement &element, XMLHelper &xm
 			RKComponentHandle *handle = RKComponentMap::getComponentHandle (component_id);
 			if (handle) {
 				if (xml.getBoolAttribute (e, "as_button", false, DL_INFO)) {
-					RKStandardComponent* swidget = handle->invoke (component (), 0);
+					RKStandardComponent* swidget = handle->invoke (component (), nullptr);
 					widget = swidget;
 					QString dummy = xml.i18nStringAttribute (e, "label", i18n ("Options"), DL_WARNING);
 					swidget->setCaption (dummy);
