@@ -21,6 +21,7 @@ class RKStandardComponentStack;
 class ScriptBackend;
 class QTimer;
 class RKXMLGUIPreviewArea;
+class RKPreviewManager;
 
 /** The standard type of component (i.e. stand-alone), previously known as "plugin". This is the type of component described by an XML-file
 
@@ -63,7 +64,7 @@ public:
 /** Submits the current code (by simulating a click on the ok button).
 @param in_chain The command chain to insert the command in (0 for regular command stack).
 @return false, if the plugin-code could not be submitted (e.g. plugin was not satisfied) */
-	bool submit (RCommandChain *in_chain = 0);
+	bool submit(RCommandChain *in_chain = nullptr);
 /** convenience access function: closes the corresponding GUI */
 	void close ();
 /** reimplemented to actually return Dead or Processing when appropriate */
@@ -74,10 +75,10 @@ public:
 /** Return the GUI-scripting handler (creating it, if needed) */
 	RKComponentScriptingProxy* scriptingProxy ();
 
-	RKXMLGUIPreviewArea *addDockedPreview (RKComponentPropertyBool *controller, const QString& label, const QString &id = QString ());
-signals:
+	RKXMLGUIPreviewArea *addDockedPreview(RKComponentPropertyBool *controller, const QString& label, RKPreviewManager *manager);
+Q_SIGNALS:
 	void standardInitializationComplete ();
-public slots:
+public Q_SLOTS:
 /** this gets called by the script-backend, when it's done. Might enable the
 	submit button or destruct the plugin. */
 	void backendIdle ();
