@@ -1,4 +1,13 @@
-function calculate () {
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
+function preview () {
+	calculate (true);
+}
+
+function calculate (is_preview) {
 	var tableOptions = "";
 	var quick = getValue ("quick");
 	if (quick == "custom") quick = "table";   // Difference only relevant in UI
@@ -28,17 +37,21 @@ function calculate () {
 	// doing col class (what a pity...)
 	if (getValue("colclass") == "custoClass") echo( "colClasses = " + getValue ("custoClasses") + ",");
 	//doing what is left
-	echo (' na.strings = "' + getValue("na") + '", nrows = ' + getValue("nrows") + ', skip = ' + getValue("skip") + ', check.names = ' + getValue("checkname") + ', strip.white = ' + getValue("stripwhite") + ', blank.lines.skip = ' + getValue("blanklinesskip") + getValue("allow_escapes") + getValue("flush") + getValue("strings_as_factors") + ')\n');
+	var nrows = 'nrows = ' + (is_preview ? '50' : getString ("nrows"));  // limit preview to first 50 rows for efficiency
+	echo (' na.strings = "' + getValue("na") + '", ' + nrows + ', skip = ' + getValue("skip") + ', check.names = ' + getValue("checkname") + ', strip.white = ' + getValue("stripwhite") + ', blank.lines.skip = ' + getValue("blanklinesskip") + getValue("allow_escapes") + getValue("flush") + getValue("strings_as_factors") + ')\n');
 	echo ('\n');
-	comment ('copy from the local environment to globalenv()');
-	echo ('.GlobalEnv$' + getValue("name") + ' <- imported\n');
-	if (getValue ("doedit")) {
-		echo ('\n');
-		echo ('rk.edit (.GlobalEnv$' + getValue ("name") + ')\n');
+	if (is_preview) {
+		echo ('preview_data <- imported[1:min(50,length(imported))]\n');  // limit preview to first 50 columns for efficiency
+	} else {
+		comment ('copy from the local environment to globalenv()');
+		echo ('.GlobalEnv$' + getValue("name") + ' <- imported\n');
+		if (getBoolean ("doedit")) {
+			echo ('\n');
+			echo ('rk.edit (.GlobalEnv$' + getValue ("name") + ')\n');
+		}
 	}
 }
 
 function printout () {
 	new Header (i18n ("Import text / csv data")).addFromUI ("file").addFromUI ("name").print ();
 }
-
