@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 include ("convert_encoding.js");
 
 function preprocess () {
@@ -5,10 +10,15 @@ function preprocess () {
 	makeEncodingPreprocessCode ();
 }
 
-function calculate () {
+function preview () {
+	preprocess ();
+	calculate (true);
+}
+
+function calculate (is_preview) {
 	var data_frame = "";
 	var data_frame_opt = "";
-	if (getValue ("data_frame")) {
+	if (getValue ("data_frame") || is_preview) {
 		data_frame = true;
 		data_frame_opt = ", to.data.frame=TRUE";
 	}
@@ -39,9 +49,13 @@ function calculate () {
 		echo ('}\n');
 	}
 	echo ('\n');
-	echo ('.GlobalEnv$' + object + ' <- data		'); comment ('assign to globalenv()');
-	if (getValue ("doedit") && data_frame) {
-		echo ('rk.edit (.GlobalEnv$' + object + ')\n');
+	if (is_preview) {
+		echo ('preview_data <- data[1:min(50,dim(data)[1]),1:min(50,dim(data)[2]),drop=FALSE]\n');
+	} else {
+		echo ('.GlobalEnv$' + object + ' <- data		'); comment ('assign to globalenv()');
+		if (getValue ("doedit") && data_frame) {
+			echo ('rk.edit (.GlobalEnv$' + object + ')\n');
+		}
 	}
 }
 
