@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 function calculate () {
 	var vars = trim (getValue ("x"));
 
@@ -22,9 +27,11 @@ function calculate () {
 	echo ('}\n');
 }
 
-function printout () {
-	new Header ("Phillips-Perron Test for Unit Roots").addFromUI ("lshort").print ();
-	echo ('\n');
+function printout (is_preview) {
+	if (!is_preview) {
+		new Header ("Phillips-Perron Test for Unit Roots").addFromUI ("lshort").print ();
+		echo ('\n');
+	}
 	echo ('rk.results (results)\n');
 }
 
