@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Meik Michalke <meik.michalke@hhu.de>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 function preprocess () {
 	// we'll need the ltm package, so in case it's not loaded...
 	echo ('require(ltm)\n');
@@ -45,12 +50,14 @@ function calculate () {
 	echo (')\n');
 }
 
-function printout () {
+function printout (is_preview) {
 	// check whether parameter estimations should be kept in the global enviroment
 	var save         = getValue("save_name.active");
 	var save_name    = getValue("save_name");
 
-	echo ('rk.header ('+ i18n ("2PL parameter estimation") + ')\n');
+	if (!is_preview) {
+		echo ('rk.header ('+ i18n ("2PL parameter estimation") + ')\n');
+	}
 	echo ('rk.print (' + i18n ("Call:") + ')\n');
 	echo ('rk.print.literal (deparse(estimates.2pl$call, width.cutoff=500))\n');
 	echo ('rk.header (' + i18n ("Coefficients:") + ', level=4)\n');
