@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 include ("moments_common.js");
 function preprocess () {} // empty for this one
 
@@ -17,7 +22,9 @@ function insertTestCall () {
 	}
 }
 
-function printout () {
-	echo ('rk.header (' + i18n ("Skewness and Kurtosis") + ')\n');
+function printout (is_preview) {
+	if (!is_preview) {
+		echo ('rk.header (' + i18n ("Skewness and Kurtosis") + ')\n');
+	}
 	echo ('rk.results (results)\n');
 }
