@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 include ("outliers_common.js");
 
 function makeTestCall () {
@@ -8,7 +13,9 @@ function makeTestCall () {
 	echo ('		results[i, ' + i18n ("Variance") + '] <- var (var)\n');
 }
 
-function printout () {
-	new Header (i18n ("Chi-squared test for outlier")).addFromUI ("opposite").print ();
+function printout (is_preview) {
+	if (!is_preview) {
+		new Header (i18n ("Chi-squared test for outlier")).addFromUI ("opposite").print ();
+	}
 	echo ('rk.results (results)\n');
 }
