@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 function printout () {
 	doPrintout (true);
 }
@@ -26,9 +31,10 @@ function doPrintout (full) {
 		echo (getValue ('tabulate_options.code.calculate'));
 	} else {
 		echo ('x <- ' + varname + "\n");
-		comment ('barplot is a bit picky about attributes, so we need to convert to vector explicitly');
-		echo ('if(!is.matrix(x)) x <- as.vector(x)\n');
-		echo ('if(!is.matrix(x) && is.data.frame(x)) x <- data.matrix(x)\n');
+		comment ('barplot is a bit picky about attributes, so we need to convert to vector or matrix explicitly');
+		echo ('if(!is.matrix(x)) {\n');
+		echo ('\tif (is.data.frame(x)) x <- data.matrix(x) else x <- as.vector(x)\n');
+		echo ('}\n');
 	}
 
 	if (limit) {
