@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 function printout () {
 	doPrintout (true);
 }
@@ -14,8 +19,7 @@ function doPrintout (full) {
 	}
 
 	if (full) {
-
-		echo ('rk.header ("Generic Plot")\n');
+		new Header (i18n ("Generic Plot")).print ();
 		echo ('rk.graph.on ()\n');
 	}
 
