@@ -1,3 +1,8 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 function calculate () {
 	echo ("## Manual set: ##\n")
 	echo ("row_count <- " + getValue ("mset.row_count") + "\n");
@@ -7,6 +12,7 @@ function calculate () {
 	echo ("row_count <- " + getValue ("set.row_count") + "\n");
 	echo ("current_row <- " + getValue ("set.current_row") + "\n");
 	echo ("set.contents.enabled <- " + getValue ("set.contents.enabled") + "\n");
+	echo (getList ("mset.summary").join (",") + "\n");
 
 	var codeprops = getList ("set.plotoption_printout");
 	for (i = 0; i < codeprops.length; ++i) {
