@@ -1,10 +1,17 @@
+/*- This file is part of the RKWard project (https://rkward.kde.org).
+SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 function preprocess () {
 	if (getValue ("format") == "svg") {
 		echo ('if (!capabilities ("cairo")) {\n');
-		echo ('	# The "cairo" library, providing SVG-support, is not compiled in by default on some systems.\n');
-		echo ('	require (cairoDevice)\n');
-		echo ('	svg <- Cairo_svg\n');
+		comment ('The "cairo" library, providing SVG-support, is not compiled in by default on some systems.', '	');
+		echo ('	require (Cairo)\n');
+		echo ('	svg <- CairoSVG\n');
 		echo ('}\n');
+	} else if (getValue ("format") == "tikz") {
+		echo ('require (tikzDevice)\n');
 	}
 }
 
@@ -23,7 +30,7 @@ function calculate () {
 		jpegpng = ((type == "jpeg") | (type == "png"));
 		eps = (type == "postscript") && (getValue ("formateps"));
 
-		// Does the filename end with .ps/.eps or .pdf or .png or .jpeg/.jpg?
+		// Does the filename end with .ps/.eps or .pdf or .png or .jpeg/.jpg or .tex?
 		// If not, add the appropriate extension.
 		if (getValue ("autoextension")) {
 			if (type == "jpeg") {
@@ -34,6 +41,8 @@ function calculate () {
 				} else {
 					if (file.search (/\.e?ps$/i) < 0) file += ".ps";
 				}
+			} else if (type == "tikz") {
+				if (file.search (/\.tex$/i) < 0) file += ".tex";
 			} else {
 				var regexp = new RegExp ("\." + type + "$", "i");
 				if (file.search (regexp) < 0) file += "." + type;
@@ -100,9 +109,9 @@ function calculate () {
 
 	echo ('dev.set (' + getValue ("devnum") + ')\n');
 	if (type == "gs") {
-		echo ('dev2bitmap ("' + file + '", type="' + gstype + '"' + options + ');\n');
+		echo ('dev2bitmap ("' + file + '", type="' + gstype + '"' + options + ')\n');
 	} else {
-		echo ('dev.print (device=' + type + ', file="' + file + '"' + options + ');\n');
+		echo ('dev.print (device=' + type + ', file="' + file + '"' + options + ')\n');
 	}
 }
 
