@@ -1,6 +1,6 @@
 /*
 rkfrontendtransmitter - This file is part of RKWard (https://rkward.kde.org). Created: Thu Nov 04 2010
-SPDX-FileCopyrightText: 2010-2019 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2010-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,19 +10,23 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "rkrbackendprotocol_frontend.h"
 #include "rkwarddevice/rkgraphicsdevice_frontendtransmitter.h"
 #include "rksessionvars.h"
-#include "../misc/rkcommonfunctions.h"
+#include "../misc/rkcommandlineargs.h"
 #include "../settings/rksettingsmodulegeneral.h"
+#include "../settings/rksettingsmoduler.h"
 
 #include <KLocalizedString>
 #include <krandom.h>
 
 #include <QCoreApplication>
+#include <QRegularExpression>
 #include <QProcess>
 #include <QLocalServer>
 #include <QLocalSocket>
 #include <QDir>
 #include <QStandardPaths>
 #include <QElapsedTimer>
+#include <QTemporaryDir>
+#include <QSettings>
 
 #include "../version.h"
 #include "../debug.h"
@@ -41,7 +45,49 @@ QString findBackendAtPath (const QString &path) {
 	return QString ();
 }
 
-RKFrontendTransmitter::RKFrontendTransmitter () : RKAbstractTransmitter () {
+#if defined(RK_DLOPEN_LIBRSO)
+QString findBackendLibAtPath(const QString &path) {
+	QDir dir(path);
+	dir.makeAbsolute();
+#ifdef Q_OS_WIN
+	QString ret = dir.filePath("rkward.rbackend.lib.dll");
+#elif defined(Q_OS_MACOS)
+	QString ret = dir.filePath("librkward.rbackend.lib.dylib");
+#else
+	QString ret = dir.filePath("librkward.rbackend.lib.so");
+#endif
+	RK_DEBUG(RBACKEND, DL_DEBUG, "Looking for backend lib at %s", qPrintable(ret));
+	if (QFileInfo::exists(ret)) return ret;
+	return QString();
+}
+#endif
+
+bool pathIsChildOf(const QString &parent, const QString &child) {
+	return QFileInfo(child).canonicalFilePath().startsWith(QFileInfo(parent).canonicalFilePath());
+}
+
+void removeFromPathList (const char* varname, bool (*shouldRemove)(const QString &path)) {
+#ifdef Q_OS_WIN
+#	define PATH_VAR_SEP ';'
+#else
+#	define PATH_VAR_SEP ':'
+#endif
+	auto var = qgetenv(varname);
+	if (var.isEmpty()) return;
+
+	const auto list = QString::fromLocal8Bit(var).split(PATH_VAR_SEP);
+	QStringList newlist;
+	for(const auto &str : list) {
+		if (shouldRemove(str)) {
+			RK_DEBUG(RBACKEND, DL_DEBUG, "Removing path %s from $%s", qPrintable(str), varname);
+		} else {
+			newlist.append(str);
+		}
+	}
+	qputenv(varname, newlist.join(PATH_VAR_SEP).toLocal8Bit());
+}
+
+RKFrontendTransmitter::RKFrontendTransmitter(RKRBackendProtocolFrontend *frontend) : RKAbstractTransmitter(), frontend(frontend) {
 	RK_TRACE (RBACKEND);
 
 	rkd_transmitter = new RKGraphicsDeviceFrontendTransmitter ();
@@ -63,10 +109,70 @@ QString localeDir () {
 	return QFileInfo (file.left (file.size() - relpath.size ())).absolutePath ();
 }
 
+/** Check if the given path to R (or "auto") is executable, and fail with an appropriate message, otherwise. If "auto" is given as input, try to auto-locate an R installation at the standard
+installation path(s) for this platform. */
+QString RKFrontendTransmitter::resolveRSpecOrFail(QString input) {
+	if (input == QLatin1String("auto")) {
+		QString ret = RKSessionVars::findRInstallations().value(0);
+
+		if (ret.isNull() || !QFileInfo(ret).isExecutable()) {
+			handleTransmissionError(i18n("RKWard failed to detect an R installation on this system. Either R is not installed, or not at one of the standard installation locations."));
+		}
+		RK_DEBUG (APP, DL_DEBUG, "Using auto-detected R at %s", qPrintable (ret));
+		return ret;
+	}
+
+	if (!QFileInfo(input).isExecutable()) {
+		handleTransmissionError(i18n("The configured R installation at <b>%1</b> does not exist or is not an executable.", input));
+	}
+	return input;
+}
+
+void RKFrontendTransmitter::detectAndCheckRBinary() {
+	if (!RKSessionVars::RBinary().isEmpty()) return;
+
+	// Look for R:
+	//- command line parameter
+	//- Specified in cfg file next to rkward executable
+	//- compile-time default
+	QString r_exe = RKCommandLineArgs::get(RKCommandLineArgs::RExecutable).toString();
+	if (!r_exe.isEmpty()) {
+		RK_DEBUG(APP, DL_DEBUG, "Using R as specified on command line");
+	} else if (!RKSettingsModuleR::userConfiguredRBinary().isEmpty()) {
+		RK_DEBUG(APP, DL_DEBUG, "Using R as previously user-configured");
+		r_exe = RKSettingsModuleR::userConfiguredRBinary();
+	} else {
+		QDir frontend_path = qApp->applicationDirPath();
+		QFileInfo rkward_ini_file(frontend_path.absoluteFilePath("rkward.ini"));
+		if (rkward_ini_file.isReadable()) {
+			QSettings rkward_ini(rkward_ini_file.absoluteFilePath(), QSettings::IniFormat);
+			r_exe = rkward_ini.value("R executable").toString ();
+			if (!r_exe.isNull()) {
+				if (QDir::isRelativePath(r_exe) && r_exe != QStringLiteral("auto")) {
+					r_exe = frontend_path.absoluteFilePath (r_exe);
+				}
+			}
+			RK_DEBUG(APP, DL_DEBUG, "Using R as configured in config file %s", qPrintable (rkward_ini_file.absoluteFilePath ()));
+		} else {
+			if (QFileInfo::exists(R_EXECUTABLE)) {
+				RK_DEBUG(APP, DL_DEBUG, "Using R as configured at compile time");
+				r_exe = R_EXECUTABLE;
+			}
+		}
+	}
+	if (r_exe.isEmpty()) {
+		RK_DEBUG(APP, DL_DEBUG, "Falling back to auto-detection of R binary");
+		r_exe = "auto";
+	}
+
+	RKSessionVars::r_binary = resolveRSpecOrFail(r_exe);
+}
+
 void RKFrontendTransmitter::run () {
 	RK_TRACE (RBACKEND);
 
-	quirkmode = RKSettingsModuleGeneral::startupOption("quirkmode").toBool();
+	quirkmode = RKCommandLineArgs::get(RKCommandLineArgs::QuirkMode).toBool();
+	detectAndCheckRBinary();
 
 	// start server
 	server = new QLocalServer (this);
@@ -79,16 +185,21 @@ void RKFrontendTransmitter::run () {
 	backend = new QProcess (this);
 	connect (backend, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &RKFrontendTransmitter::backendExit);
 
-	// Try to synchronize language selection in frontend and backend
 	QStringList env = QProcess::systemEnvironment ();
-	int index = env.indexOf (QRegExp("^LANGUAGE=.*", Qt::CaseInsensitive));
+	// Try to synchronize language selection in frontend and backend
+	int index = env.indexOf(QRegularExpression(QStringLiteral("^LANGUAGE=.*"), QRegularExpression::CaseInsensitiveOption));  // clazy:exclude=use-static-qregularexpression ; it'll only be craeted once
 	if (index >= 0) env.removeAt (index);
 	env.append ("LANGUAGE=" + QLocale ().name ().section ('_', 0, 0));
-	backend->setEnvironment (env);
+
+	if (RKSessionVars::runningInAppImage() && RKSessionVars::isPathInAppImage(RKSessionVars::RBinary())) {
+		RK_DEBUG(RBACKEND, DL_DEBUG, "Detected running from AppImage with external R.");
+		removeFromPathList("LD_LIBRARY_PATH", RKSessionVars::isPathInAppImage);
+		removeFromPathList("PATH", RKSessionVars::isPathInAppImage);
+	}
 
 	QStringList args;
 	args.append("CMD");
-	QString debugger = RKSettingsModuleGeneral::startupOption("backend-debugger").toString();
+	QString debugger = RKCommandLineArgs::get(RKCommandLineArgs::BackendDebugger).toString();
 	if (!debugger.isEmpty()) {
 		args += debugger.split(' ');
 	}
@@ -99,7 +210,7 @@ void RKFrontendTransmitter::run () {
 #endif
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/rbackend");	// for running directly from the build-dir
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../rbackend");	// for running directly from the build-test-dir
-	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../lib/libexec");
+	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/" + REL_PATH_TO_LIBEXEC); // as calculated from cmake
 #ifdef Q_OS_MACOS
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../../../rbackend");
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../Frameworks/libexec");  // For running from .dmg created by craft --package rkward
@@ -111,22 +222,50 @@ void RKFrontendTransmitter::run () {
 		return;
 	}
 
-#ifdef Q_OS_WIN
-	// Needed for paths with spaces. R CMD is too simple to deal with those, even if we provide proper quoting.
-	// So rather we need to work from a relative path with all spaces eliminated
+#if defined(RK_DLOPEN_LIBRSO)
+	/** NOTE: For a description of the rationale for this involved loading procedure rkapi.h ! */
+	QString backend_lib = findBackendLibAtPath(QCoreApplication::applicationDirPath()); // for running directly from the build tree, but also covers windows
+	if (backend_lib.isEmpty()) backend_lib = findBackendLibAtPath(QCoreApplication::applicationDirPath() + "/" + REL_PATH_TO_LIB); // regular installation; rel path between bin and lib dir is calculated in cmake
+	if (backend_lib.isEmpty()) backend_lib = findBackendLibAtPath(QFileInfo(backend_executable).absolutePath()); // backend and lib both installed in libexec or similar
+#	if defined(Q_OS_MACOS)
+	if (backend_lib.isEmpty()) backend_lib = findBackendLibAtPath(QCoreApplication::applicationDirPath() + "/../Frameworks"); // MacOS bundle: rkward in /MacOS, lib in /Framweorks
+#	endif
+#	if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+	env.append(QStringLiteral("RK_BACKEND_LIB=") + backend_lib);
+#	else
+	env.append(QStringLiteral("RK_BACKEND_LIB=") + QFileInfo(backend_lib).fileName());
+	QTemporaryDir rkward_only_dir(QDir::tempPath() + "/rkward_only");
+	QFile(QFileInfo(backend_lib).absolutePath()).link(rkward_only_dir.filePath("_rkward_only_dlpath"));
+	env.append(QStringLiteral("RK_ADD_LDPATH=./_rkward_only_dlpath"));
+	env.append(QStringLiteral("RK_LD_CWD=") + rkward_only_dir.path());
+#	endif
+#endif
+	backend->setEnvironment(env);
+
+#ifndef Q_OS_MACOS
+	// Needed on for paths with spaces. R CMD is too simple to deal with those, even if we provide proper quoting.
+	// So rather we need to work from a relative path with all spaces eliminated.
+	// However, also, we might start in directory that no longer exists, or will cease to exist, in a second
+	// (e.g. the tempdir() of the previous R session). So we set something known to exist, here.
+	// On MacOS, we cd to R_HOME, instead, below
 	QFileInfo bfi(backend_executable);
 	backend->setWorkingDirectory(bfi.absolutePath());
+#	ifdef Q_OS_WIN
 	args.append(bfi.fileName());
+#	else
+	args.append("./" + bfi.fileName());
+#	endif
 #else
 	args.append(backend_executable);
 #endif
 
-	args.append ("--debug-level=" + QString::number (RK_Debug::RK_Debug_Level));
+	if (RKSettingsModuleGeneral::rkwardVersionChanged()) args.append(QStringLiteral("--setup"));
+	args.append (QStringLiteral("--debug-level=") + QString::number (RK_Debug::RK_Debug_Level));
 	// NOTE: QProcess quotes its arguments, *but* properly passing all spaces and quotes through the R CMD wrapper, seems near(?) impossible on Windows. Instead, we use percent encoding, internally.
-	args.append ("--server-name=" + server->fullServerName ().toUtf8 ().toPercentEncoding ());
-	args.append ("--rkd-server-name=" + rkd_transmitter->serverName ().toUtf8 ().toPercentEncoding ());
-	args.append ("--data-dir=" + RKSettingsModuleGeneral::filesPath ().toUtf8 ().toPercentEncoding ());
-	args.append ("--locale-dir=" + localeDir ().toUtf8 ().toPercentEncoding ());
+	args.append (QStringLiteral("--server-name=") + server->fullServerName ().toUtf8 ().toPercentEncoding ());
+	args.append (QStringLiteral("--rkd-server-name=") + rkd_transmitter->serverName ().toUtf8 ().toPercentEncoding ());
+	args.append (QStringLiteral("--data-dir=") + RKSettingsModuleGeneral::filesPath ().toUtf8 ().toPercentEncoding ());
+	args.append (QStringLiteral("--locale-dir=") + localeDir ().toUtf8 ().toPercentEncoding ());
 	RK_DO({
 		RK_DEBUG(RBACKEND, DL_DEBUG, "R binary: %s", qPrintable(RKSessionVars::RBinary()));
 		RK_DEBUG(RBACKEND, DL_DEBUG, "%s", qPrintable(args.join("\n")));
@@ -155,13 +294,9 @@ void RKFrontendTransmitter::run () {
 #endif
 	RK_DEBUG(RBACKEND, DL_DEBUG, "Starting backend. Timestamp %d", QDateTime::currentMSecsSinceEpoch(), token.length());
 	if (quirkmode) {
-#if QT_VERSION >= QT_VERSION_CHECK(5,10,0)
 		backend->setProgram(RKSessionVars::RBinary());
 		backend->setArguments(args);
 		backend->startDetached();
-#else
-		QProcess::startDetached(RKSessionVars::RBinary(), args);
-#endif
 	} else {
 		backend->start(RKSessionVars::RBinary(), args, QIODevice::ReadOnly);
 
@@ -237,28 +372,28 @@ void RKFrontendTransmitter::requestReceived (RBackendRequest* request) {
 
 			if (handleOutput (out->output, out->output.length (), out->type)) {
 				RKRBackendEvent* event = new RKRBackendEvent (new RBackendRequest (false, RBackendRequest::OutputStartedNotification));
-				qApp->postEvent (RKRBackendProtocolFrontend::instance (), event);
+				qApp->postEvent(frontend, event);
 			}
 
 			delete (out);
 		}
 		delete list;
-		request->output = 0;
+		request->output = nullptr;
 		RK_ASSERT (request->synchronous);
 		writeRequest (request);	// to tell the backend, that we are keeping up. Also deletes the request.
 		return;
 	}
 
 	RKRBackendEvent* event = new RKRBackendEvent (request);
-	qApp->postEvent (RKRBackendProtocolFrontend::instance (), event);
+	qApp->postEvent(frontend, event);
 }
 
 void RKFrontendTransmitter::backendExit (int exitcode) {
 	RK_TRACE (RBACKEND);
 
-	if (!exitcode && token.isEmpty ()) handleTransmissionError (i18n ("The backend process could not be started. Please check your installation."));
-	else if (token.isEmpty ()) handleTransmissionError (i18n ("The backend process failed to start with exit code %1, message: '%2'.", exitcode, QString::fromLocal8Bit(backend->readAllStandardError())));
-	else handleTransmissionError (i18n ("Backend process has exited with code %1, message: '%2'.", exitcode, QString::fromLocal8Bit(backend->readAllStandardError())));
+	if (!exitcode && token.isEmpty()) handleTransmissionError(i18n("The backend process could not be started. Please check your installation."));
+	else if (token.isEmpty()) handleTransmissionError(i18n("The backend process failed to start with exit code %1, message: '%2'.", exitcode, QString::fromLocal8Bit(backend->readAllStandardError().replace('\n', "<br>"))));
+	else handleTransmissionError(i18n("Backend process has exited with code %1, message: '%2'.", exitcode, QString::fromLocal8Bit(backend->readAllStandardError().replace('\n', "<br>"))));
 }
 
 void RKFrontendTransmitter::writeRequest (RBackendRequest *request) {
@@ -276,7 +411,7 @@ void RKFrontendTransmitter::handleTransmissionError (const QString &message) {
 	RBackendRequest* req = new RBackendRequest (false, RBackendRequest::BackendExit);
 	req->params["message"] = message;
 	RKRBackendEvent* event = new RKRBackendEvent (req);
-	qApp->postEvent (RKRBackendProtocolFrontend::instance (), event);
+	qApp->postEvent(frontend, event);
 
 	exit ();
 }
