@@ -14,11 +14,12 @@ class QProcess;
 class QIODevice;
 class QLocalServer;
 class RKGraphicsDeviceFrontendTransmitter;
+class RKRBackendProtocolFrontend;
 
 class RKFrontendTransmitter : public RKAbstractTransmitter, public RKROutputBuffer {
 Q_OBJECT
 public:
-	RKFrontendTransmitter ();
+	RKFrontendTransmitter(RKRBackendProtocolFrontend *frontend);
 	~RKFrontendTransmitter ();
 
 	void run () override;
@@ -32,7 +33,7 @@ public:
 	/** Simple convenience function similar to QIODevice::waitForReadyRead(), but waiting for a full line to be available.
 	    In particular on Windows, we often receive _less_ than a full line per chunk. */
 	static QString waitReadLine (QIODevice *con, int msecs);
-private slots:
+private Q_SLOTS:
 	void connectAndEnterLoop ();
 	void backendExit (int exitcode);
 private:
@@ -41,7 +42,11 @@ private:
 	bool quirkmode;
 	QProcess* backend;
 	QLocalServer* server;
+	RKRBackendProtocolFrontend* frontend;
 	RKGraphicsDeviceFrontendTransmitter* rkd_transmitter;
+
+	QString resolveRSpecOrFail(QString input);
+	void detectAndCheckRBinary();
 };
 
 #endif
