@@ -31,19 +31,15 @@ public:
 		BackendExit,
 		ShowMessage,
 		ShowFiles,
-		ChooseFile,
 		EditFiles,
-		ReadLine,      // 5
+		ReadLine,      // 4
 		CommandOut,                  /**< Request the next command, and notify about the result of the previus. TODO split. */
 		Started,
-		EvalRequest,
-		CallbackRequest,
-		GenericRequestWithSubcommands,   // 10
-		PlainGenericRequest,
+		RCallRequest,   // 7
 		SetParamsFromBackend,
 		Debugger,
 		CommandLineIn,	/**< The next line of the current user command has been submitted in the backend. */
-		Output,		/**< A piece of output. Note: If the backend runs in a single process, output is handled in a pull fashion, instead of using requests. */  //15
+		Output,		/**< A piece of output. Note: If the backend runs in a single process, output is handled in a pull fashion, instead of using requests. */  //11
 		Interrupt,	/**< Interrupt evaluation. This request type originates in the frontend, not the backend. */
 		PriorityCommand, /**< Send a command to be run during R's event processing. This request type originates in the frontend, not the backend. */
 		OutputStartedNotification, /**< Only used in the frontend: Notification that a new bit of output has arrived. Used to trigger flushing after a timeout. */
@@ -55,13 +51,13 @@ public:
 
 	RCommandProxy *takeCommand () {
 		RCommandProxy* ret = command;
-		command = 0;
+		command = nullptr;
 		return ret;
 	}
 
 	ROutputList *takeOutput () {
 		ROutputList* ret = output;
-		output = 0;
+		output = nullptr;
 		return ret;
 	}
 
@@ -103,7 +99,7 @@ public:
 	enum EventType {
 		RKWardEvent = QEvent::User + 1
 	};
-	explicit RKRBackendEvent (RBackendRequest* data=0) : QEvent ((QEvent::Type) RKWardEvent) { _data = data; };
+	explicit RKRBackendEvent(RBackendRequest* data=nullptr) : QEvent((QEvent::Type) RKWardEvent) { _data = data; };
 	~RKRBackendEvent () {};
 
 	RBackendRequest* data () { return _data; };
