@@ -1,6 +1,6 @@
 /*
 rkrinterface.h - This file is part of the RKWard project. Created: Fri Nov 1 2002
-SPDX-FileCopyrightText: 2002-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2002-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,6 +17,7 @@ class RCommand;
 class RKWardMainWindow;
 class RKRBackend;
 class RBackendRequest;
+class RKRBackendProtocolFrontend;
 
 /** This class provides the main interface to the R-processor.
 
@@ -49,10 +50,10 @@ public:
 		RCommand *c = new RCommand(QString(), RCommand::EmptyCommand | RCommand::Sync);
 		c->whenFinished(receiver, func);
 		issueCommand(c, chain);
-	};
+	}
 
 /** opens a new command chain. Returns a pointer to the new chain. If you specify a parent, the new chain will be a sub-chain of that chain. */
-	static RCommandChain *startChain(RCommandChain *parent=0);
+	static RCommandChain *startChain(RCommandChain *parent = nullptr);
 /** closes the command chain. The chain (and even its parent, if it is already closed) may be deleted right afterwards! */
 	static void closeChain(RCommandChain *chain);
 
@@ -68,7 +69,7 @@ not be interrupted. */
 	void pauseProcessing (bool pause);
 
 /** returns the command currently running in the thread. Be careful when using the returned pointer! */
-	RCommand *runningCommand () const { return (all_current_commands.isEmpty () ? 0 : all_current_commands.last ()); };
+	RCommand *runningCommand () const { return (all_current_commands.isEmpty () ? nullptr : all_current_commands.last ()); };
 
 	enum RStatus {
 		Busy,
@@ -78,12 +79,19 @@ not be interrupted. */
 	};
 
 	bool backendIsDead () const { return backend_dead; };
+/** implies backendIsDead() */
+	bool backendFailedToStart() const { return (backend_dead && !backend_started); }
 	bool backendIsIdle ();
 	static bool isNaReal (double value) { return na_real == value; };
 	static bool isNaInt (int value) { return na_int == value; };
+	struct BackendError{
+		QString title;
+		QString id;
+		QString message;
+		QString details;
+	};
+	BackendError backendError() const { return backend_error; };
 private:
-	void timerEvent (QTimerEvent *) override;
-	int flush_timer_id;
 /** Calls RThread::flushOutput(), and takes care of adding the output to all applicable commands */
 	void flushOutput (bool forced);
 /** pointer to the RThread */
@@ -97,9 +105,7 @@ private:
 	} command_logfile_mode;
 
 /** helper function to handle backend requests that (may) involve running additional R-"sub"-commands. TODO; This should probably be merged with processRBackendRequest.*/
-	void processHistoricalSubstackRequest (const QString &call, const QVariant &args, RCommand *parent_command, RBackendRequest *request);
-/** helper function to handle the bulk backend of requests that do not involve running sub-commands */
-	GenericRRequestResult processPlainGenericRequest (const QStringList &calllist);
+	GenericRRequestResult processRCallRequest (const QString &call, const QVariant &args, RCommandChain *in_chain);
 /** helper function to handle backend requests that do not inolve running sub-commands. */
 	void processRBackendRequest (RBackendRequest *request);
 
@@ -107,7 +113,7 @@ private:
 	QList<RCommand*> all_current_commands;
 /** NOTE: processing R events while waiting for the next command may, conceivably, lead to new requests, which may also wait for sub-commands! Thus we keep a simple stack of requests. */
 	QList<RBackendRequest*> command_requests;
-	RBackendRequest* currentCommandRequest () const { return (command_requests.isEmpty () ? 0 : command_requests.last ()); };
+	RBackendRequest* currentCommandRequest () const { return (command_requests.isEmpty () ? nullptr : command_requests.last ()); };
 	void tryNextCommand ();
 	void doNextCommand (RCommand *command);
 	RCommand *popPreviousCommand (int id);
@@ -117,6 +123,7 @@ private:
 	RCommandChain* openSubcommandChain (RCommand *parent_command);
 	QList<RCommand *> current_commands_with_subcommands;
 	void closeSubcommandChain (RCommand *parent_command);
+	void reportFatalError();
 
 /** @see locked */
 	enum LockType {
@@ -128,23 +135,25 @@ private:
  * May be an OR'ed combination of several LockType s, but currently, there is only one LockType */
 	int locked;
 
-	QString startup_errors;
+	BackendError backend_error;
 	bool startup_phase2_error;
 	void runStartupCommand(RCommand *command, RCommandChain* chain, std::function<void(RCommand*)> callback);
 	RCommand *dummy_command_on_stack;
 friend class RKRBackendProtocolFrontend;
 	bool backend_dead;
+	bool backend_started;
 	static double na_real;
 	static int na_int;
+	RKRBackendProtocolFrontend *backendprotocol;
 friend class RKWardMainWindow;
 friend class RCommand;
 protected:
 	void handleRequest (RBackendRequest *request);
 	static RInterface *_instance;
-	void _issueCommand(RCommand *command, RCommandChain *chain=0);
+	void _issueCommand(RCommand *command, RCommandChain *chain = nullptr);
 /** constructor */
 	RInterface();
-signals:
+Q_SIGNALS:
 	void backendWorkdirChanged();
 /** Note: status is actually RInterface::RStatus */
 	void backendStatusChanged(int new_status);
