@@ -15,8 +15,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "rdata.h"
 
-#define R_NO_REMAP 1
-#include <Rdefines.h>
+#include "rkrapi.h"
 
 /** Convenience functions for working with R. */
 namespace RKRSupport {
@@ -34,6 +33,15 @@ namespace RKRSupport {
 	int SEXPToInt (SEXP from_exp, int def_value = INT_MIN);
 	RData::RealStorage SEXPToRealArray (SEXP from_exp);
 	RData* SEXPToRData (SEXP from_exp);
+
+	/** Replacement for BEGIN_SUSPEND_INTERRUPTS-macro that we cannot easily use */
+	class InterruptSuspension {
+	public:
+		InterruptSuspension() { old_susp = ROb(R_interrupts_suspended); }
+		~InterruptSuspension() { ROb(R_interrupts_suspended) = old_susp; if(ROb(R_interrupts_pending)) RFn::Rf_onintr(); }
+	private:
+		Rboolean old_susp;
+	};
 };
 
 class RKRShadowEnvironment {
@@ -58,4 +66,19 @@ private:
 	static SEXP shadowenvbase;
 };
 
+class RKTextCodec {
+public:
+	static QString fromNative(const QByteArray& buf) {
+		return QString::fromUtf8(doConv(from_native, buf));
+	}
+	static QByteArray toNative(const QString& buf) {
+		return doConv(to_native, buf.toUtf8());
+	}
+	static void reinit();
+private:
+	static QByteArray doConv(void *cd, const QByteArray &inp);
+	static void *from_native;
+	static void *to_native;
+};
+
 #endif
