@@ -23,14 +23,14 @@ RKStructureGetter::RKStructureGetter (bool keep_evalled_promises) {
 	RKStructureGetter::keep_evalled_promises = keep_evalled_promises;
 	num_prefetched_funs = 0;
 
-	meta_attrib = Rf_install (".rk.meta");
-	PROTECT (meta_attrib);
-	RK_ASSERT (!Rf_isNull (meta_attrib));
+	meta_attrib = RFn::Rf_install (".rk.meta");
+	RFn::Rf_protect (meta_attrib);
+	RK_ASSERT (!RFn::Rf_isNull (meta_attrib));
 
 	class_fun = prefetch_fun ("class");
 	get_meta_fun = prefetch_fun (".rk.get.meta", false);
 
-// Why do we need all these? Because the is.xxx functions may do an internal dispatch, that we do not want to miss, but don't easily get by e.g. calling Rf_isFunction() directly.
+// Why do we need all these? Because the is.xxx functions may do an internal dispatch, that we do not want to miss, but don't easily get by e.g. calling RFn::Rf_isFunction() directly.
 	is_matrix_fun = prefetch_fun ("is.matrix");
 	is_array_fun = prefetch_fun ("is.array");
 	is_list_fun = prefetch_fun ("is.list");
@@ -52,20 +52,20 @@ RKStructureGetter::RKStructureGetter (bool keep_evalled_promises) {
 RKStructureGetter::~RKStructureGetter () {
 	RK_TRACE (RBACKEND);
 
-	UNPROTECT (num_prefetched_funs + 1); /* all the pre-resolved functions and the meta attribute */
+	RFn::Rf_unprotect (num_prefetched_funs + 1); /* all the pre-resolved functions and the meta attribute */
 }
 
 SEXP RKStructureGetter::prefetch_fun (const char *name, bool from_base) {
 	SEXP ret;
 
 	if (from_base) {
-		ret = Rf_install (name);
+		ret = RFn::Rf_install (name);
 	} else {
-		ret = Rf_findFun (Rf_install (name), R_GlobalEnv);
+		ret = RFn::Rf_findFun (RFn::Rf_install (name), ROb(R_GlobalEnv));
 	}
 
-	PROTECT (ret);
-	RK_ASSERT (!Rf_isNull (ret));
+	RFn::Rf_protect (ret);
+	RK_ASSERT (!RFn::Rf_isNull (ret));
 	++num_prefetched_funs;
 
 	return (ret);
@@ -77,26 +77,26 @@ RData *RKStructureGetter::getStructure (SEXP toplevel, SEXP name, SEXP envlevel,
 	QString name_string = RKRSupport::SEXPToString (name);
 
 	// resolve namespace, if needed
-	if (Rf_isNull (namespacename)) {
+	if (RFn::Rf_isNull (namespacename)) {
 		with_namespace = false;
 	} else {
-		SEXP as_ns_fun = Rf_findFun (Rf_install (".rk.try.get.namespace"),  R_GlobalEnv);
-		PROTECT (as_ns_fun);
-		RK_ASSERT (!Rf_isNull (as_ns_fun));
+		SEXP as_ns_fun = RFn::Rf_findFun (RFn::Rf_install (".rk.try.get.namespace"),  ROb(R_GlobalEnv));
+		RFn::Rf_protect (as_ns_fun);
+		RK_ASSERT (!RFn::Rf_isNull (as_ns_fun));
 
-		namespace_envir = RKRSupport::callSimpleFun (as_ns_fun, namespacename, R_GlobalEnv);
-		with_namespace = !Rf_isNull (namespace_envir);
-		UNPROTECT (1);	/* as_ns_fun */
+		namespace_envir = RKRSupport::callSimpleFun (as_ns_fun, namespacename, ROb(R_GlobalEnv));
+		with_namespace = !RFn::Rf_isNull (namespace_envir);
+		RFn::Rf_unprotect (1);	/* as_ns_fun */
 	}
 
-	if (with_namespace) PROTECT (namespace_envir);
+	if (with_namespace) RFn::Rf_protect (namespace_envir);
 
 	RData *ret = new RData;
 
 	toplevel_value = toplevel;
-	getStructureSafe (toplevel, name_string, 0, ret, INTEGER (envlevel)[0]);
+	getStructureSafe (toplevel, name_string, 0, ret, RFn::INTEGER(envlevel)[0]);
 
-	if (with_namespace) UNPROTECT (1);	/* namespace_envir */
+	if (with_namespace) RFn::Rf_unprotect (1);	/* namespace_envir */
 
 	return ret;
 }
@@ -112,12 +112,12 @@ void RKStructureGetter::getStructureSafe (SEXP value, const QString &name, int a
 	args.getter = this;
 	args.nesting_depth = nesting_depth;
 
-	Rboolean ok = R_ToplevelExec ((void (*)(void*)) getStructureWrapper, &args);
+	Rboolean ok = RFn::R_ToplevelExec((void (*)(void*)) getStructureWrapper, &args);
 
 	if (ok != TRUE) {
 		storage->discardData();
-		Rf_warning ("failure to get object %s", name.toLatin1().data ());
-		getStructureWorker (R_NilValue, name, add_type_flags, storage, nesting_depth);
+		RFn::Rf_warning("failure to get object %s", name.toLatin1().data ());
+		getStructureWorker(ROb(R_NilValue), name, add_type_flags, storage, nesting_depth);
 	}
 }
 
@@ -136,23 +136,23 @@ SEXP RKStructureGetter::resolvePromise (SEXP from) {
 	RK_TRACE (RBACKEND);
 
 	SEXP ret = from;
-	if (TYPEOF (from) == PROMSXP) {
-		ret = PRVALUE(from);
-		if (ret == R_UnboundValue) {
-			RK_DEBUG (RBACKEND, DL_DEBUG, "temporarily resolving unbound promise");
+	if (RFn::TYPEOF (from) == PROMSXP) {
+		ret = RFn::PRVALUE(from);
+		if (ret == ROb(R_UnboundValue)) {
+			RK_DEBUG(RBACKEND, DL_TRACE, "temporarily resolving unbound promise");
 
-			PROTECT (from);
+			RFn::Rf_protect(from);
 			//SET_PRSEEN(from, 1);  // NOTE: SET_PRSEEN was removed from Rinternals.h in R 4.2.0. Its only use is to prevent recursion, however.
 			                        //       Not setting it from here, only means, any recursion will be detected one level later.
-			ret = Rf_eval(PRCODE(from), PRENV(from));
+			ret = RFn::Rf_eval(RFn::PRCODE(from), RFn::PRENV(from));
 			//SET_PRSEEN(from, 0);
 			if (keep_evalled_promises) {
-				SET_PRVALUE(from, ret);
-				SET_PRENV(from, R_NilValue);
+				RFn::SET_PRVALUE(from, ret);
+				RFn::SET_PRENV(from, ROb(R_NilValue));
 			}
-			UNPROTECT (1);
+			RFn::Rf_unprotect (1);
 
-			RK_DEBUG (RBACKEND, DL_DEBUG, "resolved type is %d", TYPEOF (ret));
+			RK_DEBUG(RBACKEND, DL_TRACE, "resolved type is %d", RFn::TYPEOF(ret));
 		}
 	}
 
@@ -170,17 +170,17 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 	bool no_recurse = (nesting_depth >= 2);	// TODO: should be configurable
 	unsigned int type = 0;
 
-	RK_DEBUG (RBACKEND, DL_DEBUG, "fetching '%s': %p, s-type %d", name.toLatin1().data(), val, TYPEOF (val));
+	RK_DEBUG(RBACKEND, DL_TRACE, "fetching '%s': %p, s-type %d", name.toLatin1().data(), val, RFn::TYPEOF (val));
 
 	SEXP value = val;
 	PROTECT_INDEX value_index;
-	PROTECT_WITH_INDEX (value, &value_index);
+	RFn::R_ProtectWithIndex (value, &value_index);
 	// manually resolve any promises
-	REPROTECT (value = resolvePromise (value), value_index);
+	RFn::R_Reprotect (value = resolvePromise (value), value_index);
 
-	bool is_s4 = Rf_isS4 (value);
-	SEXP baseenv = R_BaseEnv;
-	if (is_s4) baseenv = R_GlobalEnv;
+	bool is_s4 = RFn::Rf_isS4 (value);
+	SEXP baseenv = ROb(R_BaseEnv);
+	if (is_s4) baseenv = ROb(R_GlobalEnv);
 
 	// first field: get name
 	RData *namedata = new RData;
@@ -190,32 +190,32 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 	SEXP classes_s;
 	QStringList classes;
 
-	if ((TYPEOF (value) == LANGSXP) || (TYPEOF (value) == SYMSXP) || (TYPEOF (value) == BCODESXP)) {	// if it's a call, we should NEVER send it through eval
+	if ((RFn::TYPEOF (value) == LANGSXP) || (RFn::TYPEOF (value) == SYMSXP) || (RFn::TYPEOF (value) == BCODESXP)) {	// if it's a call, we should NEVER send it through eval
 		// stripped down and adjusted from R_data_class
-		PROTECT (classes_s = Rf_getAttrib (value, R_ClassSymbol));
-		if (Rf_length (classes_s)) classes = RKRSupport::SEXPToStringList(classes_s);
-		UNPROTECT (1);
+		RFn::Rf_protect(classes_s = RFn::Rf_getAttrib(value, ROb(R_ClassSymbol)));
+		if (RFn::Rf_length(classes_s)) classes = RKRSupport::SEXPToStringList(classes_s);
+		RFn::Rf_unprotect(1);
 		if (classes.isEmpty ()) {
-			if (TYPEOF (value) == LANGSXP) {
-				SEXP symb = PROTECT (CAR (value));
+			if (RFn::TYPEOF (value) == LANGSXP) {
+				SEXP symb = RFn::Rf_protect (RFn::CAR (value));
 				QString cl;
-				if (TYPEOF (symb) == SYMSXP) cl = CHAR (PRINTNAME (symb));
-				UNPROTECT (1);
+				if (RFn::TYPEOF (symb) == SYMSXP) cl = RFn::R_CHAR(RFn::PRINTNAME (symb));
+				RFn::Rf_unprotect (1);
 				if ((cl != "if") && (cl != "while") && (cl != "for") && (cl != "=") && (cl != "<-") && (cl != "(") && (cl != "{")) cl = "call";
 				classes = QStringList (cl);
-                        } else if (TYPEOF (value) == BCODESXP) {
-				value = R_NilValue;   // This is a bit lame, but bytecode cannot be cast to expression, below, and no idea what else to do with it (or what info to extract, anyway)
+                        } else if (RFn::TYPEOF (value) == BCODESXP) {
+				value = ROb(R_NilValue);   // This is a bit lame, but bytecode cannot be cast to expression, below, and no idea what else to do with it (or what info to extract, anyway)
 				classes = QStringList("bytecode");
 			} else {
 				classes = QStringList ("name");
 			}
 		}
 
-		REPROTECT (value = Rf_coerceVector (value, EXPRSXP), value_index);	// make sure the object is safe for everything to come
+		RFn::R_Reprotect (value = RFn::Rf_coerceVector (value, EXPRSXP), value_index);	// make sure the object is safe for everything to come
 	} else {
-		PROTECT (classes_s = RKRSupport::callSimpleFun (class_fun, value, baseenv));
+		RFn::Rf_protect (classes_s = RKRSupport::callSimpleFun (class_fun, value, baseenv));
 		classes = RKRSupport::SEXPToStringList (classes_s);
-		UNPROTECT (1);
+		RFn::Rf_unprotect (1);
 	}
 
 	// store classes
@@ -265,11 +265,11 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 
 	// get meta data, if any
 	RData *metadata = new RData;
-	if (!Rf_isNull (Rf_getAttrib (value, meta_attrib))) {
-		SEXP meta_s = RKRSupport::callSimpleFun (get_meta_fun, value, R_GlobalEnv);
-		PROTECT (meta_s);
+	if (!RFn::Rf_isNull (RFn::Rf_getAttrib (value, meta_attrib))) {
+		SEXP meta_s = RKRSupport::callSimpleFun (get_meta_fun, value, ROb(R_GlobalEnv));
+		RFn::Rf_protect (meta_s);
 		metadata->setData (RKRSupport::SEXPToStringList (meta_s));
-		UNPROTECT (1);	/* meta_s */
+		RFn::Rf_unprotect (1);	/* meta_s */
 	} else {
 		metadata->setData (QStringList ());
 	}
@@ -277,19 +277,19 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 	// get dims
 	RData::IntStorage dims;
 	SEXP dims_s = RKRSupport::callSimpleFun (dims_fun, value, baseenv);
-	if (Rf_isNumeric (dims_s)) {
+	if (RFn::Rf_isNumeric (dims_s)) {
 		dims = RKRSupport::SEXPToIntArray (dims_s);
 	} else {
-		unsigned int len = Rf_length (value);
+		unsigned int len = RFn::Rf_length (value);
 		if ((len < 2) && (!is_function)) {		// suspicious. Maybe some kind of list
 			SEXP len_s = RKRSupport::callSimpleFun (length_fun, value, baseenv);
-			PROTECT (len_s);
-			if (Rf_isNull (len_s)) {
+			RFn::Rf_protect (len_s);
+			if (RFn::Rf_isNull (len_s)) {
 				dims.append (len);
 			} else {
 				dims = RKRSupport::SEXPToIntArray (len_s);
 			}
-			UNPROTECT (1); /* len_s */
+			RFn::Rf_unprotect (1); /* len_s */
 		} else {
 			dims.append (len);
 		}
@@ -307,13 +307,13 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 			type |= RObject::Incomplete;
 			RK_DEBUG (RBACKEND, DL_DEBUG, "Depth limit reached. Will not recurse into slots of %s", name.toLatin1().data ());
 		} else {
-			RData::RDataStorage dummy (1, 0);
+			RData::RDataStorage dummy(1, nullptr);
 			dummy[0] = new RData ();
 
-			SEXP slots_pseudo_object = RKRSupport::callSimpleFun (rk_get_slots_fun, value, R_GlobalEnv);
-			PROTECT (slots_pseudo_object);
+			SEXP slots_pseudo_object = RKRSupport::callSimpleFun (rk_get_slots_fun, value, ROb(R_GlobalEnv));
+			RFn::Rf_protect (slots_pseudo_object);
 			getStructureSafe (slots_pseudo_object, "SLOTS", RObject::PseudoObject, dummy[0], nesting_depth);	// do not increase depth for this pseudo-object
-			UNPROTECT (1);
+			RFn::Rf_unprotect (1);
 
 			slotsdata->setData (dummy);
 		}
@@ -330,7 +330,7 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 	} else if (is_function) {
 		storage_length = RObject::StorageSizeBasicInfo + 2;
 	}
-	RData::RDataStorage res (storage_length, 0);
+	RData::RDataStorage res(storage_length, nullptr);
 	res[RObject::StoragePositionName] = namedata;
 	res[RObject::StoragePositionType] = typedata;
 	res[RObject::StoragePositionClass] = classdata;
@@ -346,13 +346,13 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 		// fetch list of child names
 		SEXP childnames_s;
 		if (do_env) {
-			childnames_s = R_lsInternal3(value, TRUE, FALSE);
+			childnames_s = RFn::R_lsInternal3(value, TRUE, FALSE);
 		} else if (do_cont) {
 			childnames_s = RKRSupport::callSimpleFun (names_fun, value, baseenv);
 		} else {
-			childnames_s = R_NilValue; // dummy
+			childnames_s = ROb(R_NilValue); // dummy
 		}
-		PROTECT (childnames_s);
+		RFn::Rf_protect (childnames_s);
 		QStringList childnames = RKRSupport::SEXPToStringList (childnames_s);
 		int childcount = childnames.size ();
 		if (childcount > NAMED_CHILDREN_LIMIT) {
@@ -360,63 +360,55 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 			childcount = NAMED_CHILDREN_LIMIT;
 		}
 
-		RData::RDataStorage children (childcount, 0);
+		RData::RDataStorage children(childcount, nullptr);
 		for (int i = 0; i < childcount; ++i) {
 			children[i] = new RData ();		// NOTE: RData-ctor pre-initializes these to empty. Thus, we're safe even if there is an error while fetching one of the children.
 		}
 
 		if (do_env) {
 			RK_DEBUG (RBACKEND, DL_DEBUG, "recurse into environment %s", name.toLatin1().data ());
-			if (!Rf_isEnvironment (value)) {
+			if (!RFn::Rf_isEnvironment (value)) {
 				// some classes (ReferenceClasses) are identified as environments by is.environment(), but are not internally ENVSXPs.
-				// For these, Rf_findVar would fail.
-				REPROTECT (value = RKRSupport::callSimpleFun (as_environment_fun, value, R_GlobalEnv), value_index);
+				// For these, RFn::Rf_findVar would fail.
+				RFn::R_Reprotect (value = RKRSupport::callSimpleFun (as_environment_fun, value, ROb(R_GlobalEnv)), value_index);
 			}
 			for (int i = 0; i < childcount; ++i) {
-				SEXP current_childname = Rf_install(CHAR(STRING_ELT(childnames_s, i)));		// ??? Why does simply using STRING_ELT(childnames_i, i) crash?
-				PROTECT (current_childname);
-				SEXP child = Rf_findVar (current_childname, value);
-				PROTECT (child);
+				SEXP current_childname = RFn::Rf_install(RFn::R_CHAR(RFn::STRING_ELT(childnames_s, i)));		// ??? Why does simply using RFn::STRING_ELT(childnames_i, i) crash?
+				RFn::Rf_protect (current_childname);
+				SEXP child = RFn::Rf_findVar (current_childname, value);
+				RFn::Rf_protect (child);
 
-				bool child_misplaced = false;
-				if (at_toplevel && with_namespace && (!RKRBackend::this_pointer->RRuntimeIsVersion (2, 14, 0))) {
-					if (!Rf_isNull (namespace_envir)) {
-						SEXP dummy = Rf_findVarInFrame (namespace_envir, current_childname);
-						if (Rf_isNull (dummy) || (dummy == R_UnboundValue)) child_misplaced = true;
-					}
-				}
-
-				getStructureSafe (child, childnames[i], child_misplaced ? RObject::Misplaced : 0, children[i], nesting_depth + 1);
-				UNPROTECT (2); /* current_childname, child */
+				getStructureSafe (child, childnames[i], 0, children[i], nesting_depth + 1);
+				RFn::Rf_unprotect (2); /* current_childname, child */
 			}
 		} else if (do_cont) {
 			RK_DEBUG (RBACKEND, DL_DEBUG, "recurse into list %s", name.toLatin1().data ());
 			// fewer elements than names() can happen, although I doubt it is supposed to happen.
 			// see http://sourceforge.net/p/rkward/bugs/67/
-			bool may_be_special = Rf_length (value) < childcount;
-			if (Rf_isList (value) && (!may_be_special)) {		// old style list
+			bool may_be_special = RFn::Rf_length (value) < childcount;
+			if (RFn::Rf_isList (value) && (!may_be_special)) {		// old style list
 				for (int i = 0; i < childcount; ++i) {
-					SEXP child = CAR (value);
+					SEXP child = RFn::CAR (value);
 					getStructureSafe (child, childnames[i], 0, children[i], nesting_depth + 1);
-					CDR (value);
+					RFn::CDR (value);
 				}
-			} else if (Rf_isNewList (value) && (!may_be_special)) {				// new style list
+			} else if (RFn::Rf_isNewList (value) && (!may_be_special)) {				// new style list
 				for (int i = 0; i < childcount; ++i) {
-					SEXP child = VECTOR_ELT(value, i);
+					SEXP child = RFn::VECTOR_ELT(value, i);
 					getStructureSafe (child, childnames[i], 0, children[i], nesting_depth + 1);
 				}
 			} else {		// probably an S4 object disguised as a list
-				SEXP index = Rf_allocVector(INTSXP, 1);
-				PROTECT (index);
+				SEXP index = RFn::Rf_allocVector(INTSXP, 1);
+				RFn::Rf_protect (index);
 				for (int i = 0; i < childcount; ++i) {
-					INTEGER (index)[0] = (i + 1);
+					RFn::INTEGER(index)[0] = (i + 1);
 					SEXP child = RKRSupport::callSimpleFun2 (double_brackets_fun, value, index, baseenv);
 					getStructureSafe (child, childnames[i], 0, children[i], nesting_depth + 1);
 				}
-				UNPROTECT (1); /* index */
+				RFn::Rf_unprotect (1); /* index */
 			}
 		}
-		UNPROTECT (1);   /* childnames_s */
+		RFn::Rf_unprotect (1);   /* childnames_s */
 
 		RData *childdata = new RData;
 		childdata->setData (children);
@@ -429,7 +421,7 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 				type |= RObject::Incomplete;
 				RK_DEBUG (RBACKEND, DL_DEBUG, "Depth limit reached. Will not recurse into namespace of %s", name.toLatin1().data ());
 			} else {
-				RData::RDataStorage dummy (1, 0);
+				RData::RDataStorage dummy(1, nullptr);
 				dummy[0] = new RData ();
 
 				getStructureSafe (namespace_envir, "NAMESPACE", RObject::PseudoObject, dummy[0], nesting_depth+99);	// HACK: By default, do not recurse into the children of the namespace, until dealing with the namespace object itself.
@@ -442,37 +434,37 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 	} else if (is_function) {
 // TODO: getting the formals is still a bit of a bottleneck, but no idea, how to improve on this, any further
 		SEXP formals_s;
-		if (Rf_isPrimitive (value)) formals_s = FORMALS (RKRSupport::callSimpleFun (args_fun, value, baseenv));	// primitives don't have formals, internally
-		else formals_s = FORMALS (value);
-		PROTECT (formals_s);
+		if (RFn::Rf_isPrimitive (value)) formals_s = RFn::FORMALS (RKRSupport::callSimpleFun (args_fun, value, baseenv));	// primitives don't have formals, internally
+		else formals_s = RFn::FORMALS (value);
+		RFn::Rf_protect (formals_s);
 
 		// get the default values
 		QStringList formals = RKRSupport::SEXPToStringList (formals_s);
 		// for the most part, the implicit as.character in SEXPToStringList does a good on the formals (and it's the fastest of many options that I have tried).
 		// Only for naked strings (as in 'function (a="something")'), we're missing the quotes. So we add quotes, after conversion, as needed:
 		SEXP dummy = formals_s;
-		const int formals_len = Rf_length (formals_s);
+		const int formals_len = RFn::Rf_length (formals_s);
 		for (int i = 0; i < formals_len; ++i) {
-			if (TYPEOF (CAR (dummy)) == STRSXP) formals[i] = RKRSharedFunctionality::quote (formals[i]);
-			dummy = CDR (dummy);
+			if (RFn::TYPEOF (RFn::CAR (dummy)) == STRSXP) formals[i] = RKRSharedFunctionality::quote (formals[i]);
+			dummy = RFn::CDR (dummy);
 		}
 		RData *funargvaluesdata = new RData;
 		funargvaluesdata->setData (formals);
 
 		// the argument names
-		SEXP names_s = Rf_getAttrib (formals_s, R_NamesSymbol);
-		PROTECT (names_s);
+		SEXP names_s = RFn::Rf_getAttrib (formals_s, ROb(R_NamesSymbol));
+		RFn::Rf_protect (names_s);
 		RData *funargsdata = new RData;
 		funargsdata->setData (RKRSupport::SEXPToStringList (names_s));
 
-		UNPROTECT (2); /* names_s, formals_s */
+		RFn::Rf_unprotect (2); /* names_s, formals_s */
 
 		res[RObject::StoragePositionFunArgs] = funargsdata;
 		res[RObject::StoragePositionFunValues] = funargvaluesdata;
 	}
 
-	UNPROTECT (1); /* value */
+	RFn::Rf_unprotect (1); /* value */
 
-	RK_ASSERT (!res.contains (0));
+	RK_ASSERT (!res.contains (nullptr));
 	storage->setData (res);
 }
