@@ -263,12 +263,13 @@ void RKAbstractTransmitter::setConnection (QLocalSocket *_connection) {
 	connect (connection, &QLocalSocket::disconnected, this, &RKAbstractTransmitter::disconnected);
 
 	// In case something is pending already.
-	if (connection->bytesAvailable ()) QTimer::singleShot (0, this, SLOT (fetchTransmission()));
+	if (connection->bytesAvailable ()) QTimer::singleShot(0, this, &RKAbstractTransmitter::fetchTransmission);
 }
 
 void RKAbstractTransmitter::disconnected () {
 	RK_TRACE (RBACKEND);
 
+	if (!connection) return;  // -> May happen in RKRBackendTransmitter::doExit()
 	handleTransmissionError ("Connection closed unexpectedly. Last error was: " + connection->errorString ());
 }
 
