@@ -1,3 +1,7 @@
+# - This file is part of the RKWard project (https://rkward.kde.org).
+# SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+# SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+# SPDX-License-Identifier: GPL-2.0-or-later
 #' RKWard file names
 #' 
 #' In RKWard the output is saved as a html file which is located at "~/.rkward"
@@ -51,7 +55,7 @@
 #'            placed next to x, with file name extension ".css". Only effective when initializing a
 #'            (non-existing) output file.
 #' @param silent Set to true to avoid the output window being raised in the frontend.
-#' @param flush.images. If true, any images used in the output file will be deleted as well.
+#' @param flush.images If true, any images used in the output file will be deleted as well.
 #' @param ask Logical: Whether to ask before flushing the output file.
 #' @param ... Further parameters passed to rk.set.output.html.file()
 #' @return \code{rk.get.tempfile.name}, \code{rk.get.output.html.file}, \code{rk.get.workspace.url}, and
@@ -62,8 +66,9 @@
 #'   \link{rk.print}
 #' @keywords utilities IO
 #' @rdname rk.get.tempfile.name
+#' @export
 #' @examples
-#' 
+#' \dontrun{
 #' testfile.name <- rk.get.tempfile.name(prefix="test", extension=".txt")
 #' testfile <- file(testfile.name)
 #' cat("This is a test\n", file=testfile)
@@ -72,30 +77,28 @@
 #' 
 #' outfile <- rk.get.output.html.file()
 #' 
-#' ## Not run
 #' rk.set.output.html.file("~/.rkward/another_file.html")
 #' rk.header("Output on a different output file")
 #' rk.show.html(rk.get.output.html.file())
 #' rk.flush.output()
 #' rk.set.output.html.file(outfile)
-#' 
-#' @export
+#' }
 "rk.get.tempfile.name" <- function (prefix="image", extension=".jpg", directory=dirname (rk.get.output.html.file ())) {
-	x <- .rk.do.simple.call ("unused.filename", c (prefix, extension, directory))
+	x <- .rk.call.backend("unused.filename", c(prefix, extension, directory))
 	ret <- x[2]
-	names (ret) <- x[1]
+	names(ret) <- x[1]
 	ret
 }
 
 #' @export
-"rk.tempdir" <- function () {
-	.rk.do.simple.call ("tempdir")
+"rk.tempdir" <- function() {
+	.rk.call.backend("tempdir")
 }
 
 #' @export
 #' @rdname rk.get.tempfile.name
 "rk.get.workspace.url" <- function () {
-	res <- .rk.do.plain.call ("getWorkspaceUrl")
+	res <- .rk.call("getWorkspaceUrl")
 	if (length (res)) res
 	else NULL
 }
@@ -103,7 +106,11 @@
 #' @export
 #' @rdname rk.get.tempfile.name
 "rk.home" <- function (component="home") {
-	normalizePath (.rk.do.plain.call ("home", component))
+	if(component %in% c("home", "lib")) {
+		normalizePath(.rk.call.backend("home", component))
+	} else {
+		stop("Unknown component type");
+	}
 }
 
 #' @export
@@ -123,7 +130,14 @@
 	assign (".rk.output.html.file", x, .rk.variables)
 
 	if (!file.exists (x)) {
-		.rk.cat.output (paste ("<?xml version=\"1.0\" encoding=\"", .rk.do.simple.call ("locale.name"), "\"?>\n", sep=""))
+		encoding.name <- function() {
+			li <- l10n_info();
+			if(isTRUE(li$'UTF-8')) return("UTF-8")  # hopefully the most common case, these days
+			if(!is.null(li$codeset)) return(li$codeset)
+			if(!is.null(li$codepage)) return(paste0("windows-", li$codepage))
+			return(tail(strsplit(Sys.getlocale("LC_CTYPE"), ".") ,1))
+		}
+		.rk.cat.output (paste ("<?xml version=\"1.0\" encoding=\"", encoding.name(), "\"?>\n", sep=""))
 		.rk.cat.output ("<html><head>\n<title>RKWard Output</title>\n")
 		if (!is.null (css)) {
 			cssfilename <- paste (sub ("\\.[^.]*$", "", basename (x)), ".css", sep="")
@@ -211,7 +225,7 @@
 	}
 
 	# needs to come after initialization, so initialization alone does not trigger an update during startup
-	.rk.do.plain.call ("set.output.file", c (x, if (isTRUE (silent)) "SILENT" else NULL), synchronous=FALSE)
+	if (!isTRUE(silent)) .rk.call.async("set.output.file", x)
 	invisible (oldfile)
 }
 
