@@ -32,9 +32,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <kmessagebox.h>
 #include <kshellcompletion.h>
 #include <ktexteditor/editor.h>
-#include <ktexteditor/configinterface.h>
-#include <ktexteditor/codecompletioninterface.h>
-#include <ktexteditor/markinterface.h>
 #include <ktexteditor_version.h>
 #include <kxmlguifactory.h>
 #include <kio/filecopyjob.h>
@@ -45,12 +42,12 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "windows/rkhelpsearchwindow.h"
 #include "windows/rkcodecompletion.h"
 #include "windows/rktexthints.h"
+#include "windows/katepluginintegration.h"
 #include "rbackend/rkrinterface.h"
 #include "settings/rksettings.h"
 #include "settings/rksettingsmoduleconsole.h"
 #include "settings/rkrecenturls.h"
 #include "misc/rkcommonfunctions.h"
-#include "misc/rkcompatibility.h"
 #include "misc/rkstandardicons.h"
 #include "misc/rkstandardactions.h"
 #include "core/robjectlist.h"
@@ -59,7 +56,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "debug.h"
 
 // static
-RKConsole* RKConsole::main_console = 0;
+RKConsole* RKConsole::main_console = nullptr;
 
 RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKMDIWindow (parent, RKMDIWindow::ConsoleWindow, tool_window, name), commands_history (false, false) {
 	RK_TRACE (APP);
@@ -67,24 +64,7 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 	QVBoxLayout *layout = new QVBoxLayout (this);
 	layout->setContentsMargins (0, 0, 0, 0);
 
-	// I'd like to have this as a runtime version-check, but for that, I'd have to create a KTextEditor::Editor::instance(), first, and by
-	// that time the katepart has already enumerated its highlighting files, and the hack below would not work (for this session, at least).
-	if (KTEXTEDITOR_VERSION < ((5 << 16) | (16 << 8))) {
-		// Older katepart5 (before 5.16.0) will not accept rkward.xml installed in its own directory (as that has an index.json where
-		// rkward.xml is not included). Thus, we try to sneak in rkward.xml as a local user syntax highlighting file.
-		QDir writable_path = QDir (QDir (QStandardPaths::writableLocation (QStandardPaths::GenericDataLocation)).absoluteFilePath ("katepart5/syntax"));
-		QFileInfo rkwardxml (writable_path.absoluteFilePath ("rkward.xml"));
-		if (!rkwardxml.exists ()) {
-			writable_path.mkpath (".");
-			QFile rkwardxml_up (QStandardPaths::locate (QStandardPaths::GenericDataLocation, "katepart5/syntax/rkward.xml"));
-			rkwardxml_up.copy (rkwardxml.absoluteFilePath ());
-			QFile index_json (writable_path.absoluteFilePath ("index.json"));
-			if (index_json.exists ()) index_json.remove ();
-		}
-	}
-
 	// create a Kate-part as command-editor
-	// KF5 TODO: (How) can we make sure we are getting a katepart, here, not some other implementation. Or can we take that for granted?
 	KTextEditor::Editor* editor = KTextEditor::Editor::instance ();
 	if (!editor) {
 		RK_ASSERT (false);
@@ -93,7 +73,9 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 	}
 
 	doc = editor->createDocument (this);
-	view = doc->createView (this);
+	// even though the R Console is not really a document window, it is important for it to be constructed with a proper main window.
+	// E.g. argument hints don't get the correct window parent, otherwise
+	view = doc->createView (this, RKWardMainWindow::getMain()->katePluginIntegration()->mainWindow ()->mainWindow());
 	layout->addWidget (view);
 	view->setStatusBarEnabled (false);
 	setFocusProxy (view);
@@ -135,11 +117,9 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 	setMetaInfo (shortCaption (), QUrl ("rkward://page/rkward_console"), RKSettings::PageConsole);
 	initializeActivationSignals ();
 	initializeActions (getPart ()->actionCollection ());
-	KTextEditor::ConfigInterface *confint = qobject_cast<KTextEditor::ConfigInterface*> (view);
-	RK_ASSERT(confint);
-	QAction* action = RKSettingsModuleConsole::showMinimap()->makeAction(this, i18n("Scrollbar minimap"), [confint](bool val) { confint->setConfigValue("scrollbar-minimap", val); });
+	QAction* action = RKSettingsModuleConsole::showMinimap()->makeAction(this, i18n("Scrollbar minimap"), [this](bool val) { view->setConfigValue("scrollbar-minimap", val); });
 	getPart()->actionCollection()->addAction("view_show_minimap", action);
-	action = RKSettingsModuleConsole::wordWrap()->makeAction(this, i18n("Dynamic word wrap"), [confint](bool val) { confint->setConfigValue("dynamic-word-wrap", val); });
+	action = RKSettingsModuleConsole::wordWrap()->makeAction(this, i18n("Dynamic word wrap"), [this](bool val) { view->setConfigValue("dynamic-word-wrap", val); });
 	getPart()->actionCollection()->addAction("view_dynamic_word_wrap", action);
 
 	nprefix = "> ";
@@ -152,7 +132,7 @@ RKConsole::RKConsole (QWidget *parent, bool tool_window, const char *name) : RKM
 
 	commands_history.setHistory (RKSettingsModuleConsole::loadCommandHistory ());
 
-	current_command = 0;
+	current_command = nullptr;
 	current_command_displayed_up_to = 0;
 	tab_key_pressed_before = false;
 	previous_chunk_was_piped = false;
@@ -178,8 +158,8 @@ QAction* RKConsole::addProxyAction (const QString& actionName, const QString& la
 	QList<KActionCollection*> acs = view->findChildren<KActionCollection*>();
 	acs.append (view->actionCollection ());
 
-	QAction* found = 0;
-	foreach (KActionCollection* ac, acs) {
+	QAction* found = nullptr;
+	for (KActionCollection* ac : std::as_const(acs)) {
 		found = ac->action (actionName);
 		if (found) break;
 	}
@@ -202,7 +182,7 @@ QAction* RKConsole::addProxyAction (const QString& actionName, const QString& la
 		getPart ()->actionCollection ()->addAction (actionName, ret);
 		return ret;
 	} else {
-		return 0;
+		return nullptr;
 	}
 }
 
@@ -312,7 +292,7 @@ bool RKConsole::handleKeyPress (QKeyEvent *e) {
 		if (modifier == Qt::NoModifier) setCursorClear (para, pos - 1);
 		else if (modifier == Qt::ShiftModifier) triggerEditAction ("select_char_left");
 		else if (modifier == Qt::ControlModifier) triggerEditAction ("word_left");
-		else if (modifier == (Qt::ControlModifier + Qt::ShiftModifier)) triggerEditAction ("select_word_left");
+		else if (modifier == (Qt::ControlModifier | Qt::ShiftModifier)) triggerEditAction ("select_word_left");
 		else return false;
 
 		return true;
@@ -322,7 +302,7 @@ bool RKConsole::handleKeyPress (QKeyEvent *e) {
 		if (modifier == Qt::NoModifier) setCursorClear (para, pos + 1);
 		else if (modifier == Qt::ShiftModifier) triggerEditAction ("select_char_right");
 		else if (modifier == Qt::ControlModifier) triggerEditAction ("word_right");
-		else if (modifier == (Qt::ControlModifier + Qt::ShiftModifier)) triggerEditAction ("select_word_right");
+		else if (modifier == (Qt::ControlModifier | Qt::ShiftModifier)) triggerEditAction ("select_word_right");
 		else return false;
 
 		return true;
@@ -370,18 +350,19 @@ bool RKConsole::eventFilter (QObject *o, QEvent *e) {
 	}
 
 	if ((e->type () == QEvent::KeyPress) || (e->type () == QEvent::Shortcut)) {
-		QKeyEvent *k = (QKeyEvent *)e;
+		QKeyEvent *k = static_cast<QKeyEvent *>(e);
 		return (handleKeyPress (k));
 	} else if (e->type () == QEvent::MouseButtonPress) {
 		// we seem to need this, as the kateview will swallow the contextMenuEvent, otherwise
 		QMouseEvent *m = (QMouseEvent *)e;
 		if (m->button() == Qt::RightButton) {
-			qApp->sendEvent (this, new QContextMenuEvent (QContextMenuEvent::Other, m->globalPos ()));
+			QPoint pos = m->globalPosition().toPoint();
+			qApp->sendEvent(this, new QContextMenuEvent(QContextMenuEvent::Mouse, mapFromGlobal(pos), pos));
 			return (true);
 		}
 	} else if (e->type () == QEvent::MouseButtonRelease){
 		QMouseEvent *m = (QMouseEvent *)e;
-		if (m->button() == Qt::MidButton) {
+		if (m->button() == Qt::MiddleButton) {
 			QClipboard *cb = QApplication::clipboard ();
 			submitBatch (cb->text (QClipboard::Selection));
 			return (true);
@@ -404,7 +385,7 @@ bool RKConsole::eventFilter (QObject *o, QEvent *e) {
 		// We try to map it back to the view, correctly.
 		QWidget *rec = dynamic_cast<QWidget*> (o);
 		if (!o) rec = view;
-		KTextEditor::Cursor pos = view->coordinatesToCursor (rec->mapTo (view, me->pos ()));
+		KTextEditor::Cursor pos = view->coordinatesToCursor(rec->mapTo(view, me->position().toPoint()));
 
 		bool in_last_line = (pos.line () == doc->lines () - 1) && (pos.column () >= prefix.length ());
 		if (!in_last_line) {
@@ -469,7 +450,7 @@ void RKConsole::submitCommand () {
 			last_line_end = 0;
 			RK_ASSERT (false);
 		}
-		command.append(input_buffer.leftRef(last_line_end));
+		command.append(QStringView{input_buffer}.left(last_line_end));
 		if (last_line_end < (input_buffer.size() - 1)) {
 			input_buffer = input_buffer.mid(last_line_end + 1);
 		} else {
@@ -486,6 +467,7 @@ void RKConsole::submitCommand () {
 	skip_command_display_lines = incomplete_command.count ('\n') + 1;	// incomplete command, and first line have already been shown.
 
 	doc->insertLine (doc->lines (), QString ());
+	output_cursor = doc->documentEnd();
 	if (!command.isEmpty ()) {
 		current_command = new RCommand (command, RCommand::User | RCommand::Console);
 		connect(current_command->notifier(), &RCommandNotifier::commandOutput, this, &RKConsole::newOutput);
@@ -533,11 +515,30 @@ void RKConsole::commandsListDown (bool context_sensitive) {
 	else qApp->beep ();
 }
 
+void RKConsole::rawWriteLine(const QString& line, QChar line_end) {
+	int existing_line_length = doc->lineLength(output_cursor.line());
+	if (output_cursor.column() < existing_line_length) {
+		int overwrite_end = qMin(existing_line_length, output_cursor.column() + line.length());
+		doc->removeText(KTextEditor::Range(output_cursor, KTextEditor::Cursor(output_cursor.line(), overwrite_end)));
+	}
+	doc->insertText(output_cursor, line);
+	output_cursor.setColumn(output_cursor.column() + line.length());
+	if (line_end == '\n') {
+		output_cursor.setColumn(doc->lineLength(output_cursor.line()));
+		doc->insertText(output_cursor, "\n");
+		output_cursor.setColumn(0);
+		output_cursor.setLine(output_cursor.line() + 1);
+	} else if (line_end == '\r') {
+		output_cursor.setColumn(0);
+	}
+}
+
 void RKConsole::newOutput (RCommand *command, const ROutput *output) {
 	RK_TRACE (APP);
 
 	int first_line = doc->lines () -1;
 	QString popped_line;
+	// TODO: rewrite utilizing output_cursor;
 	if (!command) {
 		// spontanteous R output, to be inserted _above_ the current command
 		// as a shortcut, we pop the last line, and reinsert in, later
@@ -545,32 +546,24 @@ void RKConsole::newOutput (RCommand *command, const ROutput *output) {
 		doc->removeLine(doc->lines() - 1);
 	}
 
-	// split by and handle carriage returns
-	const QString outstr = output->output;
+	// split by and handle carriage returns (important for progress bars)
+	const QString out = output->output;
+	int string_pos = -1;
 	int start_pos = 0;
-	int end_pos = outstr.size () - 1;
-	QChar c;
-	for (int pos = 0; pos <= end_pos; ++pos) {
-		c = output->output.at (pos);
-		if (c == '\r') {
-			/* NOTE: My first approach was to split the whole string by newlines, and insert each line separately. This allowed for a minor
-			 * optimization when hitting a carriage return (the string before the '\r' could simply be ignored, then), however it caused
-			 * around 10% slowdown when printing large amounts of output.
-			 * Thus, instead, when hitting a CR, we first insert everything before that into the document, then reset the line. */
-			doc->insertText (doc->documentEnd (), outstr.mid (start_pos, pos - start_pos));
-			doc->removeLine (doc->lines () - 1);
-			doc->insertLine (doc->lines (), QString ());
-			start_pos = pos + 1;
+	int end_pos = out.length();
+	while (++string_pos < end_pos) {
+		auto c = out.at(string_pos);
+		if (c == '\n' || c == '\r') {
+			rawWriteLine(out.mid(start_pos, string_pos - start_pos), c);
+			start_pos = string_pos+1;
 		}
 	}
-	if (start_pos <= end_pos) doc->insertText (doc->documentEnd (), outstr.mid (start_pos, end_pos - start_pos + 1));
+	if (start_pos < end_pos) rawWriteLine(out.mid(start_pos, string_pos - start_pos + 1), ' ');
 
 	int end_line = doc->lines () -1;
 	if (output->type != ROutput::Output || (!command)) {
-		KTextEditor::MarkInterface *markiface = qobject_cast<KTextEditor::MarkInterface*> (doc);
-		RK_ASSERT (markiface);
 		for (int line = first_line; line < end_line; ++line) {
-			markiface->addMark (line, command ? KTextEditor::MarkInterface::BreakpointActive : KTextEditor::MarkInterface::BreakpointDisabled);
+			doc->addMark (line, command ? KTextEditor::Document::BreakpointActive : KTextEditor::Document::BreakpointDisabled);
 		}
 	}
 
@@ -581,6 +574,7 @@ void RKConsole::newOutput (RCommand *command, const ROutput *output) {
 // KDE4: does the setUpdatesEnabled (false) still affect performance?
 			view->setUpdatesEnabled (false);		// major performance boost while removing lines!
 			doc->removeText (KTextEditor::Range (0, 0, c - RKSettingsModuleConsole::maxConsoleLines (), 0));
+			output_cursor.setLine(output_cursor.line() - c + RKSettingsModuleConsole::maxConsoleLines());
 			view->setUpdatesEnabled (true);
 		}
 	}
@@ -606,6 +600,7 @@ void RKConsole::userCommandLineIn (RCommand* cmd) {
 	prefix = iprefix;
 	showPrompt ();
 	setCurrentEditingLine (line);
+	output_cursor = doc->documentEnd();
 }
 
 void RKConsole::submitBatch (const QString &batch) {
@@ -618,7 +613,7 @@ void RKConsole::submitBatch (const QString &batch) {
 		int pos = currentCursorPositionInCommand ();
 		if (pos >= 0) {
 			setCurrentEditingLine(line.left(pos));
-			input_buffer.append(line.midRef(pos));
+			input_buffer.append(QStringView{line}.mid(pos));
 		}
 	}
 	if (!current_command) tryNextInBuffer ();
@@ -694,7 +689,7 @@ void RKConsole::userLoadHistory (const QUrl &_url) {
 		if (url.isEmpty ()) return;
 	}
 
-	QTemporaryFile *tmpfile = 0;
+	QTemporaryFile *tmpfile = nullptr;
 	QString filename;
 	if (!url.isLocalFile ()) {
 		tmpfile = new QTemporaryFile (this);
@@ -712,7 +707,7 @@ void RKConsole::userLoadHistory (const QUrl &_url) {
 
 	QFile file (filename);
 	if (!file.open (QIODevice::Text | QIODevice::ReadOnly)) return;
-	setCommandHistory (QString (file.readAll ()).split ('\n', RKCompatibility::SkipEmptyParts()), false);
+	setCommandHistory (QString (file.readAll ()).split ('\n', Qt::SkipEmptyParts), false);
 	file.close ();
 
 	delete (tmpfile);
@@ -745,12 +740,12 @@ QString RKConsole::cleanSelection (const QString &origin) {
 
 	QString ret;
 	ret.reserve (origin.length ());
-	QStringList lines = origin.split ('\n');
-	foreach (const QString& line, lines) {
+	const QStringList lines = origin.split ('\n');
+	for (const QString& line : lines) {
 		if (line.startsWith(nprefix)) {
-			ret.append(line.midRef(nprefix.length()));
+			ret.append(QStringView{line}.mid(nprefix.length()));
 		} else if (line.startsWith(iprefix)) {
-			ret.append(line.midRef(iprefix.length()));
+			ret.append(QStringView{line}.mid(iprefix.length()));
 		} else {
 			ret.append(line);
 		}
@@ -845,35 +840,35 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 	RKStandardActions::copyLinesToOutput (this, this, SLOT (copyLinesToOutput()));
 	RKStandardActions::functionHelp (this, this);
 	RKStandardActions::onlineHelp (this, this);
-	run_selection_action = RKStandardActions::runCurrent (this, this, SLOT (runSelection()));
+	run_selection_action = RKStandardActions::runCurrent(this, this, SLOT (runSelection()));
 
-	interrupt_command_action = ac->addAction ("interrupt", this, SLOT (resetConsole()));
-	interrupt_command_action->setText (i18n ("Interrupt running command"));
-	ac->setDefaultShortcut (interrupt_command_action, REAL_CTRL_KEY + Qt::Key_C);
-	interrupt_command_action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionInterrupt));
-	interrupt_command_action->setEnabled (false);
+	interrupt_command_action = ac->addAction("interrupt", this, &RKConsole::resetConsole);
+	interrupt_command_action->setText(i18n("Interrupt running command"));
+	ac->setDefaultShortcut(interrupt_command_action, REAL_CTRL_KEY | Qt::Key_C);
+	interrupt_command_action->setIcon(RKStandardIcons::getIcon(RKStandardIcons::ActionInterrupt));
+	interrupt_command_action->setEnabled(false);
 
-	copy_literal_action = ac->addAction ("rkconsole_copy_literal", this, SLOT (literalCopy()));
-	ac->setDefaultShortcut (copy_literal_action, REAL_CMD_KEY + Qt::Key_C);
-	copy_literal_action->setText (i18n ("Copy selection literally"));
+	copy_literal_action = ac->addAction("rkconsole_copy_literal", this, &RKConsole::literalCopy);
+	ac->setDefaultShortcut(copy_literal_action, REAL_CMD_KEY | Qt::Key_C);
+	copy_literal_action->setText(i18n("Copy selection literally"));
 
-	copy_commands_action = ac->addAction ("rkconsole_copy_commands", this, SLOT (copyCommands()));
-	copy_commands_action->setText (i18n ("Copy commands, only"));
+	copy_commands_action = ac->addAction("rkconsole_copy_commands", this, &RKConsole::copyCommands);
+	copy_commands_action->setText(i18n("Copy commands, only"));
 
 	RKStandardActions::pasteSpecial (this, this, SLOT (submitBatch(QString)));
 
-	ac->addAction (KStandardAction::Clear, "rkconsole_clear", this, SLOT (clear()));
-	paste_action = ac->addAction (KStandardAction::Paste, "rkconsole_paste", this, SLOT (paste()));
+	ac->addAction(KStandardAction::Clear, "rkconsole_clear", this, &RKConsole::clear);
+	paste_action = ac->addAction(KStandardAction::Paste, "rkconsole_paste", this, &RKConsole::paste);
 
 	addProxyAction ("file_print", i18n ("Print Console"));
 	addProxyAction ("file_export_html");
 	addProxyAction ("view_inc_font_sizes");
 	addProxyAction ("view_dec_font_sizes");
 
-	QAction *action = ac->addAction ("loadhistory", this, SLOT (userLoadHistory()));
-	action->setText (i18n ("Import command history..."));
-	action = ac->addAction ("savehistory", this, SLOT (userSaveHistory()));
-	action->setText (i18n ("Export command history..."));
+	QAction *action = ac->addAction("loadhistory", this, [this](){ userLoadHistory(); });
+	action->setText(i18n("Import command history..."));
+	action = ac->addAction("savehistory", this, [this](){ userSaveHistory(); });
+	action->setText(i18n("Export command history..."));
 }
 
 void RKConsole::pipeUserCommand (const QString &command) {
@@ -892,15 +887,15 @@ void RKConsole::pipeCommandThroughConsoleLocal (const QString &command_string) {
 
 	activate (false);
 	if (isBusy () && (!previous_chunk_was_piped)) {
-		int res = KMessageBox::questionYesNoCancel (this, i18n ("You have configured RKWard to pipe script editor commands through the R Console. However, another command is currently active in the console. Do you want to append it to the command in the console, or do you want to reset the console, first? Press cancel if you do not wish to run the new command, now."), i18n ("R Console is busy"), KGuiItem (i18n ("Append")), KGuiItem (i18n ("Reset, then submit")));
-		if (res == KMessageBox::No) {
+		int res = KMessageBox::questionTwoActionsCancel (this, i18n ("You have configured RKWard to pipe script editor commands through the R Console. However, another command is currently active in the console. Do you want to append it to the command in the console, or do you want to reset the console, first? Press cancel if you do not wish to run the new command, now."), i18n ("R Console is busy"), KGuiItem (i18n ("Append")), KGuiItem (i18n ("Reset, then submit")));
+		if (res == KMessageBox::SecondaryAction) {
 			resetConsole ();
-		} else if (res != KMessageBox::Yes) {
+		} else if (res != KMessageBox::PrimaryAction) {
 			return;
 		}
 	}
 	if (RKSettingsModuleConsole::addPipedCommandsToHistory() != RKSettingsModuleConsole::DontAdd) {
-		QStringList lines = command_string.split ('\n', RKCompatibility::SkipEmptyParts());
+		QStringList lines = command_string.split ('\n', Qt::SkipEmptyParts);
 		if ((RKSettingsModuleConsole::addPipedCommandsToHistory() == RKSettingsModuleConsole::AlwaysAdd) || (lines.count () == 1)) {
 			for (int i = 0; i < lines.count (); ++i) {
 				commands_history.append (lines[i]);
@@ -925,7 +920,7 @@ void RKConsole::contextMenuEvent (QContextMenuEvent * event) {
 	copy_literal_action->setEnabled (view->selection ());
 	run_selection_action->setEnabled (view->selection ());
 
-	console_part->showPopupMenu (event->pos ());
+	console_part->showPopupMenu(event->globalPos());
 
 	run_selection_action->setEnabled (true);
 	copy_literal_action->setEnabled (true);
@@ -944,7 +939,7 @@ void RKConsole::activate (bool with_focus) {
 ///################### BEGIN RKConsolePart ####################
 
 
-RKConsolePart::RKConsolePart (RKConsole *console) : KParts::Part (0) {
+RKConsolePart::RKConsolePart(RKConsole *console) : KParts::Part(nullptr) {
 	RK_TRACE (APP);
 
 	setComponentName (QCoreApplication::applicationName (), QGuiApplication::applicationDisplayName ());
