@@ -1,6 +1,6 @@
 /*
 rkward.cpp - This file is part of RKWard (https://rkward.kde.org). Created: Tue Oct 29 2002
-SPDX-FileCopyrightText: 2002-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2002-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,6 +38,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KConfigGroup>
 #include <KColorScheme>
 #include <kwidgetsaddons_version.h>
+#include <KMessageWidget>
 
 // application specific includes
 #include "core/rkmodificationtracker.h"
@@ -53,10 +54,9 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "core/robjectlist.h"
 #include "core/renvironmentobject.h"
 #include "misc/rkstandardicons.h"
+#include "misc/rkcommandlineargs.h"
 #include "misc/rkcommonfunctions.h"
-#include "misc/rkcompatibility.h"
 #include "misc/rkxmlguisyncer.h"
-#include "misc/rkdbusapi.h"
 #include "misc/rkdialogbuttonbox.h"
 #include "misc/rkstyle.h"
 #include "dialogs/rkloadlibsdialog.h"
@@ -94,26 +94,29 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 // This nevers gets called. It's needed to trick ld into linking correctly. Nothing else.
 void bogusCalls () {
-	ShowEditTextFileAgent::showEditFiles (0);		// TODO: AAAAAAAARGGGH!!!! It won't link without this bogus line!!!
-	RKReadLineDialog::readLine (0, QString(), QString(), 0, 0);	// TODO: see above
-	RKSelectListDialog::doSelect (0, QString(), QStringList(), QStringList(), false);	// TODO: see above
-	new RKEditorDataFrame (0, 0);
-	DetachedWindowContainer (0, false);
-	new RKWorkplaceView (0);
-	new RKEditObjectAgent (QStringList (), 0);
-	RKPrintAgent::printPostscript (QString (), false);
+#ifndef CPPCHECK_ONLY  // it would rightfully complain about some of these
+	ShowEditTextFileAgent::showEditFiles(nullptr);                                   // TODO: AAAAAAAARGGGH!!!! It won't link without this bogus line!!!
+	RKReadLineDialog::readLine(nullptr, QString(), QString(), nullptr, nullptr);     // TODO: see above
+	RKSelectListDialog::doSelect(nullptr, QString(), QStringList(), QStringList(), false); // TODO: see above
+	new RKEditorDataFrame(nullptr, nullptr);
+	DetachedWindowContainer(nullptr, false);
+	new RKWorkplaceView(nullptr);
+	new RKEditObjectAgent(QStringList(), nullptr);
+	RKPrintAgent::printPostscript(QString(), false);
+#endif
 }
 
 /** Main window **/
 
 //static
-RKWardMainWindow *RKWardMainWindow::rkward_mainwin = 0;
+RKWardMainWindow *RKWardMainWindow::rkward_mainwin = nullptr;
 
 RKWardMainWindow::RKWardMainWindow() : KParts::MainWindow() {
-	RK_TRACE (APP);
-	RK_ASSERT (rkward_mainwin == 0);
+	RK_TRACE(APP);
+	RK_ASSERT(rkward_mainwin == nullptr);
 
 	Q_INIT_RESOURCE(resources);
+	Q_INIT_RESOURCE(icons);
 	testmode_suppress_dialogs = false;
 	gui_rebuild_locked = true;
 	no_ask_save = true;
@@ -175,7 +178,7 @@ RKWardMainWindow::RKWardMainWindow() : KParts::MainWindow() {
 	RKComponentMap::initialize ();
 
 	// stuff which should wait until the event loop is running
-	QTimer::singleShot (0, this, SLOT (doPostInit()));
+	QTimer::singleShot(0, this, &RKWardMainWindow::doPostInit);
 }
 
 RKWardMainWindow::~RKWardMainWindow() {
@@ -191,7 +194,7 @@ RKWardMainWindow::~RKWardMainWindow() {
 	delete RControlWindow::getControl ();
 	factory ()->removeClient (RKComponentMap::getMap ());
 	delete RKComponentMap::getMap ();
-	RKStyle::cleanResources();
+	delete RKStyle::_view_scheme;
 }
 
 KatePluginIntegrationApp* RKWardMainWindow::katePluginIntegration () {
@@ -213,17 +216,24 @@ void RKWardMainWindow::closeEvent (QCloseEvent *e) {
 
 	e->ignore();
 	if (doQueryQuit()) {
-		emit aboutToQuitRKWard();
+		Q_EMIT aboutToQuitRKWard();
 		new RKQuitAgent(this);
 	}
 }
 
+bool RKWardMainWindow::event(QEvent *e) {
+	if (e->type() == QEvent::ApplicationPaletteChange) {
+		delete RKStyle::_view_scheme;
+		RKStyle::_view_scheme = nullptr;
+	}
+	return KParts::MainWindow::event(e);
+}
+
 void RKWardMainWindow::doPostInit () {
 	RK_TRACE (APP);
 
-	QStringList open_urls = RKSettingsModuleGeneral::takeStartupOption("initial_urls").toStringList();
-	bool warn_external = RKSettingsModuleGeneral::takeStartupOption("warn_external").toBool();
-	QString evaluate_code = RKSettingsModuleGeneral::takeStartupOption("evaluate").toString();
+	QStringList open_urls = RKCommandLineArgs::get(RKCommandLineArgs::UrlArgs).toStringList();
+	QString evaluate_code = RKCommandLineArgs::get(RKCommandLineArgs::Evaluate).toString();
 
 	initPlugins ();
 	gui_rebuild_locked = false;
@@ -245,18 +255,12 @@ void RKWardMainWindow::doPostInit () {
 		open_urls[i] = url.url ();
 	}
 
-	QString cd_to = RKSettingsModuleGeneral::initialWorkingDirectory ();
-	if (!cd_to.isEmpty ()) {
-		RInterface::issueCommand ("setwd (" + RObject::rQuote (cd_to) + ")\n", RCommand::App);
-		QDir::setCurrent (cd_to);
-	}
-
 	if (!open_urls.isEmpty()) {
 		// this is also done when there are no urls specified on the command line. But in that case _after_ loading any workspace, so
 		// the help window will be on top
 		if (RKSettingsModuleGeneral::showHelpOnStartup ()) toplevel_actions->showRKWardHelp ();
 
-		openUrlsFromCommandLineOrDBus (warn_external, open_urls);
+		openUrlsFromCommandLineOrExternal(true, open_urls);
 	} else {
 		if (RKSettingsModuleGeneral::openRestoreFileOnLoad() && QFile::exists(".RData")) {
 			// setNoAskSave(true); was called earlier
@@ -276,16 +280,12 @@ void RKWardMainWindow::doPostInit () {
 	RInterface::issueCommand (command);
 
 	if (!evaluate_code.isEmpty ()) RKConsole::pipeUserCommand (evaluate_code);
-	RKDBusAPI *dbus = new RKDBusAPI (this);
-	connect (this, &RKWardMainWindow::aboutToQuitRKWard, dbus, &RKDBusAPI::deleteLater);
-	// around on the bus in this case.
 
 	updateCWD ();
-	connect (RInterface::instance(), &RInterface::backendWorkdirChanged, this, &RKWardMainWindow::updateCWD);
 	setCaption (QString ());	// our version of setCaption takes care of creating a correct caption, so we do not need to provide it here
 }
 
-void RKWardMainWindow::openUrlsFromCommandLineOrDBus (bool warn_external, QStringList _urls) {
+void RKWardMainWindow::openUrlsFromCommandLineOrExternal(bool no_warn_external, QStringList _urls) {
 	RK_TRACE (APP);
 
 	bool any_dangerous_urls = false;
@@ -298,7 +298,8 @@ void RKWardMainWindow::openUrlsFromCommandLineOrDBus (bool warn_external, QStrin
 		urls.append (url);
 	}
 
-	if (warn_external && any_dangerous_urls) {
+	// --nowarn-external, if used cross-process, must be set on the commandline in both this, *and* the calling process
+	if (any_dangerous_urls && !(no_warn_external && RKCommandLineArgs::get(RKCommandLineArgs::NoWarnExternal).toBool())) {
 		RK_ASSERT (urls.size () == 1);
 		QString message = i18n ("<p>You are about to start an RKWard dialog from outside of RKWard, probably by clicking on an 'rkward://'-link, somewhere. In case you have found this link on an external website, please bear in mind that R can be used to run arbitrary commands on your computer, <b>potentially including downloading and installing malicious software</b>. If you do not trust the source of the link you were following, you should press 'Cancel', below.</p><p>In case you click 'Continue', no R code will be run, unless and until you click 'Submit' in the dialog window, and you are encouraged to review the generated R code, before doing so.</p><p><i>Note</i>: Checking 'Do not ask again' will suppress this message for the remainder of this session, only.");
 		if (KMessageBox::warningContinueCancel (this, message, i18n ("A note on external links"), KStandardGuiItem::cont (), KStandardGuiItem::cancel (), "external_link_warning") != KMessageBox::Continue) return;
@@ -351,11 +352,11 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 	}
 	if (!completely_broken_maps.isEmpty ()) {
 		QString maplist = "<ul><li>" + completely_broken_maps.join ("</li>\n<li>") + "</li></ul>";
-		KMessageBox::detailedError (0, QString ("<p>%1</p><p>%2</p>").arg (i18n ("The following RKWard pluginmap files could not be loaded, and have been disabled. This could be because they are broken, not compatible with this version of RKWard, or not meant for direct loading (see the 'Details' for more information). They have been disabled."), maplist), completely_broken_maps_details.join ("\n"), i18n ("Failed to load some plugin maps"));
+		KMessageBox::detailedError(nullptr, QString("<p>%1</p><p>%2</p>").arg(i18n("The following RKWard pluginmap files could not be loaded, and have been disabled. This could be because they are broken, not compatible with this version of RKWard, or not meant for direct loading (see the 'Details' for more information). They have been disabled."), maplist), completely_broken_maps_details.join ("\n"), i18n("Failed to load some plugin maps"));
 	}
 	if (!somewhat_broken_maps.isEmpty ()) {
 		QString maplist = "<ul><li>" + somewhat_broken_maps.join ("</li>\n<li>") + "</li></ul>";
-		KMessageBox::detailedError (0, QString ("<p>%1</p><p>%2</p><p>%3</p>").arg (i18n ("Some errors were encountered while loading the following RKWard pluginmap files. This could be because individual plugins are broken or not compatible with this version of RKWard (see the 'Details' for more information). Other plugins were loaded, successfully, however."), maplist, i18n ("Note: You will not be warned about these pluginmap files again, until you upgrade RKWard, or remove and re-add them in Settings->Configure RKWard->Plugins.")), somewhat_broken_maps_details.join ("\n"), i18n ("Failed to load some plugin maps"));
+		KMessageBox::detailedError(nullptr, QString("<p>%1</p><p>%2</p><p>%3</p>").arg(i18n("Some errors were encountered while loading the following RKWard pluginmap files. This could be because individual plugins are broken or not compatible with this version of RKWard (see the 'Details' for more information). Other plugins were loaded, successfully, however."), maplist, i18n("Note: You will not be warned about these pluginmap files again, until you upgrade RKWard, or remove and re-add them in Settings->Configure RKWard->Plugins.")), somewhat_broken_maps_details.join("\n"), i18n("Failed to load some plugin maps"));
 	}
 
 	slotSetStatusReady ();
@@ -364,6 +365,7 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 void RKWardMainWindow::startR () {
 	RK_TRACE (APP);
 
+	setRStatus(RInterface::Starting);
 	// make sure our general purpose files directory exists
 	QString packages_path = RKSettingsModuleGeneral::filesPath() + "/.rkward_packages";
 	bool ok = QDir ().mkpath (packages_path);
@@ -373,12 +375,11 @@ void RKWardMainWindow::startR () {
 	// This may look redundant at first (since the package still needs to be installed from the
 	// backend. However, if frontend and backend are on different machines (eventually), only  the
 	// filesPath is shared between both.
-	QStringList packages;
-	packages << "rkward.tgz" << "rkwardtests.tgz";
+	QStringList packages({"rkward.tgz", "rkwardtests.tgz"});
 	for (int i = 0; i < packages.size (); ++i) {
 		QString package = QDir (packages_path).absoluteFilePath (packages[i]);
-		if (RKSettingsModuleGeneral::rkwardVersionChanged ()) {
-			RK_DEBUG(APP, DL_INFO, "RKWard version changed. Discarding cached package at %s", qPrintable (package));
+		if (RKSettingsModuleGeneral::rkwardVersionChanged() || RKCommandLineArgs::get(RKCommandLineArgs::Setup).toBool()) {
+			RK_DEBUG(APP, DL_INFO, "RKWard version changed or setup requested. Discarding cached package at %s", qPrintable(package));
 			if(QFileInfo::exists(package)) RK_ASSERT(QFile::remove(package));
 		}
 		if (!QFileInfo::exists(package)) {
@@ -390,7 +391,9 @@ void RKWardMainWindow::startR () {
 	}
 
 	RInterface::create();
+	Q_EMIT backendCreated();
 	connect(RInterface::instance(), &RInterface::backendStatusChanged, this, &RKWardMainWindow::setRStatus);
+	connect(RInterface::instance(), &RInterface::backendWorkdirChanged, this, &RKWardMainWindow::updateCWD);
 	RObjectList::init();
 
 	RObjectBrowser::mainBrowser ()->unlock ();
@@ -428,43 +431,43 @@ void RKWardMainWindow::configureCarbonCopy () {
 void RKWardMainWindow::initToolViewsAndR () {
 	RK_TRACE (APP);
 
-	RObjectBrowser::object_browser = new RObjectBrowser (0, true);
+	RObjectBrowser::object_browser = new RObjectBrowser(nullptr, true);
 	RObjectBrowser::mainBrowser ()->setCaption (i18n ("Workspace"));
-	RKToolWindowList::registerToolWindow (RObjectBrowser::mainBrowser (), "workspace", RKToolWindowList::Left, Qt::AltModifier + Qt::Key_1);
+	RKToolWindowList::registerToolWindow (RObjectBrowser::mainBrowser (), "workspace", RKToolWindowList::Left, Qt::AltModifier | Qt::Key_1);
 
-	RKCommandLog::rkcommand_log = new RKCommandLog (0, true);
-	RKToolWindowList::registerToolWindow (RKCommandLog::rkcommand_log, "commandlog", RKToolWindowList::Bottom, Qt::AltModifier + Qt::Key_3);
+	RKCommandLog::rkcommand_log = new RKCommandLog(nullptr, true);
+	RKToolWindowList::registerToolWindow (RKCommandLog::rkcommand_log, "commandlog", RKToolWindowList::Bottom, Qt::AltModifier | Qt::Key_3);
 
 	startR ();
 
-	RKFileBrowser::main_browser = new RKFileBrowser (0, true);
+	RKFileBrowser::main_browser = new RKFileBrowser(nullptr, true);
 	RKFileBrowser::main_browser->setCaption (i18n ("Files"));
-	RKToolWindowList::registerToolWindow (RKFileBrowser::main_browser, "filebrowser", RKToolWindowList::Left, Qt::AltModifier + Qt::Key_2);
+	RKToolWindowList::registerToolWindow (RKFileBrowser::main_browser, "filebrowser", RKToolWindowList::Left, Qt::AltModifier | Qt::Key_2);
 
-	RControlWindow::control_window = new RControlWindow (0, true);
+	RControlWindow::control_window = new RControlWindow(nullptr, true);
 	RControlWindow::getControl ()->setCaption (i18n ("Pending Jobs"));
-	RKToolWindowList::registerToolWindow (RControlWindow::getControl (), "pendingjobs", RKToolWindowList::Nowhere, Qt::AltModifier + Qt::Key_4);
+	RKToolWindowList::registerToolWindow (RControlWindow::getControl (), "pendingjobs", RKToolWindowList::Nowhere, Qt::AltModifier | Qt::Key_4);
 
-	RKConsole *console = new RKConsole (0, true);
+	RKConsole *console = new RKConsole(nullptr, true);
 	RKConsole::setMainConsole (console);
-	RKToolWindowList::registerToolWindow (console, "console", RKToolWindowList::Bottom, Qt::AltModifier + Qt::Key_5);
+	RKToolWindowList::registerToolWindow (console, "console", RKToolWindowList::Bottom, Qt::AltModifier | Qt::Key_5);
 
-	RKHelpSearchWindow *help_search = new RKHelpSearchWindow (0, true);
+	RKHelpSearchWindow *help_search = new RKHelpSearchWindow(nullptr, true);
 	RKHelpSearchWindow::main_help_search = help_search;
-	RKToolWindowList::registerToolWindow (help_search, "helpsearch", RKToolWindowList::Bottom, Qt::AltModifier + Qt::Key_6);
+	RKToolWindowList::registerToolWindow (help_search, "helpsearch", RKToolWindowList::Bottom, Qt::AltModifier | Qt::Key_6);
 
-	RKCallstackViewer::_instance = new RKCallstackViewer (0, true);
+	RKCallstackViewer::_instance = new RKCallstackViewer(nullptr, true);
 	RKCallstackViewer::instance ()->setCaption (i18n ("Debugger Frames"));
-	RKToolWindowList::registerToolWindow (RKCallstackViewer::instance (), "debugframes", RKToolWindowList::Right, Qt::AltModifier + Qt::Key_8);
+	RKToolWindowList::registerToolWindow (RKCallstackViewer::instance (), "debugframes", RKToolWindowList::Right, Qt::AltModifier | Qt::Key_8);
 
 	// HACK: Creating this _after_ the callstackviewer is important, so the debug console will end up the active window when entering a debug context
-	RKDebugConsole::_instance = new RKDebugConsole (0, true);
+	RKDebugConsole::_instance = new RKDebugConsole(nullptr, true);
 	RKDebugConsole::instance ()->setCaption (i18n ("Debugger Console"));
-	RKToolWindowList::registerToolWindow (RKDebugConsole::instance (), "debugconsole", RKToolWindowList::Nowhere, Qt::AltModifier + Qt::Key_7);
+	RKToolWindowList::registerToolWindow (RKDebugConsole::instance (), "debugconsole", RKToolWindowList::Nowhere, Qt::AltModifier | Qt::Key_7);
 
-	RKDebugMessageWindow::_instance = new RKDebugMessageWindow (0, true);
+	RKDebugMessageWindow::_instance = new RKDebugMessageWindow(nullptr, true);
 	RKDebugMessageWindow::instance ()->setCaption (i18n ("RKWard Debug Messages"));
-	RKToolWindowList::registerToolWindow (RKDebugMessageWindow::instance (), "rkdebugmessages", RKToolWindowList::Nowhere, 0);
+	RKToolWindowList::registerToolWindow (RKDebugMessageWindow::instance (), "rkdebugmessages", RKToolWindowList::Nowhere, QKeyCombination());
 
 	RKWorkplace::mainWorkplace ()->placeToolWindows ();
 }
@@ -474,26 +477,26 @@ void RKWardMainWindow::initActions() {
 	QAction *action;
 
 	// TODO: is there a way to insert actions between standard actions without having to give all standard actions custom ids?
-	new_data_frame = actionCollection ()->addAction ("new_data_frame", this, SLOT (slotNewDataFrame()));
+	new_data_frame = actionCollection()->addAction("new_data_frame", this, &RKWardMainWindow::slotNewDataFrame);
 	new_data_frame->setText (i18n ("Dataset"));
 	new_data_frame->setIcon (RKStandardIcons::getIcon (RKStandardIcons::WindowDataFrameEditor));
 	new_data_frame->setWhatsThis(i18n ("Creates new empty dataset and opens it for editing"));
 
-	new_command_editor = actionCollection ()->addAction (KStandardAction::New, "new_command_editor", this, SLOT(slotNewCommandEditor()));
+	new_command_editor = actionCollection()->addAction(KStandardAction::New, "new_command_editor", this, &RKWardMainWindow::slotNewCommandEditor);
 	new_command_editor->setText (i18n ("Script File"));
 	new_command_editor->setIcon (RKStandardIcons::getIcon (RKStandardIcons::WindowCommandEditor));
 
-	new_output = actionCollection ()->addAction("new_output", this, SLOT(slotNewOutput()));
+	new_output = actionCollection()->addAction("new_output", this, &RKWardMainWindow::slotNewOutput);
 	new_output->setText(i18n("Output document"));
 	new_output->setIcon(RKStandardIcons::getIcon(RKStandardIcons::WindowOutput));
 	new_output->setWhatsThis(i18n("Creates and activates a new output document"));
 
 	fileOpenScript = actionCollection()->addAction(KStandardAction::Open, "file_open_script");
 	connect(fileOpenScript, &QAction::triggered, this, [this]() { slotOpenCommandEditor(); });
-	actionCollection()->setDefaultShortcut(fileOpenScript, Qt::ControlModifier + Qt::AltModifier + Qt::Key_O);
+	actionCollection()->setDefaultShortcut(fileOpenScript, Qt::ControlModifier | Qt::AltModifier | Qt::Key_O);
 	fileOpenScript->setText(i18n("Open R Script File..."));
 
-	fileOpenOutput = actionCollection()->addAction(KStandardAction::Open, "file_open_output", this, SLOT(slotOpenOutput()));
+	fileOpenOutput = actionCollection()->addAction(KStandardAction::Open, "file_open_output", this, [this](){ slotOpenOutput(); });
 	actionCollection()->setDefaultShortcut(fileOpenOutput, QKeySequence());
 	fileOpenOutput->setText(i18n("Open RKWard Output File..."));
 
@@ -514,7 +517,7 @@ void RKWardMainWindow::initActions() {
 	fileOpenWorkspace = actionCollection()->addAction(KStandardAction::Open, "file_openx");
 	connect(fileOpenWorkspace, &QAction::triggered, this, [this](){ askOpenWorkspace(); });
 	fileOpenWorkspace->setText (i18n ("Open Workspace..."));
-	actionCollection ()->setDefaultShortcut (fileOpenWorkspace, Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_O);
+	actionCollection ()->setDefaultShortcut (fileOpenWorkspace, Qt::ControlModifier | Qt::ShiftModifier | Qt::Key_O);
 	fileOpenWorkspace->setWhatsThis(i18n ("Opens an existing document"));
 
 	fileOpenRecentWorkspace = RKRecentUrls::claimAction(RKRecentUrls::workspaceId());
@@ -523,54 +526,54 @@ void RKWardMainWindow::initActions() {
 	fileOpenRecentWorkspace->setText (i18n ("Open Recent Workspace"));
 	fileOpenRecentWorkspace->setWhatsThis(i18n ("Opens a recently used file"));
 
-	fileSaveWorkspace = actionCollection ()->addAction (KStandardAction::Save, "file_savex", this, SLOT(slotFileSaveWorkspace()));
+	fileSaveWorkspace = actionCollection()->addAction(KStandardAction::Save, "file_savex", this, [](){ RKSaveAgent::saveWorkspace(); });
 	fileSaveWorkspace->setText (i18n ("Save Workspace"));
-	actionCollection ()->setDefaultShortcut (fileSaveWorkspace, Qt::ControlModifier + Qt::AltModifier + Qt::Key_S);
+	actionCollection ()->setDefaultShortcut (fileSaveWorkspace, Qt::ControlModifier | Qt::AltModifier | Qt::Key_S);
 	fileSaveWorkspace->setWhatsThis(i18n ("Saves the actual document"));
 
-	fileSaveWorkspaceAs = actionCollection ()->addAction (KStandardAction::SaveAs, "file_save_asx", this, SLOT(slotFileSaveWorkspaceAs()));
-	actionCollection ()->setDefaultShortcut (fileSaveWorkspaceAs, Qt::ControlModifier + Qt::AltModifier + Qt::ShiftModifier + Qt::Key_S);
+	fileSaveWorkspaceAs = actionCollection()->addAction(KStandardAction::SaveAs, "file_save_asx", this, [](){ RKSaveAgent::saveWorkspaceAs(); });
+	actionCollection ()->setDefaultShortcut (fileSaveWorkspaceAs, Qt::ControlModifier | Qt::AltModifier | Qt::ShiftModifier | Qt::Key_S);
 	fileSaveWorkspaceAs->setText (i18n ("Save Workspace As"));
 	fileSaveWorkspaceAs->setWhatsThis(i18n ("Saves the actual document as..."));
 
-	fileQuit = actionCollection ()->addAction (KStandardAction::Quit, "file_quitx", this, SLOT(close()));
+	fileQuit = actionCollection()->addAction(KStandardAction::Quit, "file_quitx", this, &RKWardMainWindow::close);
 	fileQuit->setWhatsThis(i18n ("Quits the application"));
 
-	interrupt_all_commands = actionCollection ()->addAction ("cancel_all_commands", this, SLOT (slotCancelAllCommands()));
+	interrupt_all_commands = actionCollection()->addAction("cancel_all_commands", this, &RKWardMainWindow::slotCancelAllCommands);
 	interrupt_all_commands->setText (i18n ("Interrupt all commands"));
-	actionCollection ()->setDefaultShortcut (interrupt_all_commands, Qt::ShiftModifier + Qt::Key_Escape);
+	actionCollection ()->setDefaultShortcut (interrupt_all_commands, Qt::ShiftModifier | Qt::Key_Escape);
 	interrupt_all_commands->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionInterrupt));
 	interrupt_all_commands->setEnabled (false);		// enabled from within setRStatus()
 
-	action = actionCollection ()->addAction ("carbon_copy", this, SLOT (configureCarbonCopy()));
+	action = actionCollection()->addAction("carbon_copy", this, &RKWardMainWindow::configureCarbonCopy);
 	action->setText (i18n ("CC commands to output..."));
 
 	// These two currently do the same thing
-	action = actionCollection ()->addAction ("load_unload_libs", this, SLOT (slotFileLoadLibs()));
+	action = actionCollection()->addAction("load_unload_libs", this, &RKWardMainWindow::slotFileLoadLibs); // TODO: set page
 	action->setText (i18n ("Manage R packages and plugins..."));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionConfigurePackages));
 
-	action = actionCollection ()->addAction ("configure_packages", this, SLOT (slotFileLoadLibs()));
+	action = actionCollection()->addAction("configure_packages", this, &RKWardMainWindow::slotFileLoadLibs); // TODO: set page
 	action->setText (i18n ("Manage R packages and plugins..."));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionConfigurePackages));
 
 	setStandardToolBarMenuEnabled (true);
 	createStandardStatusBarAction ();
 
-	close_all_editors = actionCollection ()->addAction ("close_all_editors", this, SLOT (slotCloseAllEditors()));
+	close_all_editors = actionCollection()->addAction("close_all_editors", this, &RKWardMainWindow::slotCloseAllEditors);
 	close_all_editors->setText (i18n ("Close All Data"));
 	close_all_editors->setWhatsThis(i18n ("Closes all open data editors"));
 
-	action = actionCollection ()->addAction (KStandardAction::Close, "window_close", this, SLOT (slotCloseWindow()));
+	action = actionCollection()->addAction(KStandardAction::Close, "window_close", this, &RKWardMainWindow::slotCloseWindow);
 
-	window_close_all = actionCollection ()->addAction ("window_close_all", this, SLOT (slotCloseAllWindows()));
+	window_close_all = actionCollection()->addAction("window_close_all", this, &RKWardMainWindow::slotCloseAllWindows);
 	window_close_all->setText (i18n ("Close All"));
 
-	window_detach = actionCollection ()->addAction ("window_detach", this, SLOT (slotDetachWindow()));
+	window_detach = actionCollection()->addAction("window_detach", this, &RKWardMainWindow::slotDetachWindow);
 	window_detach->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionDetachWindow));
 	window_detach->setText (i18n ("Detach"));
 
-	configure = actionCollection ()->addAction (KStandardAction::Preferences, "options_configure", this, SLOT (slotConfigure()));
+	configure = actionCollection()->addAction(KStandardAction::Preferences, "options_configure", this, &RKWardMainWindow::slotConfigure);
 	action = actionCollection()->addAction("setup_wizard");
 	action->setText(i18n("Check installation"));
 	connect(action, &QAction::triggered, &RKSetupWizard::manualCheck);
@@ -607,15 +610,9 @@ void RKWardMainWindow::initActions() {
 	save_any_action = new KActionMenu (QIcon::fromTheme("document-save"), i18n ("Save..."), this);
 	actionCollection ()->addAction ("save_any", save_any_action);
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
 	open_any_action->setPopupMode(QToolButton::InstantPopup);
 	new_any_action->setPopupMode(QToolButton::InstantPopup);
 	save_any_action->setPopupMode(QToolButton::InstantPopup);
-#else
-	open_any_action->setDelayed(false);
-	new_any_action->setDelayed(false);
-	save_any_action->setDelayed(false);
-#endif
 
 	save_any_action->addAction (fileSaveWorkspace);
 	save_any_action->addAction (fileSaveWorkspaceAs);
@@ -627,50 +624,59 @@ void RKWardMainWindow::initActions() {
 	restart_r = actionCollection()->addAction("restart_r");
 	restart_r->setIcon(QIcon::fromTheme("view-refresh"));
 	restart_r->setText(i18n("Restart R Backend"));
-	connect(restart_r, &QAction::triggered, this, [this]() {
-		QString message = i18n("<p>This feature is primarily targetted at advanced users working on scripts or packages. Please proceed with caution.</p><p><b>All unsaved data in this workspace will be lost!</b> All data editors, and graphics windows will be closed.</p><p>Are you sure you want to proceed?</p>");
-		if (suppressModalDialogsForTesting() || (KMessageBox::warningContinueCancel(this, message, i18n("Restart R backend"), KGuiItem(i18n("Restart R backend"))) == KMessageBox::Continue)) {
-			bool forced = RInterface::instance()->backendIsDead();
-			while (!RInterface::instance()->backendIsDead() && !RInterface::instance()->backendIsIdle()) {
-				RK_DEBUG(APP, DL_DEBUG, "Backend not idle while restart requested.");
-				message = i18n("<p>One or more operations are pending.</p><p>If you have recently chosen to save your workspace, and you see this message, <b>your data may not be saved, yet!</b></p><p>How do you want to proceed?</p>");
-				auto res = KMessageBox::warningYesNoCancel(this, message, i18n("R commands still pending"), KGuiItem(i18n("Force restart now")), KGuiItem(i18n("Check again")), KGuiItem(i18n("Cancel restarting")));
-				if (res == KMessageBox::Yes) {
-					forced = true;
-					break;
-				} else if (res == KMessageBox::Cancel) {
-					return;
-				}
-				// KMessageBox::No means to loop: Commands may have finished, meanwhile. This is not really pretty, a proper progress control would be nicer,
-				// but then, this is a corner case to a feature that is not really targetted at a mainstream audience, anyway.
-			}
+	connect(restart_r, &QAction::triggered, this, &RKWardMainWindow::triggerBackendRestart);
+}
 
-			RKWorkplace::mainWorkplace()->closeAll(RKMDIWindow::X11Window);
-			slotCloseAllEditors();
-			auto restart_now = [this]() {
-				RK_DEBUG(APP, DL_DEBUG, "Backend restart now");
-				delete RInterface::instance();  // NOTE: Do not use deleteLater(), here. It is important to fully tear down the old backend, before creating the new one,
-				                                //       as code is written around the assumption that RInterface and friends are singletons. (RInterface::instance(), etc.)
-				RKWorkplace::mainWorkplace()->setWorkspaceURL(QUrl());
-				startR();
-			};
-			if (forced) {
-				RKConsole::mainConsole()->resetConsole();
-				restart_now();
-			} else {
-				RCommand *c = new RCommand(QString(), RCommand::QuitCommand);
-				c->whenFinished(this, [this, restart_now]() { QTimer::singleShot(0, this, restart_now); });
-				RInterface::issueCommand(c);
-			}
+bool RKWardMainWindow::triggerBackendRestart(bool promptsave) {
+	RK_TRACE (APP);
+
+	promptsave = promptsave && !suppressModalDialogsForTesting();
+	QString message = i18n("<p><b>Restarting the backend will discard all unsaved data in this workspace!</b> All data editors, and graphics windows will be closed.</p><p>Are you sure you want to proceed?</p>");
+	if (promptsave && (KMessageBox::warningContinueCancel(this, message, i18n("Restart R backend"), KGuiItem(i18n("Restart R backend"))) != KMessageBox::Continue)) {
+		return false;
+	}
+
+	bool forced = RInterface::instance()->backendIsDead();
+	while (!RInterface::instance()->backendIsDead() && !RInterface::instance()->backendIsIdle()) {
+		RK_DEBUG(APP, DL_DEBUG, "Backend not idle while restart requested.");
+		message = i18n("<p>One or more operations are pending.</p><p>If you have recently chosen to save your workspace, and you see this message, <b>your data may not be saved, yet!</b></p><p>How do you want to proceed?</p>");
+		auto res = KMessageBox::warningTwoActionsCancel(this, message, i18n("R commands still pending"), KGuiItem(i18n("Force restart now")), KGuiItem(i18n("Check again")), KGuiItem(i18n("Cancel restarting")));
+		if (res == KMessageBox::PrimaryAction) {
+			forced = true;
+			break;
+		} else if (res == KMessageBox::Cancel) {
+			return false;
 		}
-	});
+		// KMessageBox::No means to loop: Commands may have finished, meanwhile. This is not really pretty, a proper progress control would be nicer,
+		// but then, this is a corner case to a feature that is not really targetted at a mainstream audience, anyway.
+	}
+
+	RKWorkplace::mainWorkplace()->closeAll(RKMDIWindow::X11Window);
+	slotCloseAllEditors();
+	auto restart_now = [this]() {
+		RK_DEBUG(APP, DL_DEBUG, "Backend restart now");
+		delete RInterface::instance();  // NOTE: Do not use deleteLater(), here. It is important to fully tear down the old backend, before creating the new one,
+						//       as code is written around the assumption that RInterface and friends are singletons. (RInterface::instance(), etc.)
+		RKWorkplace::mainWorkplace()->setWorkspaceURL(QUrl());
+		startR();
+	};
+	if (forced) {
+		RKConsole::mainConsole()->resetConsole();
+		restart_now();
+	} else {
+		RCommand *c = new RCommand(QString("# Quit (restarting)"), RCommand::App | RCommand::EmptyCommand | RCommand::QuitCommand);
+		c->whenFinished(this, [this, restart_now]() { QTimer::singleShot(0, this, restart_now); });
+		RInterface::issueCommand(c);
+	}
+
+	return true;
 }
 
 /*
 // debug code: prints out all current actions
 void printActionsRecursive (QAction* action, const QString &prefix) {
 	if (action->menu ()) {
-		foreach (QAction *a, action->menu ()->actions ()) printActionsRecursive (a, prefix + action->text () + "->");
+		for (QAction *a : action->menu ()->actions ()) printActionsRecursive (a, prefix + action->text () + "->");
 	} else {
 		qDebug ("%s", qPrintable (prefix + action->text ()));
 	}
@@ -703,7 +709,8 @@ void RKWardMainWindow::partChanged(KParts::Part *part) {
 	if (gui_rebuild_locked) return;
 	if (!part) return;
 	createGUI(part);
-	foreach (QAction *a, actions()) {
+	const auto actionsList = actions();
+	for (QAction *a : actionsList) {
 		if (a->statusTip().isEmpty()) a->setStatusTip(a->whatsThis());
 	}
 
@@ -741,7 +748,7 @@ void RKWardMainWindow::partChanged(KParts::Part *part) {
 	}
 /*
 	// debug code: prints out all current actions
-	foreach (QAction *action, menuBar ()->actions ()) printActionsRecursive (action, QString ());
+	for (QAction *action : menuBar ()->actions ()) printActionsRecursive (action, QString ());
 */
 }
 
@@ -797,7 +804,6 @@ void RKWardMainWindow::initStatusBar () {
 	boxl->addWidget(dummy);
 
 	realbar->addPermanentWidget(box, 0);
-	setRStatus(RInterface::Starting);
 }
 
 void RKWardMainWindow::saveOptions () {
@@ -831,7 +837,7 @@ void RKWardMainWindow::readOptions () {
 	KConfigGroup cg = config->group ("General Options");
 	QSize size = cg.readEntry ("Geometry", QSize ());
 	if (size.isEmpty ()) {
-		size = RKCompatibility::availableGeometry(this).size();
+		size = screen() ? screen()->availableGeometry().size() : QApplication::primaryScreen()->availableGeometry().size();
 	}
 	resize (size);
 
@@ -887,20 +893,10 @@ void RKWardMainWindow::askOpenWorkspace (const QUrl &url) {
 
 void RKWardMainWindow::slotFileLoadLibs () {
 	RK_TRACE (APP);
-	RKLoadLibsDialog *dial = new RKLoadLibsDialog (this, 0);
+	RKLoadLibsDialog *dial = new RKLoadLibsDialog(this, nullptr);
 	dial->show ();
 }
 
-void RKWardMainWindow::slotFileSaveWorkspace () {
-	RK_TRACE (APP);
-	RKSaveAgent::saveWorkspace();
-}
-
-void RKWardMainWindow::slotFileSaveWorkspaceAs () {
-	RK_TRACE (APP);
-	RKSaveAgent::saveWorkspaceAs();
-}
-
 void RKWardMainWindow::updateCWD () {
 	RK_TRACE (APP);
 
@@ -954,6 +950,7 @@ void setIndictatorColor(QWidget *widget, KColorScheme::ForegroundRole fg, KColor
 
 void RKWardMainWindow::setRStatus (int status) {
 	RK_TRACE (APP);
+	static KMessageWidget* rstatus_message = nullptr;
 
 	if (status == RInterface::Busy) {
 		setIndictatorColor(statusbar_r_status, KColorScheme::NegativeText, KColorScheme::NegativeBackground);
@@ -964,12 +961,23 @@ void RKWardMainWindow::setRStatus (int status) {
 		statusbar_r_status->setToolTip(i18n("The <b>R</b> engine is idle."));
 		interrupt_all_commands->setEnabled(false);
 	} else if (status == RInterface::Starting) {
+		if (rstatus_message) rstatus_message->hide();
 		setIndictatorColor(statusbar_r_status, KColorScheme::NeutralText, KColorScheme::NeutralBackground);
 		statusbar_r_status->setToolTip(i18n("The <b>R</b> engine is being initialized."));
 	} else {
 		setIndictatorColor(statusbar_r_status, KColorScheme::NegativeText, KColorScheme::NegativeBackground);
 		statusbar_r_status->setToolTip(i18n("The <b>R</b> engine is unavailable."));
 		interrupt_all_commands->setEnabled(false);
+		if (RInterface::instance()->backendFailedToStart()) {
+			RKSetupWizard::doAutoCheck();  // The wizard itself will prevent recursion, if alread active
+		}
+		if (!rstatus_message) {
+			rstatus_message = new KMessageWidget(i18n("R engine unavailable. See <a href=\"rkward://page/rkward_trouble_shooting\">troubleshooting</a> for possible solutions."));
+			rstatus_message->setMessageType(KMessageWidget::Error);
+			rstatus_message->setCloseButtonVisible(false);
+			connect(rstatus_message, &KMessageWidget::linkActivated, this, [](const QString& url) { RKWorkplace::mainWorkplace()->openAnyUrl(QUrl(url)); });
+			RKWorkplace::mainWorkplace()->addMessageWidget(rstatus_message);
+		}
 	}
 }
 
@@ -989,8 +997,8 @@ void RKWardMainWindow::slotNewCommandEditor () {
 void RKWardMainWindow::openAnyFile () {
 	RK_TRACE (APP);
 
-	QFileDialog* dialog = new QFileDialog (0, QString (), RKRecentUrls::mostRecentUrl(RKRecentUrls::scriptsId()).adjusted(QUrl::RemoveFilename).toLocalFile(), QString ("*|All Files (*)\n%1|R Script Files (%1)").arg (RKSettingsModuleCommandEditor::scriptFileFilter ()));
-	dialog->setFileMode (QFileDialog::ExistingFiles);
+	QFileDialog* dialog = new QFileDialog(nullptr, QString(), RKRecentUrls::mostRecentUrl(RKRecentUrls::scriptsId()).adjusted(QUrl::RemoveFilename).toLocalFile(), QString ("*|All Files (*)\n%1|R Script Files (%1)").arg(RKSettingsModuleCommandEditor::scriptFileFilter()));
+	dialog->setFileMode(QFileDialog::ExistingFiles);
 
 // Create a type selection widget, and hack it into the dialog:
 	QFrame* dummy = new QFrame (this);
