@@ -31,10 +31,10 @@ public:
 	static QString workspaceId();
 	static QString outputId();
 	static RKRecentUrls* notifier();
-signals:
+Q_SIGNALS:
 	void recentUrlsChanged();
 private:
-	RKRecentUrls(QObject* parent);
+	explicit RKRecentUrls(QObject* parent);
 	~RKRecentUrls();
 	void notifyChange();
 	static void notifyChangeProxy();
