@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rksettingsmoduleconsole  -  description
-                             -------------------
-    begin                : Sun Oct 16 2005
-    copyright            : (C) 2005-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rksettingsmoduleconsole - This file is part of the RKWard project. Created: Sun Oct 16 2005
+SPDX-FileCopyrightText: 2005-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef RKSETTINGSMODULECONSOLE_H
 #define RKSETTINGSMODULECONSOLE_H
 
@@ -22,7 +12,6 @@
 #include "rksettingsmodulecommandeditor.h"  // For RKCodeCompletionSettings
 #include <qnamespace.h>
 
-class QCheckBox;
 class QComboBox;
 class QSpinBox;
 
@@ -37,12 +26,10 @@ public:
 	RKSettingsModuleConsole (RKSettings *gui, QWidget *parent);
 	~RKSettingsModuleConsole ();
 
-	static void saveSettings (KConfig *config);
-	static void loadSettings (KConfig *config);
+	void save(KConfig *config) override { syncConfig(config, RKConfigBase::SaveConfig); };
+	static void syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction);
 	static void validateSettingsInteractive (QList<RKSetupWizardItem*>*) {};
-
 	void applyChanges () override;
-	void save (KConfig *config) override;
 
 	static bool saveHistory () { return save_history; };
 	static uint maxHistoryLength () { return max_history_length; };
@@ -58,32 +45,29 @@ public:
 	@param current_state the current button state
 	@returns true, if a the search should be context sensitive, false for a normal search */
 	static bool shouldDoHistoryContextSensitive (Qt::KeyboardModifiers current_state);
+	static RKConfigValue<bool> *showMinimap() { return &show_minimap; };
+	static RKConfigValue<bool> *wordWrap() { return &word_wrap; };
 	static const RKCodeCompletionSettings* completionSettings() { return &completion_settings; }
 
 	static QStringList loadCommandHistory ();
 	static void saveCommandHistory (const QStringList &list);
 
-	QString caption () override;
+	QString caption() const override;
+	QIcon icon() const override;
 
 	QUrl helpURL () override { return QUrl ("rkward://page/rkward_console#settings"); };
-public slots:
-	void changedSetting (int);
 private:
 	static RKCodeCompletionSettings completion_settings;
-	static bool save_history;
-	static uint max_history_length;
-	static uint max_console_lines;
-	static bool pipe_user_commands_through_console;
-	static PipedCommandsHistoryMode add_piped_commands_to_history;
-	static bool context_sensitive_history_by_default;
+	static RKConfigValue<bool> save_history;
+	static RKConfigValue<uint> max_history_length;
+	static RKConfigValue<uint> max_console_lines;
+	static RKConfigValue<bool> pipe_user_commands_through_console;
+	static RKConfigValue<PipedCommandsHistoryMode, int> add_piped_commands_to_history;
+	static RKConfigValue<bool> context_sensitive_history_by_default;
+	static RKConfigValue<bool> show_minimap;
+	static RKConfigValue<bool> word_wrap;
 
 	RKCodeCompletionSettingsWidget *completion_settings_widget;
-	QCheckBox *save_history_box;
-	QCheckBox *reverse_context_mode_box;
-	QCheckBox *pipe_user_commands_through_console_box;
-	QComboBox *add_piped_commands_to_history_box;
-	QSpinBox *max_history_length_spinner;
-	QSpinBox *max_console_lines_spinner;
 };
 
 #endif
