@@ -26,7 +26,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../misc/rkstyle.h"
 #include "../misc/multistringselector.h"
 #include "../misc/rkcommonfunctions.h"
-#include "../misc/rkcompatibility.h"
 #include "../misc/rkspinbox.h"
 #include "../misc/xmlhelper.h"
 #include "../plugin/rkcomponentmap.h"
@@ -68,7 +67,7 @@ RKSettingsModulePlugins::RKSettingsModulePlugins (RKSettings *gui, QWidget *pare
 	button_group->addButton (button, PreferWizard);
 	if ((button = button_group->button (interface_pref))) button->setChecked (true);
 
-	connect (button_group, RKCompatibility::groupButtonClicked(), this, &RKSettingsModulePlugins::settingChanged);
+	connect (button_group, &QButtonGroup::idClicked, this, &RKSettingsModulePlugins::settingChanged);
 	main_vbox->addWidget (button_box);
 
 	main_vbox->addSpacing (2*RKStyle::spacingHint ());
@@ -162,7 +161,7 @@ void RKSettingsModulePlugins::RKPluginMapList::readFromConfig(KConfigGroup& cg)
 		else inf.state = (PluginMapState) ppmg.readEntry("State", (int) Working);
 		inf.last_modified = ppmg.readEntry ("timestamp", QDateTime ());
 		inf.id = ppmg.readEntry ("id");
-		inf.version = ppmg.readEntry ("version");
+		inf.version = RKParsedVersion(ppmg.readEntry("version"));
 		inf.priority = ppmg.readEntry ("priority", (int) PriorityMedium);
 		addMap(inf, ppmg.readEntry("Active", false) ? ForceActivate : DoNotActivate);
 	}
@@ -370,9 +369,9 @@ void RKSettingsModulePlugins::registerPluginMaps (const QStringList &maps, AddMo
 	RK_TRACE (SETTINGS);
 
 	QStringList added;
-	foreach (const QString &map, maps) {
+	for (const QString &map : maps) {
 		if (map.isEmpty ()) continue;
-		if (known_plugin_maps.addMap(map, add_mode)) {
+		if (known_plugin_maps.addMap(PluginMapStoredInfo(map), add_mode)) {
 			added.append(map);
 		}
 	}
@@ -392,21 +391,24 @@ RKSettingsModulePlugins::PluginMapStoredInfo RKSettingsModulePlugins::parsePlugi
 	inf.id = RKPluginMapFile::parseId(de, xml);
 	inf.priority = xml.getMultiChoiceAttribute(de, "priority", "hidden;low;medium;high", (int) PriorityMedium, DL_WARNING);
 	auto about = xml.getChildElement(de, "about", DL_WARNING);
-	inf.version = xml.getStringAttribute(about, "version", QString(), DL_WARNING);
+	inf.version = RKParsedVersion(xml.getStringAttribute(about, "version", QString(), DL_WARNING));
 	return inf;
 }
 
 QStringList RKSettingsModulePlugins::findPluginMapsRecursive (const QString &basedir) {
 	RK_TRACE (SETTINGS);
 
-	QDir dir (basedir);
-	QStringList maps = dir.entryList (QDir::Files).filter (QRegExp (".*\\.pluginmap$"));
+	QDir dir(basedir);
+	static const QRegularExpression pluginmapfile_ext((".*\\.pluginmap$"));
+	const QStringList maps = dir.entryList(QDir::Files).filter(pluginmapfile_ext);
 	QStringList ret;
-	foreach (const QString &map, maps) ret.append (dir.absoluteFilePath (map));
+	for (const QString &map : maps) {
+		ret.append(dir.absoluteFilePath(map));
+	}
 
-	QStringList subdirs = dir.entryList (QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot);
-	foreach (const QString& subdir, subdirs) {
-		ret.append (findPluginMapsRecursive (dir.absoluteFilePath (subdir)));
+	const QStringList subdirs = dir.entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot);
+	for (const QString& subdir : subdirs) {
+		ret.append(findPluginMapsRecursive(dir.absoluteFilePath(subdir)));
 	}
 
 	return ret;
@@ -418,7 +420,7 @@ RKSettingsModulePluginsModel::RKSettingsModulePluginsModel (QObject* parent) : Q
 
 RKSettingsModulePluginsModel::~RKSettingsModulePluginsModel() {
 	RK_TRACE (SETTINGS);
-	foreach (const PluginMapMetaInfo &inf, plugin_map_dynamic_info) {
+	for (const PluginMapMetaInfo &inf : std::as_const(plugin_map_dynamic_info)) {
 		delete (inf.about);
 	}
 }
@@ -538,7 +540,7 @@ bool RKSettingsModulePluginsModel::setData (const QModelIndex& index, const QVar
 			if (!plugin_maps.all_maps.contains(id)) return false;
 			auto &handle = plugin_maps.all_maps[id];
 			handle.active = value.toBool ();
-			emit dataChanged(index, index);
+			Q_EMIT dataChanged(index, index);
 			return true;
 		}
 	}
