@@ -27,7 +27,7 @@ public:
 	explicit DetachedWindowContainer (RKMDIWindow *widget_to_capture, bool copy_geometry);
 /** destructor. Usually you don't call this explicitly, but rather delete/close the child view. The DetachedWindowContainer will then self destruct via viewDestroyed () */
 	~DetachedWindowContainer ();
-public slots:
+public Q_SLOTS:
 /** self-destruct, when child view is destroyed */
 	void viewDestroyed (QObject *view);
 /** re-attach to the main window */
