@@ -1,6 +1,6 @@
 /*
 katepluginintegration - This file is part of RKWard (https://rkward.kde.org). Created: Mon Jun 12 2017
-SPDX-FileCopyrightText: 2017-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2017-2023 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,9 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QVBoxLayout>
 #include <QChildEvent>
 #include <QComboBox>
+#include <QStatusBar>
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <KTextEditor/Editor>
 #include <KTextEditor/Application>
@@ -36,25 +36,70 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "../debug.h"
 
+///  BEGIN  Helper class for tool windows
+class KatePluginWindow : public RKMDIWindow {
+	Q_OBJECT
+public:
+	explicit KatePluginWindow(QWidget *parent, bool tool_window=true) : RKMDIWindow(parent, RKMDIWindow::KatePluginWindow, tool_window) {
+		RK_TRACE (APP);
+
+		QVBoxLayout *layout = new QVBoxLayout(this);
+		layout->setContentsMargins(0, 0, 0, 0);
+		setPart(new RKDummyPart(this, this));
+		initializeActivationSignals();
+		setFocusPolicy(Qt::ClickFocus);
+	}
+	~KatePluginWindow() {
+		RK_TRACE (APP);
+	}
+
+	void showEvent(QShowEvent *e) override {
+		RKMDIWindow::showEvent(e);
+		Q_EMIT toolVisibleChanged(true);
+	}
+
+	void hideEvent(QHideEvent *e) override {
+		RKMDIWindow::hideEvent(e);
+		Q_EMIT toolVisibleChanged(false);
+	}
+
+/** This is a bit lame, but the plugin does not add itself to the parent widget's layout by itself. So we need this override
+ *  to do that. Where did the good old KVBox go? */
+	void childEvent(QChildEvent *ev) override {
+		if ((ev->type() == QEvent::ChildAdded) && ev->child()->isWidgetType()) {
+			QWidget *widget = qobject_cast<QWidget *>(ev->child()); // clazy:exclude=child-event-qobject-cast - Cast to QWidget is ok, we checked for widgetType(), above
+			if (widget) {
+				layout()->addWidget(widget);
+				setFocusProxy(widget);
+			}
+		}
+		RKMDIWindow::childEvent(ev);
+	}
+	QWidget* internalWidget() const {
+		return internal_widget;
+	}
+Q_SIGNALS:
+	void toolVisibleChanged(bool);
+private:
+	QWidget* internal_widget;
+};
+
+///  END  Helper class for tool windows
 ///  BEGIN  KTextEditor::Application interface
 
 KatePluginIntegrationApp::KatePluginIntegrationApp(QObject *parent) : QObject (parent) {
 	RK_TRACE (APP);
 
-	dummy_view = 0;
+	dummy_view = nullptr;
 	window = new KatePluginIntegrationWindow(this);
 	app = new KTextEditor::Application(this);
 	KTextEditor::Editor::instance()->setApplication(app);
 
 	// enumerate all available kate plugins
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5,89,0)
-	QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("ktexteditor"));
-#else
-	QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("ktexteditor"), [](const KPluginMetaData &) { return true; });
-#endif
+	QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf6/ktexteditor"));
 	for (int i = plugins.size() -1; i >= 0; --i) {
 		PluginInfo info;
-		info.plugin = 0;
+		info.plugin = nullptr;
 		info.data = plugins[i];
 		// Note: creates a lookup-table *and* eliminates potential dupes later in the search path
 		known_plugins.insert(idForPlugin(info.data), info);
@@ -96,43 +141,38 @@ QObject* KatePluginIntegrationApp::loadPlugin (const QString& identifier) {
 
 	if (!known_plugins.contains (identifier)) {
 		RK_DEBUG (APP, DL_WARNING, "Plugin %s is not known", qPrintable (identifier));
-		return 0;
+		return nullptr;
 	}
 
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5,86,0)
-	KPluginFactory *factory = KPluginLoader(known_plugins[identifier].data.fileName ()).factory ();
-	if (factory) {
-#endif
-		if (identifier == "katekonsoleplugin") {
-			// Workaround until https://invent.kde.org/utilities/kate/-/commit/cf11bcbf1f36e2a82b1a1b14090a3f0a2b09ecf4 can be assumed to be present (should be removed in KF6)
-			if (qEnvironmentVariableIsEmpty("EDITOR")) qputenv("EDITOR", "vi");
-		}
+	if (identifier == "katekonsoleplugin") {
+		// Workaround until https://invent.kde.org/utilities/kate/-/commit/cf11bcbf1f36e2a82b1a1b14090a3f0a2b09ecf4 can be assumed to be present (should be removed in KF6)
+		if (qEnvironmentVariableIsEmpty("EDITOR")) qputenv("EDITOR", "vi");
+	}
 
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5,86,0)
-		KTextEditor::Plugin *plugin = factory->create<KTextEditor::Plugin>(this, QVariantList () << identifier);
-#else
-		KTextEditor::Plugin *plugin = KPluginFactory::instantiatePlugin<KTextEditor::Plugin>(known_plugins[identifier].data, this, QVariantList() << identifier).plugin;
-#endif
-		if (plugin) {
-			known_plugins[identifier].plugin = plugin;
-			emit KTextEditor::Editor::instance()->application()->pluginCreated(identifier, plugin);
-			QObject* created = mainWindow()->createPluginView(plugin);
-			if (created) {
-				emit mainWindow()->main->pluginViewCreated(identifier, created);
-				KTextEditor::SessionConfigInterface *interface = qobject_cast<KTextEditor::SessionConfigInterface *>(created);
-				if (interface) {
-					// NOTE: Some plugins (noteably the Search in files plugin) will misbehave, unless readSessionConfig has been called!
-					KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("KatePlugin:%1:").arg(identifier));
-					interface->readSessionConfig(group);
-				}
+	KTextEditor::Plugin *plugin = KPluginFactory::instantiatePlugin<KTextEditor::Plugin>(known_plugins[identifier].data, this, QVariantList() << identifier).plugin;
+	if (plugin) {
+		known_plugins[identifier].plugin = plugin;
+		Q_EMIT KTextEditor::Editor::instance()->application()->pluginCreated(identifier, plugin);
+		QObject* created = mainWindow()->createPluginView(plugin);
+		if (created) {
+			Q_EMIT mainWindow()->main->pluginViewCreated(identifier, created);
+			KTextEditor::SessionConfigInterface *interface = qobject_cast<KTextEditor::SessionConfigInterface *>(created);
+			if (interface) {
+				// NOTE: Some plugins (noteably the Search in files plugin) will misbehave, unless readSessionConfig has been called!
+				KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("KatePlugin:%1:").arg(identifier));
+				interface->readSessionConfig(group);
+			}
+			interface = qobject_cast<KTextEditor::SessionConfigInterface *>(plugin);
+			if (interface) {
+				// NOTE: The session interface may be implemented in either the view or the plugin (or neither or both)
+				KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("KatePlugin_plugin:%1:").arg(identifier));
+				interface->readSessionConfig(group);
 			}
-			return plugin;
 		}
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5,86,0)
+		return plugin;
 	}
-#endif
 
-	return 0;
+	return nullptr;
 }
 
 void KatePluginIntegrationApp::loadPlugins(const QStringList& plugins) {
@@ -184,12 +224,17 @@ void KatePluginIntegrationApp::unloadPlugin(const QString &identifier) {
 			KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("KatePlugin:%1:").arg(identifier));
 			interface->writeSessionConfig(group);
 		}
-		emit mainWindow()->main->pluginViewDeleted(identifier, view);
+		interface = qobject_cast<KTextEditor::SessionConfigInterface *>(info.plugin);
+		if (interface) {
+			KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("KatePlugin_plugin:%1:").arg(identifier));
+			interface->writeSessionConfig(group);
+		}
+		Q_EMIT mainWindow()->main->pluginViewDeleted(identifier, view);
 		delete view;
 	}
-	emit app->pluginDeleted(identifier, info.plugin);
+	Q_EMIT app->pluginDeleted(identifier, info.plugin);
 	delete info.plugin;
-	info.plugin = 0;
+	info.plugin = nullptr;
 }
 
 void KatePluginIntegrationApp::saveConfigAndUnload() {
@@ -199,6 +244,12 @@ void KatePluginIntegrationApp::saveConfigAndUnload() {
 		unloadPlugin(it.key());
 	}
 	known_plugins.clear();
+
+	// "Global" tool views such as the Diagnostic Window did not get unloaded with any plugin, but need to be torn down, while KXML (factory) is still availalbe
+	if (window->plugin_resources.contains(nullptr)) {
+		const auto wins = window->plugin_resources[nullptr].windows;
+		for(auto win : wins) delete win;
+	}
 }
 
 QList<KTextEditor::MainWindow *> KatePluginIntegrationApp::mainWindows() {
@@ -223,7 +274,7 @@ RKCommandEditorWindow* findWindowForView(KTextEditor::View *view) {
 			return static_cast<RKCommandEditorWindow*>(w[i]);
 		}
 	}
-	return 0;
+	return nullptr;
 }
 
 RKCommandEditorWindow* findWindowForDocument(KTextEditor::Document *document) {
@@ -236,7 +287,7 @@ RKCommandEditorWindow* findWindowForDocument(KTextEditor::Document *document) {
 			return static_cast<RKCommandEditorWindow*>(w[i]);
 		}
 	}
-	return 0;
+	return nullptr;
 }
 
 QList<KTextEditor::Document *> KatePluginIntegrationApp::documents() {
@@ -266,7 +317,7 @@ KTextEditor::Document *KatePluginIntegrationApp::findUrl(const QUrl &url) {
 			if (v) return v->document();
 		}
 	}
-	return 0;
+	return nullptr;
 }
 
 KTextEditor::Document *KatePluginIntegrationApp::openUrl(const QUrl &url, const QString &encoding) {
@@ -274,7 +325,7 @@ KTextEditor::Document *KatePluginIntegrationApp::openUrl(const QUrl &url, const
 
 	KTextEditor::View *v = window->openUrl(url, encoding);
 	if (v) return v->document();
-	return 0;
+	return nullptr;
 }
 
 bool KatePluginIntegrationApp::closeDocument(KTextEditor::Document *document) {
@@ -313,13 +364,12 @@ KTextEditor::Plugin *KatePluginIntegrationApp::plugin(const QString &name) {
 	if (known_plugins.contains(name)) {
 		return known_plugins[name].plugin;
 	}
-	return 0;
+	return nullptr;
 }
 
 ///  END  KTextEditor::Application interface
 ///  BEGIN  KTextEditor::MainWindow interface
 
-
 KatePluginIntegrationWindow::KatePluginIntegrationWindow(KatePluginIntegrationApp *parent) : QObject(parent), KXMLGUIClient() {
 	RK_TRACE(APP);
 
@@ -338,58 +388,15 @@ KatePluginIntegrationWindow::~KatePluginIntegrationWindow() {
 	delete dynamic_actions_client;
 }
 
-
-class KatePluginToolWindow : public RKMDIWindow {
-	Q_OBJECT
-public:
-	KatePluginToolWindow(QWidget *parent) : RKMDIWindow(parent, RKMDIWindow::KatePluginWindow, true) {
-		RK_TRACE (APP);
-
-		QVBoxLayout *layout = new QVBoxLayout(this);
-		layout->setContentsMargins(0, 0, 0, 0);
-		setPart(new RKDummyPart(this, this));
-		initializeActivationSignals();
-		setFocusPolicy(Qt::ClickFocus);
-	}
-	~KatePluginToolWindow() {
-		RK_TRACE (APP);
-	}
-
-	void showEvent(QShowEvent *e) override {
-		RKMDIWindow::showEvent(e);
-		emit toolVisibleChanged(true);
-	}
-
-	void hideEvent(QHideEvent *e) override {
-		RKMDIWindow::hideEvent(e);
-		emit toolVisibleChanged(false);
-	}
-
-/** This is a bit lame, but the plugin does not add itself to the parent widget's layout by itself. So we need this override
- *  to do that. Where did the good old KVBox go? */
-	void childEvent(QChildEvent *ev) override {
-		if ((ev->type() == QEvent::ChildAdded) && ev->child()->isWidgetType()) {
-			QWidget *widget = qobject_cast<QWidget *>(ev->child()); // clazy:exclude=child-event-qobject-cast - Cast to QWidget is ok, we checked for widgetType(), above
-			if (widget) {
-				layout()->addWidget(widget);
-				setFocusProxy(widget);
-			}
-		}
-		RKMDIWindow::childEvent(ev);
-	}
-signals:
-	void toolVisibleChanged(bool);
-};
-
 QWidget* KatePluginIntegrationWindow::createToolView (KTextEditor::Plugin *plugin, const QString &identifier, KTextEditor::MainWindow::ToolViewPosition pos, const QIcon &icon, const QString &text) {
 	RK_TRACE (APP);
 
 	RK_DEBUG(APP, DL_DEBUG, "createToolView for %p, %s, position %d, %s", plugin, qPrintable(identifier), pos, qPrintable(text));
 	// TODO: Set proper RKMDIWindow:type
-	KatePluginToolWindow *window = new KatePluginToolWindow(RKWorkplace::mainWorkplace()->view());
+	KatePluginWindow *window = new KatePluginWindow(RKWorkplace::mainWorkplace()->view(), true);
 	window->setCaption(text);
 	window->setWindowIcon(icon);
-	RKToolWindowList::registerToolWindow(window, identifier, (RKToolWindowList::Placement) pos, 0);
+	RKToolWindowList::registerToolWindow(window, identifier, (RKToolWindowList::Placement) pos, QKeyCombination());
 	RKWorkplace::mainWorkplace()->placeInToolWindowBar(window, pos);
 	plugin_resources[plugin].windows.append(window);
 
@@ -408,6 +415,74 @@ bool KatePluginIntegrationWindow::showToolView (QWidget *widget) {
 	return true;
 }
 
+QWidget *KatePluginIntegrationWindow::toolviewForName(const QString &toolviewName) {
+	RK_TRACE(APP);
+	return RKToolWindowList::findToolWindowById(toolviewName);
+}
+
+bool KatePluginIntegrationWindow::addWidget(QWidget *widget) {
+	RK_TRACE(APP);
+
+	RK_DEBUG(APP, DL_DEBUG, "addWidget %p: %s", widget, qPrintable(widget->windowTitle()));
+	// TODO: Set proper RKMDIWindow:type
+	KatePluginWindow *window = new KatePluginWindow(RKWorkplace::mainWorkplace()->view(), false);
+	widget->setParent(window);
+	window->setCaption(widget->windowTitle());
+	widget->show();
+	RKWorkplace::mainWorkplace()->addWindow(window);
+	return true;
+}
+
+void KatePluginIntegrationWindow::activateWidget(QWidget *widget) {
+	RK_TRACE(APP);
+
+	QWidget *w = widget;
+	while (w) {
+		RKMDIWindow *rkw = qobject_cast<RKMDIWindow*>(w);
+		if (rkw) {
+			rkw->activate();
+			return;
+		}
+		w = w->parentWidget();
+	}
+	RK_DEBUG(APP, DL_WARNING, "no such widget found in activateWidget %p: %s", widget, widget ? qPrintable(widget->windowTitle()) : "[null]");
+}
+
+QWidgetList KatePluginIntegrationWindow::widgets() {
+	RK_TRACE(APP);
+
+	QWidgetList ret;
+	const auto list = RKWorkplace::mainWorkplace()->getObjectList();
+	for (const auto win : list) {
+		if (win->isType(RKMDIWindow::KatePluginWindow) && win->isType(RKMDIWindow::DocumentWindow)) {
+			auto w = qobject_cast<KatePluginWindow*>(win)->internalWidget();
+			if (w) {
+				ret.append(w);
+			} else {
+				RK_DEBUG(APP, DL_WARNING, "found empty kate plugin mdi wrapper");
+			}
+		}
+	}
+	return ret;
+}
+
+#include "../rbackend/rcommand.h"
+#include "rkcommandlog.h"
+bool KatePluginIntegrationWindow::showMessage(const QVariantMap &map) {
+	RK_TRACE(APP);
+
+	ROutput::ROutputType severity = ROutput::Output;
+	auto type = map["type"].toString();
+	if (type == QStringLiteral("Error")) severity = ROutput::Error;
+	else if (type == QStringLiteral("Warning")) severity = ROutput::Warning;
+	RKCommandLog::getLog()->addOtherMessage(map["text"].toString(), map["categoryicon"].value<QIcon>(), severity);
+	return true;
+}
+
+void KatePluginIntegrationWindow::insertWidgetInStatusbar(QWidget *widget) {
+	RKWorkplace::mainWorkplace()->statusBar()->insertWidget(0, widget);
+}
+
 KXMLGUIFactory *KatePluginIntegrationWindow::guiFactory () {
 	RK_TRACE (APP);
 
@@ -438,7 +513,7 @@ void KatePluginIntegrationWindow::activeWindowChanged(RKMDIWindow* window) {
 	RK_TRACE (APP);
 
 	if (window->isType(RKMDIWindow::CommandEditorWindow)) {
-		emit main->viewChanged(static_cast<RKCommandEditorWindow *>(window)->getView());
+		Q_EMIT main->viewChanged(static_cast<RKCommandEditorWindow *>(window)->getView());
 	}
 }
 
@@ -469,7 +544,7 @@ KTextEditor::View *KatePluginIntegrationWindow::activateView(KTextEditor::Docume
 		return w->getView();
 	}
 	if (app->dummy_view && document == app->dummy_view->document()) return app->dummy_view;
-	return 0;
+	return nullptr;
 }
 
 KTextEditor::View *KatePluginIntegrationWindow::openUrl(const QUrl &url, const QString &encoding) {
@@ -478,7 +553,7 @@ KTextEditor::View *KatePluginIntegrationWindow::openUrl(const QUrl &url, const Q
 	if (w) return static_cast<RKCommandEditorWindow*>(w)->getView();
 
 	RK_ASSERT(w);  // should not happen
-	return 0;
+	return nullptr;
 }
 
 QObject *KatePluginIntegrationWindow::pluginView(const QString &name) {
@@ -487,6 +562,29 @@ QObject *KatePluginIntegrationWindow::pluginView(const QString &name) {
 	return plugin_resources.value(app->plugin(name)).view;
 }
 
+/* BEGIN deliberately left unimplemented */
+QWidget *KatePluginIntegrationWindow::createViewBar(KTextEditor::View *) {
+	RK_TRACE (APP);
+	return nullptr;
+}
+
+void KatePluginIntegrationWindow::deleteViewBar(KTextEditor::View *) {
+	RK_TRACE (APP);
+}
+
+void KatePluginIntegrationWindow::showViewBar(KTextEditor::View *) {
+	RK_TRACE (APP);
+}
+
+void KatePluginIntegrationWindow::hideViewBar(KTextEditor::View *) {
+	RK_TRACE (APP);
+}
+
+void KatePluginIntegrationWindow::addWidgetToViewBar(KTextEditor::View *, QWidget *)  {
+	RK_TRACE (APP);
+}
+/* END deliberately left unimplemented */
+
 bool KatePluginIntegrationWindow::closeSplitView(KTextEditor::View* view) {
 	RK_TRACE (APP);
 
@@ -607,7 +705,7 @@ QObject* KatePluginIntegrationWindow::createPluginView(KTextEditor::Plugin* plug
 	active_plugin = plugin;
 	PluginResources& resources = plugin_resources.insert(plugin, PluginResources()).value();
 	resources.view = plugin->createView(main);
-	active_plugin = 0;
+	active_plugin = nullptr;
 	disconnect(factory(), &KXMLGUIFactory::clientAdded, this, &KatePluginIntegrationWindow::catchXMLGUIClientsHack);
 	fixUpPluginUI(app->idForPlugin(plugin), resources);
 	connect(plugin, &QObject::destroyed, this, [this, plugin]() { plugin_resources.remove(plugin); });
