@@ -1,6 +1,6 @@
 /*
 katepluginintegration - This file is part of the RKWard project. Created: Mon Jun 12 2017
-SPDX-FileCopyrightText: 2017-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2017-2023 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,6 +14,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KXMLGUIClient>
 
 #include <QMap>
+#include <QWidget>
 
 class KatePluginIntegrationWindow;
 class RKMDIWindow;
@@ -26,7 +27,7 @@ class RKMDIWindow;
 class KatePluginIntegrationApp : public QObject {
 	Q_OBJECT
 public:
-	KatePluginIntegrationApp(QObject *parent);
+	explicit KatePluginIntegrationApp(QObject *parent);
 	~KatePluginIntegrationApp();
 	QObject* loadPlugin(const QString& identifier);
 	/** Loads the given plugins, *and* unloads all others. */
@@ -34,7 +35,7 @@ public:
 	void loadPlugins(const QStringList &plugins);
 	KatePluginIntegrationWindow *mainWindow() const { return window; };
 	int knownPluginCount() const { return known_plugins.size(); };
-private slots:
+private Q_SLOTS:
 friend class KatePluginIntegrationWindow;
 	void saveConfigAndUnload();
 	// These are the implementations of the KTextEditor::Application interface.
@@ -64,15 +65,16 @@ friend class RKSettingsModuleKatePlugins;
 	QString idForPlugin(const KPluginMetaData &plugin) const;
 };
 
+class KatePluginWindow;
 class KatePluginIntegrationWindow : public QObject, public KXMLGUIClient {
 	Q_OBJECT
 public:
-	KatePluginIntegrationWindow(KatePluginIntegrationApp *parent);
+	explicit KatePluginIntegrationWindow(KatePluginIntegrationApp *parent);
 	~KatePluginIntegrationWindow();
 	KTextEditor::MainWindow *mainWindow() const { return main; };
 	KXMLGUIClient* persistentGuiClient() { return this; }
 	KXMLGUIClient* dynamicGuiClient() const { return dynamic_actions_client; }
-private slots:
+private Q_SLOTS:
 	// These are the implementations of the KTextEditor::MainWindow interface.
 	// NOTE that they are not technically overrides, but get invoked via QMetaObject::invokeMethod()
 	QWidget *createToolView(KTextEditor::Plugin *plugin, const QString &identifier, KTextEditor::MainWindow::ToolViewPosition pos, const QIcon &icon, const QString &text);
@@ -91,27 +93,40 @@ private slots:
 	bool hideToolView(QWidget *widget);
 	QObject *pluginView(const QString &name);
 
-/* Apparently, these are truely optional, so let's disable them for the time being
+	/* Apparently, these are truely optional. We provide dummy implementations anyway to
+	 * get a better signal to noise ratio in warnings.
+	 *
+	 * "Viewbar" is the area containing line number, etc. If not created by the main window,
+	 * each view gets equipped with its own bar. That may actually be preferrable, as
+	 * our global bottom bar is quite crowded, already. */
 	QWidget *createViewBar(KTextEditor::View *view);
 	void deleteViewBar(KTextEditor::View *view);
 	void showViewBar(KTextEditor::View *view);
 	void hideViewBar(KTextEditor::View *view);
-	void addWidgetToViewBar(KTextEditor::View *view, QWidget *bar); */
+	void addWidgetToViewBar(KTextEditor::View *view, QWidget *bar);
+
+// New in Kate 2023-07, not yet formalized in KTextEditor
+	QWidget *toolviewForName(const QString &toolviewName);
+	bool showMessage(const QVariantMap &map);
+	bool addWidget(QWidget *widget);
+	void activateWidget(QWidget *widget);
+	QWidgetList widgets();
+	void insertWidgetInStatusbar(QWidget *widget);
 private:
 friend class KatePluginIntegrationApp;
 	KTextEditor::MainWindow *main;
 	QObject* createPluginView(KTextEditor::Plugin* plugin);
 	struct PluginResources {
-		PluginResources() : view(0) {};
+		PluginResources() : view(nullptr) {};
 		QObject *view;
 		QList<KXMLGUIClient*> clients;
-		QList<RKMDIWindow*> windows;
+		QList<KatePluginWindow*> windows;
 	};
 	QHash<QObject*, PluginResources> plugin_resources;
 
 	KatePluginIntegrationApp *app;
 	KXMLGUIClient *dynamic_actions_client;
-private slots:
+private Q_SLOTS:
 	void catchXMLGUIClientsHack(KXMLGUIClient* client);
 	void activeWindowChanged(RKMDIWindow *window);
 private:
