@@ -16,6 +16,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QIcon>
 #include <QDir>
 #include <QAction>
+#include <QTimer>
 
 #include "../misc/rkcommonfunctions.h"
 #include "../misc/rkstandardicons.h"
@@ -30,7 +31,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 class RKCompletionNotifierModel : public RKCompletionModelBase {
 public:
-	RKCompletionNotifierModel (RKCompletionManager *manager) : RKCompletionModelBase (manager) {};
+	explicit RKCompletionNotifierModel(RKCompletionManager *manager) : RKCompletionModelBase(manager) {};
 	KTextEditor::Range completionRange (KTextEditor::View *, const KTextEditor::Cursor &position) override {
 		return KTextEditor::Range (position, position);
 	}
@@ -40,7 +41,7 @@ public:
 
 		if (invocationType == KTextEditor::CodeCompletionModel::UserInvocation) {
 			// NOTE: Without this short timeout, the completion window will sometimes disappear, again, right away.
-			QTimer::singleShot (50, manager, SLOT(userTriggeredCompletion()));
+			QTimer::singleShot(50, manager, [this](){ manager->userTriggeredCompletion();});
 		}
 	}
 	QVariant data (const QModelIndex&, int) const override {
@@ -51,22 +52,6 @@ public:
 //////////////////////// RKCompletionManager //////////////////////
 #include <KAboutData>
 #include <KMessageBox>
-bool checkSaneVersion() {
-	static enum { Unknown, Ok, Bad } version_check = Unknown;
-	if (version_check == Unknown) {
-		KAboutData d = KTextEditor::Editor::instance()->aboutData();
-		if (d.version() == "5.92.0") {
-			KMessageBox::information(nullptr, i18n("Due to a bug in version 5.92.0 of ktexteditor (the version in use, right now), the function call tip feature would"
-			                         " crash, and has been disabled in this session. To enable the call tip, install any other (earlier or later) version of (lib|kf5)ktexteditor."),
-			                         i18n("Incompatible version of ktexteditor"), "ktexteditor_v5.92.0");
-			version_check = Bad;
-		} else {
-			version_check = Ok;
-		}
-	}
-	return version_check == Ok;
-}
-
 RKCompletionManager::RKCompletionManager(KTextEditor::View* view, const RKCodeCompletionSettings *settings) : QObject(view), settings(settings) {
 	RK_TRACE (COMMANDEDITOR);
 
@@ -76,36 +61,30 @@ RKCompletionManager::RKCompletionManager(KTextEditor::View* view, const RKCodeCo
 	update_call = true;
 	cached_position = KTextEditor::Cursor (-1, -1);
 
-	cc_iface = qobject_cast<KTextEditor::CodeCompletionInterface*> (view);
-	if (cc_iface) {
-		cc_iface->setAutomaticInvocationEnabled (false);
-		completion_model = new RKCodeCompletionModel (this);
-		file_completion_model = new RKFileCompletionModel (this);
-		callhint_model = new RKCallHintModel (this);
-		arghint_model = new RKArgumentHintModel (this);
-		cc_iface->registerCompletionModel (new RKCompletionNotifierModel (this));  // (at least) one model needs to be registered, so we will know, when completion was triggered by the user (shortcut)
-		completion_timer = new QTimer (this);
-		completion_timer->setSingleShot (true);
-		connect (completion_timer, &QTimer::timeout, this, &RKCompletionManager::tryCompletion);
-		connect (view->document (), &KTextEditor::Document::textInserted, this, &RKCompletionManager::textInserted);
-		connect (view->document (), &KTextEditor::Document::textRemoved, this, &RKCompletionManager::textRemoved);
-		connect (view->document (), &KTextEditor::Document::lineWrapped, this, &RKCompletionManager::lineWrapped);
-		connect (view->document (), &KTextEditor::Document::lineUnwrapped, this, &RKCompletionManager::lineUnwrapped);
-		connect (view, &KTextEditor::View::cursorPositionChanged, this, &RKCompletionManager::cursorPositionChanged);
-		const QObjectList children = _view->children ();
-		for (QObjectList::const_iterator it = children.constBegin(); it != children.constEnd (); ++it) {
-			(*it)->installEventFilter (this);  // to handle Tab-key; installing on the view, alone, is not enough.
-		}
-
-		// HACK: I just can't see to make the object name completion model play nice with automatic invocation.
-		//       However, there is no official way to invoke all registered models, manually. So we try to hack our way
-		//       to a pointer to the default kate keyword completion model
-		kate_keyword_completion_model = KTextEditor::Editor::instance ()->findChild<KTextEditor::CodeCompletionModel *> ();
-		if (!kate_keyword_completion_model) kate_keyword_completion_model = view->findChild<KTextEditor::CodeCompletionModel *> (QString());
-
-	} else {
-		RK_ASSERT (false);  // Not a katepart?
+	view->setAutomaticInvocationEnabled (false);
+	completion_model = new RKCodeCompletionModel (this);
+	file_completion_model = new RKFileCompletionModel (this);
+	callhint_model = new RKCallHintModel (this);
+	arghint_model = new RKArgumentHintModel (this);
+	view->registerCompletionModel (new RKCompletionNotifierModel (this));  // (at least) one model needs to be registered, so we will know, when completion was triggered by the user (shortcut)
+	completion_timer = new QTimer (this);
+	completion_timer->setSingleShot (true);
+	connect (completion_timer, &QTimer::timeout, this, &RKCompletionManager::tryCompletion);
+	connect (view->document (), &KTextEditor::Document::textInserted, this, &RKCompletionManager::textInserted);
+	connect (view->document (), &KTextEditor::Document::textRemoved, this, &RKCompletionManager::textRemoved);
+	connect (view->document (), &KTextEditor::Document::lineWrapped, this, &RKCompletionManager::lineWrapped);
+	connect (view->document (), &KTextEditor::Document::lineUnwrapped, this, &RKCompletionManager::lineUnwrapped);
+	connect (view, &KTextEditor::View::cursorPositionChanged, this, &RKCompletionManager::cursorPositionChanged);
+	const QObjectList children = _view->children ();
+	for (QObjectList::const_iterator it = children.constBegin(); it != children.constEnd (); ++it) {
+		(*it)->installEventFilter (this);  // to handle Tab-key; installing on the view, alone, is not enough.
 	}
+
+	// HACK: I just can't see to make the object name completion model play nice with automatic invocation.
+	//       However, there is no official way to invoke all registered models, manually. So we try to hack our way
+	//       to a pointer to the default kate keyword completion model
+	kate_keyword_completion_model = KTextEditor::Editor::instance ()->findChild<KTextEditor::CodeCompletionModel *> ();
+	if (!kate_keyword_completion_model) kate_keyword_completion_model = view->findChild<KTextEditor::CodeCompletionModel *> (QString());
 }
 
 RKCompletionManager::~RKCompletionManager () {
@@ -113,7 +92,7 @@ RKCompletionManager::~RKCompletionManager () {
 }
 
 void RKCompletionManager::tryCompletionProxy () {
-	if (cc_iface->isCompletionActive ()) {
+	if (_view->isCompletionActive ()) {
 		// Handle this in the next event cycle, as more than one event may trigger
 		completion_timer->start (0);
 	} else if (settings->autoEnabled ()) {
@@ -139,9 +118,9 @@ void RKCompletionManager::userTriggeredCompletion () {
 
 void RKCompletionManager::tryCompletion () {
 	RK_TRACE (COMMANDEDITOR);
-	if (!cc_iface) {
+	if (!_view) {
 		// NOTE: This should not be possible, because the connections  have not been set up in the constructor, in this case.
-		RK_ASSERT (cc_iface);
+		RK_ASSERT (_view);
 		return;
 	}
 	if (ignore_next_trigger) {
@@ -164,7 +143,7 @@ void RKCompletionManager::tryCompletion () {
 		if (end > cursor_pos) {
 			symbol_range = KTextEditor::Range ();   // Only hint when at the end of a word/symbol: https://mail.kde.org/pipermail/rkward-devel/2015-April/004122.html
 		} else {
-			if (doc->defaultStyleAt (c) == KTextEditor::dsComment) symbol_range = KTextEditor::Range ();	// do not hint while in comments
+			if (doc->defaultStyleAt (c) == KSyntaxHighlighting::Theme::TextStyle::Comment) symbol_range = KTextEditor::Range ();	// do not hint while in comments
 		}
 	}
 
@@ -210,17 +189,17 @@ void RKCompletionManager::tryCompletion () {
 }
 
 bool isCode (KTextEditor::Document* doc, int line, int column) {
-	KTextEditor::DefaultStyle style = doc->defaultStyleAt (KTextEditor::Cursor (line, column));
-	if (style == KTextEditor::dsComment) return false;
-	if (style == KTextEditor::dsString) return false;
-	if (style == KTextEditor::dsChar) return false;
+	KSyntaxHighlighting::Theme::TextStyle style = doc->defaultStyleAt (KTextEditor::Cursor (line, column));
+	if (style == KSyntaxHighlighting::Theme::TextStyle::Comment) return false;
+	if (style == KSyntaxHighlighting::Theme::TextStyle::String) return false;
+	if (style == KSyntaxHighlighting::Theme::TextStyle::Char) return false;
 	return true;
 }
 
 void RKCompletionManager::updateCallHint () {
 	RK_TRACE (COMMANDEDITOR);
 
-	if (cc_iface->isCompletionActive () && !update_call) return;
+	if (_view->isCompletionActive () && !update_call) return;
 	update_call = false;
 
 	int line = cached_position.line () + 1;
@@ -270,7 +249,7 @@ void RKCompletionManager::updateCallHint () {
 	}
 
 	// now identify the symbol and object (if any)
-	RObject *object = 0;
+	RObject *object = nullptr;
 	call_opening = KTextEditor::Cursor (-1, -1);
 	if (potential_symbol_end > 0) {
 		QString effective_symbol = RKCommonFunctions::getCurrentSymbol (full_context, potential_symbol_end);
@@ -289,7 +268,7 @@ void RKCompletionManager::startModel( KTextEditor::CodeCompletionModel *model, b
 	}
 	if (start) {
 		if (!started_models.contains (model)) {
-			cc_iface->startCompletion (range, model);
+			_view->startCompletion (range, model);
 			started_models.append (model);
 		}
 		auto ci = dynamic_cast<KTextEditor::CodeCompletionModelControllerInterface*>(model);
@@ -302,7 +281,7 @@ void RKCompletionManager::startModel( KTextEditor::CodeCompletionModel *model, b
 void RKCompletionManager::updateVisibility () {
 	RK_TRACE (COMMANDEDITOR);
 
-	if (user_triggered || !cc_iface->isCompletionActive()) {
+	if (user_triggered || !_view->isCompletionActive()) {
 		started_models.clear ();
 	}
 
@@ -315,7 +294,7 @@ void RKCompletionManager::updateVisibility () {
 		startModel(kate_keyword_completion_model, min_len, symbol_range);
 	}
 // NOTE: Freaky bug in KF 5.44.0: Call hint will not show for the first time, if logically above the primary screen. TODO: provide patch for kateargumenthinttree.cpp:166pp
-	startModel(callhint_model, checkSaneVersion() && settings->isEnabled(RKCodeCompletionSettings::Calltip), currentCallRange());
+	startModel(callhint_model, settings->isEnabled(RKCodeCompletionSettings::Calltip), currentCallRange());
 	startModel(arghint_model, settings->isEnabled(RKCodeCompletionSettings::Arghint), argname_range);
 }
 
@@ -327,7 +306,7 @@ void RKCompletionManager::modelGainedLateData(RKCompletionModelBase* model) {
 }
 
 void RKCompletionManager::textInserted (KTextEditor::Document*, const KTextEditor::Cursor& position, const QString& text) {
-	if (cc_iface->isCompletionActive ()) {
+	if (_view->isCompletionActive ()) {
 		if (position < call_opening) update_call = true;
 		else if (text.contains (QChar ('(')) || text.contains (QChar (')'))) update_call = true;
 	}
@@ -335,7 +314,7 @@ void RKCompletionManager::textInserted (KTextEditor::Document*, const KTextEdito
 }
 
 void RKCompletionManager::textRemoved (KTextEditor::Document*, const KTextEditor::Range& range, const QString& text) {
-	if (cc_iface->isCompletionActive ()) {
+	if (_view->isCompletionActive ()) {
 		if (range.start () < call_opening) update_call = true;
 		else if (text.contains (QChar ('(')) || text.contains (QChar (')'))) update_call = true;
 	}
@@ -353,7 +332,7 @@ void RKCompletionManager::lineUnwrapped (KTextEditor::Document* , int ) {
 }
 
 void RKCompletionManager::cursorPositionChanged (KTextEditor::View* view, const KTextEditor::Cursor& newPosition) {
-	if (cc_iface->isCompletionActive ()) {
+	if (_view->isCompletionActive ()) {
 		if (newPosition < call_opening) update_call = true;
 		else {
 			QString text = view->document ()->text (KTextEditor::Range (newPosition, cached_position));
@@ -469,7 +448,7 @@ bool RKCompletionManager::eventFilter (QObject*, QEvent* event) {
 		RK_TRACE (COMMANDEDITOR);	// avoid loads of empty traces, putting this here
 		QKeyEvent *k = static_cast<QKeyEvent *> (event);
 
-		if (!cc_iface->isCompletionActive()) {
+		if (!_view->isCompletionActive()) {
 			if (k->type () == QEvent::ShortcutOverride) return true; // retriggered as key event
 			if (settings->tabKeyInvokesCompletion() && k->key() == Qt::Key_Tab && k->modifiers() == Qt::NoModifier) {
 				userTriggeredCompletion();
@@ -482,7 +461,7 @@ bool RKCompletionManager::eventFilter (QObject*, QEvent* event) {
 		if ((k->key() == Qt::Key_Tab) || (k->key() == Qt::Key_Return) || (k->key() == Qt::Key_Enter) || (k->key() == Qt::Key_Backtab) || (k->key() == Qt::Key_Up) || (k->key() == Qt::Key_Down)) {
 			if (onlyCallHintShown()) {
 				completion_timer->start(0);
-				cc_iface->abortCompletion(); // That's a bit lame, but the least hacky way to get the key into the document. completion_timer was started, so
+				_view->abortCompletion(); // That's a bit lame, but the least hacky way to get the key into the document. completion_timer was started, so
 							// the completion window should come back up, without delay
 				return false;
 			}
@@ -494,7 +473,7 @@ bool RKCompletionManager::eventFilter (QObject*, QEvent* event) {
 				return true;
 			}
 			bool callhint_active = started_models.contains(callhint_model);
-			cc_iface->forceCompletion();
+			_view->forceCompletion();
 			started_models.clear();  // forceCompletion(), also aborts. Keep track of that.
 // TODO: If nothing was actually modified, should return press be sent? Configurable?
 			completion_timer->stop();  // do not bring up completion right again, but do restore the call-hint, if applicable
@@ -526,7 +505,7 @@ bool RKCompletionManager::eventFilter (QObject*, QEvent* event) {
 				if (candidate_completions.size() == 1) {
 					// Ouch, how messy. We want to make sure completion stops (except for any call hints), and is not re-triggered by the insertion, itself
 					bool callhint_active = started_models.contains(callhint_model);
-					cc_iface->abortCompletion ();
+					_view->abortCompletion ();
 					started_models.clear ();
 					completion_timer->stop();
 					if (callhint_active) startModel(callhint_model, true, currentCallRange());
@@ -535,7 +514,7 @@ bool RKCompletionManager::eventFilter (QObject*, QEvent* event) {
 				QApplication::beep ();
 			}
 			return true;
-		} else if ((k->key () == Qt::Key_Up || k->key () == Qt::Key_Down) && cc_iface->isCompletionActive ()) {
+		} else if ((k->key () == Qt::Key_Up || k->key () == Qt::Key_Down) && _view->isCompletionActive ()) {
 			bool navigate = (settings->cursorNavigatesCompletions() && k->modifiers() == Qt::NoModifier) || (!settings->cursorNavigatesCompletions() && k->modifiers() == Qt::AltModifier);
 
 			// Make up / down-keys (without alt) navigate in the document (aborting the completion)
@@ -550,16 +529,16 @@ bool RKCompletionManager::eventFilter (QObject*, QEvent* event) {
 
 				// No, we cannot just send a fake key event, easily...
 				KActionCollection *kate_edit_actions = view ()->findChild<KActionCollection*> ("edit_actions");
-				QAction *action = kate_edit_actions ? (kate_edit_actions->action (k->key () == Qt::Key_Up ? "move_line_up" : "move_line_down")) : 0;
+				QAction *action = kate_edit_actions ? (kate_edit_actions->action (k->key () == Qt::Key_Up ? "move_line_up" : "move_line_down")) : nullptr;
 				if (!action) {
 					kate_edit_actions = view ()->actionCollection ();
-					action = kate_edit_actions ? (kate_edit_actions->action (k->key () == Qt::Key_Up ? "move_line_up" : "move_line_down")) : 0;
+					action = kate_edit_actions ? (kate_edit_actions->action (k->key () == Qt::Key_Up ? "move_line_up" : "move_line_down")) : nullptr;
 				}
 				if (action) action->trigger ();
 				else RK_ASSERT (action);
 				return true;
 			} else {
-				cc_iface->abortCompletion ();
+				_view->abortCompletion ();
 				return false;
 			}
 		}
@@ -736,7 +715,7 @@ QStringList RKCodeCompletionModel::rawPartialCompletions() const {
 //////////////////////// RKCallHintModel //////////////////////////
 RKCallHintModel::RKCallHintModel (RKCompletionManager* manager) : RKCompletionModelBase (manager) {
 	RK_TRACE (COMMANDEDITOR);
-	function = 0;
+	function = nullptr;
 }
 
 // TODO: There could be more than one function by a certain name, and we could support this!
@@ -753,16 +732,11 @@ void RKCallHintModel::setFunction(RObject* _function) {
 		QStringList args = fo->argumentNames ();
 		QStringList defs = fo->argumentDefaults ();
 
-		name = function->getFullName ();
-
 		formals = '(';
 		formatting.clear ();
-		KTextEditor::Attribute format;
-//		format.setFontBold (); // NOTE: Not good. makes size mis-calculation worse.
-		format.setForeground (QBrush (Qt::green));  // But turns out purple?!
+		QTextCharFormat format;
+		format.setForeground(QBrush(Qt::green));
 
-		// NOTE: Unfortunately, adding new-lines within (long) formals does not work. If this issue turns out to be relevant, we'll have to resort to breaking the formals into
-		// several (dummy) items.
 		int pos = 1;
 		for (int i = 0; i < args.size (); ++i) {
 			QString pair = args[i];
@@ -793,7 +767,6 @@ QVariant RKCallHintModel::data (const QModelIndex& index, int role) const {
 	if (role == Qt::DisplayRole) {
 		if (col == KTextEditor::CodeCompletionModel::Prefix) return (name);
 		if (col == KTextEditor::CodeCompletionModel::Arguments) return (formals);
-		if (col == KTextEditor::CodeCompletionModel::Postfix) return ("        "); // Size is off a bit for KF5 5.44.0. Provide some padding to work around cut-off parts.
 	} else if (role == KTextEditor::CodeCompletionModel::ArgumentHintDepth) {
 		return 1;
 	} else if (role == KTextEditor::CodeCompletionModel::CompletionRole) {
@@ -801,7 +774,7 @@ QVariant RKCallHintModel::data (const QModelIndex& index, int role) const {
 	} else if (role == KTextEditor::CodeCompletionModel::HighlightingMethod) {
 		if (col == KTextEditor::CodeCompletionModel::Arguments) return KTextEditor::CodeCompletionModel::CustomHighlighting;
 	} else if (role == KTextEditor::CodeCompletionModel::CustomHighlight) {
-		if (col == KTextEditor::CodeCompletionModel::Arguments)  return formatting;
+		if (col == KTextEditor::CodeCompletionModel::Arguments) return formatting;
 	} else if (role == KTextEditor::CodeCompletionModel::MatchQuality) {
 		return (10);
 	}
@@ -945,12 +918,12 @@ void RKFileCompletionModelWorker::run () {
 		exes = comp.allMatches ();
 	}
 
-	emit completionsReady(string, exes, files);
+	Q_EMIT completionsReady(string, exes, files);
 }
 
 RKFileCompletionModel::RKFileCompletionModel (RKCompletionManager* manager) : RKCompletionModelBase (manager) {
 	RK_TRACE (COMMANDEDITOR);
-	worker = 0;
+	worker = nullptr;
 }
 
 RKFileCompletionModel::~RKFileCompletionModel () {
@@ -983,7 +956,7 @@ void RKFileCompletionModel::completionsReady (const QString& string, const QStri
 	RK_TRACE (COMMANDEDITOR);
 
 	RK_DEBUG (COMMANDEDITOR, DL_DEBUG, "Filename completion finished for '%s': %d matches", qPrintable (string), files.size () + exes.size ());
-	worker = 0;
+	worker = nullptr;
 	if (current_fragment == string) {
 		beginResetModel ();
 		names = files + exes; // TODO: This could be prettier
@@ -1050,7 +1023,7 @@ void RKDynamicCompletionsAddition::update(const QString &mode, const QString &fr
 		current_filterlist = filterlist;
 		if (status == Ready) filterResults(); // no update was triggered, above, need to update filter, manually
 	}
-	if (status == Ready) emit resultsComplete();
+	if (status == Ready) Q_EMIT resultsComplete();
 }
 
 void RKDynamicCompletionsAddition::doUpdateFromR() {
@@ -1084,7 +1057,7 @@ void RKDynamicCompletionsAddition::doUpdateFromR() {
 		}
 		filterResults();
 		status = Ready;
-		emit resultsComplete();
+		Q_EMIT resultsComplete();
 	});
 	RInterface::issueCommand(command);
 }
