@@ -15,7 +15,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <ktexteditor/view.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/movingrange.h>
-#include <ktexteditor/movinginterface.h>
 
 #include <QUrl>
 
@@ -28,8 +27,7 @@ class QFrame;
 class QLabel;
 class QAction;
 class QActionGroup;
-class QTemporaryDir;
-class QFile;
+class RKScriptPreviewIO;
 class KActionMenu;
 class RKCommandEditorWindow;
 class KActionCollection;
@@ -41,7 +39,7 @@ class KActionCollection;
 class RKCommandEditorWindowPart : public KParts::Part {
 protected:
 friend class RKCommandEditorWindow;
-	RKCommandEditorWindowPart (QWidget *parent);
+	explicit RKCommandEditorWindowPart(QWidget *parent);
 	~RKCommandEditorWindowPart ();
 };
 
@@ -85,7 +83,7 @@ public:
 /** destructor */
 	~RKCommandEditorWindow ();
 /** returns, whether the document was modified since the last save */
-	bool isModified () override;
+	bool isModified() const override;
 /** saves the document, returns true on success */
 	bool save () override;
 /** insert the given text into the document at the current cursor position. Additionally, focuses the view */
@@ -115,7 +113,7 @@ public:
 	void highlightLine (int linenum);
 /** Returns the (main, non-preview) texteditor view in this editor. */
 	KTextEditor::View* getView () const { return m_view; };
-public slots:
+public Q_SLOTS:
 /** update Tab caption according to the current url. Display the filename-component of the URL, or - if not available - a more elaborate description of the url. Also appends a "[modified]" if appropriate */
 	void updateCaption ();
 	void focusIn (KTextEditor::View *);
@@ -140,14 +138,14 @@ protected:
 /** reimplemented from RKMDIWindow: give the editor window a chance to object to being closed (if unsaved) */
 	void closeEvent (QCloseEvent *e) override;
 	void setWindowStyleHint (const QString& hint) override;
-private slots:
+private Q_SLOTS:
 /** mark current selection as a block */
-	void markBlock ();
+	void markBlock(int index);
 /** unmark a block */
-	void unmarkBlock ();
+	void unmarkBlock(int index);
 /** run a block */
-	void runBlock ();
-	void clearUnusedBlocks ();
+	void runBlock(int index);
+	void clearUnusedBlocks();
 /** handler to control when autosaves should be created, preview should be updated */
 	void textChanged ();
 /** Render the (.Rmd) current script */
@@ -161,11 +159,11 @@ private slots:
 /** document was saved. Update preview, if appropriate */
 	void documentSaved ();
 private:
+friend class RKWardCoreTest;
 	void urlChanged();
 	KTextEditor::Cursor saved_scroll_position;
 	KTextEditor::Document *m_doc;
 	KTextEditor::View *m_view;
-	KTextEditor::MovingInterface *smart_iface;
 
 	void initializeActions (KActionCollection* ac);
 
@@ -192,14 +190,6 @@ private:
 	QAction* action_no_preview;
 	QAction* action_preview_as_you_type;
 
-	enum PreviewMode {
-		NoPreview,
-		RMarkdownPreview,
-		RKOutputPreview,
-		GraphPreview,
-		ConsolePreview,
-	};
-
 	QAction* action_setwd_to_script;
 
 	QUrl previous_autosave_url;
@@ -211,11 +201,21 @@ private:
 	QString _id;
 	static QMap<QString, KTextEditor::Document*> unnamed_documents;
 
+	struct PreviewMode {
+		QIcon icon;
+		QString actionlabel;
+		QString previewlabel;
+		QString tooltip;
+		QString input_ext;
+		std::function<QString(const QString&, const QString&, const QString&)> command;
+	};
+	QList<PreviewMode> preview_mode_list;
+	void initPreviewModes();
+
 	RKXMLGUIPreviewArea *preview;
 	QTimer preview_timer;
 	RKPreviewManager *preview_manager;
-	QTemporaryDir *preview_dir;
-	QFile *preview_input_file;
+	RKScriptPreviewIO *preview_io;
 	void changePreviewMode (QAction* mode);
 	void discardPreview ();
 };
