@@ -1,6 +1,6 @@
 /*
 rkcommandlog - This file is part of RKWard (https://rkward.kde.org). Created: Sun Nov 3 2002
-SPDX-FileCopyrightText: 2002-2010 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2002-2023 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,7 +27,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../debug.h"
 
 //static
-RKCommandLog *RKCommandLog::rkcommand_log = 0;
+RKCommandLog *RKCommandLog::rkcommand_log = nullptr;
 
 RKCommandLog::RKCommandLog (QWidget *parent, bool tool_window, const char *name) : RKMDIWindow (parent, CommandLogWindow, tool_window, name) {
 	RK_TRACE (APP);
@@ -73,6 +73,30 @@ void RKCommandLog::addInput (RCommand *command) {
 	addInputNoCheck (command);
 }
 
+void RKCommandLog::addOtherMessage(const QString &message, const QIcon &icon, ROutput::ROutputType severity) {
+	RK_TRACE(APP);
+
+	if (!icon.isNull()) {
+		auto doc = log_view->document();
+		QUrl uri = QUrl(QString("internalicon://%1.png").arg(icon.name()));
+		doc->addResource(QTextDocument::ImageResource, uri, QVariant(icon.pixmap(16,16)));
+		QTextImageFormat f;
+		f.setWidth(16);
+		f.setHeight(16);
+		f.setName(uri.toString());;
+		log_view->textCursor().insertImage(f);
+	}
+
+	if (severity != ROutput::Output) {
+		QTextBlockFormat f;
+		f.setBackground(QBrush(QColor(255, 255, 255)));
+		log_view->textCursor().mergeBlockFormat(f);
+	}
+	log_view->insertPlainText(message + '\n');
+	log_view->setFontWeight(QFont::Normal);
+	log_view->setTextColor(Qt::black);
+}
+
 void RKCommandLog::addInputNoCheck (RCommand *command) {
 	RK_TRACE (APP);
 	if (command_input_shown.contains (command)) return;		// already shown
@@ -238,7 +262,7 @@ RKCommandLogView::~RKCommandLogView () {
 void RKCommandLogView::contextMenuEvent(QContextMenuEvent *event) {
 	RK_TRACE(APP);
 
-	emit popupMenuRequest(event->globalPos());
+	Q_EMIT popupMenuRequest(event->globalPos());
 	event->accept();
 }
 
@@ -256,7 +280,7 @@ void RKCommandLogView::selectAll () {
 #include <QAction>
 #include <QGuiApplication>
 
-RKCommandLogPart::RKCommandLogPart (RKCommandLog *for_log) : KParts::Part (0) {
+RKCommandLogPart::RKCommandLogPart(RKCommandLog *for_log) : KParts::Part(nullptr) {
 	RK_TRACE (APP);
 
 	setComponentName (QCoreApplication::applicationName (), QGuiApplication::applicationDisplayName ());
@@ -271,10 +295,10 @@ RKCommandLogPart::~RKCommandLogPart () {
 void RKCommandLogPart::initActions () {
 	RK_TRACE (APP);
 
-	copy = actionCollection ()->addAction (KStandardAction::Copy, "log_copy", log->getView (), SLOT (copy()));
-	actionCollection ()->addAction (KStandardAction::Clear, "log_clear", log, SLOT (clearLog()));
-	actionCollection ()->addAction (KStandardAction::SelectAll, "log_select_all", log->getView (), SLOT (selectAll()));
-	QAction *configure = actionCollection ()->addAction ("log_configure", log, SLOT(configureLog()));
+	copy = actionCollection()->addAction(KStandardAction::Copy, "log_copy", log->getView(), &RKCommandLogView::copy);
+	actionCollection()->addAction(KStandardAction::Clear, "log_clear", log, &RKCommandLog::clearLog);
+	actionCollection()->addAction(KStandardAction::SelectAll, "log_select_all", log->getView(), &RKCommandLogView::selectAll);
+	QAction *configure = actionCollection()->addAction("log_configure", log, &RKCommandLog::configureLog);
 	configure->setText (i18n ("Configure"));
 
 	run_selection = RKStandardActions::runCurrent (log, log, SLOT(runSelection()));
