@@ -1,6 +1,6 @@
 /*
 rkcommandlog - This file is part of the RKWard project. Created: Sun Nov 3 2002
-SPDX-FileCopyrightText: 2002-2010 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2002-2023 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,6 +30,8 @@ public:
 	void addInput (RCommand *command);
 /** Adds output to the log_view-window (i.e. replies received) */
 	void newOutput (RCommand *command, ROutput *output_fragment);
+/** Adds output not originating from R. Note: Currently used from kate plugins, only, see katepluginintegration.cpp */
+	void addOtherMessage(const QString &message, const QIcon &icon, ROutput::ROutputType severity);
 
 	static RKCommandLog *getLog () { return rkcommand_log; };
 
@@ -38,9 +40,9 @@ protected:
 friend class RCommand;
 /** Command has finished. If the command has failed, it may be necessary to print some more information */
 	void rCommandDone (RCommand *command);
-	RKCommandLog (QWidget *parent, bool tool_window, const char *name=0);
-	~RKCommandLog ();
-public slots:
+	RKCommandLog(QWidget *parent, bool tool_window, const char *name=nullptr);
+	~RKCommandLog();
+public Q_SLOTS:
 /** configures the log_view-window */
 	void configureLog ();
 /** clears the log_view-window */
@@ -69,9 +71,9 @@ class RKCommandLogView : public QTextEdit {
 public:
 	explicit RKCommandLogView (RKCommandLog *parent);
 	~RKCommandLogView ();
-public slots:
+public Q_SLOTS:
 	void selectAll ();
-signals:
+Q_SIGNALS:
 	void popupMenuRequest (const QPoint &pos);
 protected:
 	void contextMenuEvent (QContextMenuEvent *event) override;
@@ -89,7 +91,7 @@ public:
 	~RKCommandLogPart ();
 
 	void initActions ();
-public slots:
+public Q_SLOTS:
 	void doPopupMenu (const QPoint &pos);
 private:
 	RKCommandLog *log;
