@@ -25,8 +25,8 @@ class QAction;
 class RKFileBrowser : public RKMDIWindow {
 	Q_OBJECT
 public:
-	RKFileBrowser (QWidget *parent, bool tool_window, const char *name=0);
-	~RKFileBrowser ();
+	RKFileBrowser(QWidget *parent, bool tool_window, const char *name=nullptr);
+	~RKFileBrowser();
 
 /** reimplemented to create the real file browser widget only when the file browser is shown for the first time */
 	void showEvent (QShowEvent *e) override;
@@ -48,7 +48,7 @@ public:
 	~RKFileBrowserWidget ();
 
 	bool eventFilter (QObject* o, QEvent* e) override;
-public slots:
+public Q_SLOTS:
 	void setURL (const QUrl &url);
 	void urlChangedInView (const QUrl &url);
 	void stringChangedInCombo (const QString &url);
