@@ -1,17 +1,16 @@
 /*
 rkhtmlwindow - This file is part of RKWard (https://rkward.kde.org). Created: Wed Oct 12 2005
-SPDX-FileCopyrightText: 2005-2022 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2005-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "rkhtmlwindow.h"
 
 #include <KLocalizedString>
-#include <kmessagebox.h>
-#include <kparts/plugin.h>
+#include <KMessageBox>
 #include <kactioncollection.h>
 #include <kdirwatch.h>
-#include <kio/job.h>
+#include <KIO/StoredTransferJob>
 #include <kservice.h>
 #include <kcodecaction.h>
 #include <KColorScheme>
@@ -22,8 +21,8 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <qfileinfo.h>
 #include <qwidget.h>
 #include <qlayout.h>
-#include <qtimer.h>
-#include <qdir.h>
+#include <QTimer>
+#include <QDir>
 #include <QHBoxLayout>
 #include <QHostInfo>
 #include <QPrintDialog>
@@ -37,6 +36,18 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QMimeDatabase>
 #include <QCheckBox>
 #include <QFileDialog>
+#include <QStringEncoder>
+#include <QWebEngineUrlSchemeHandler>
+#include <QWebEngineUrlRequestJob>
+#include <QBuffer>
+#include <QWebEnginePage>
+#include <QWebEngineView>
+#include <QWebEngineSettings>
+#include <QWebEngineProfile>
+#include <QWebEngineScript>
+#include <QWebEngineScriptCollection>
+#include <QWheelEvent>
+#include <QWebEngineFindTextResult>
 
 #include "../rbackend/rkrinterface.h"
 #include "rkhelpsearchwindow.h"
@@ -47,7 +58,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../settings/rksettings.h"
 #include "../settings/rksettingsmoduleoutput.h"
 #include "../misc/rkcommonfunctions.h"
-#include "../misc/rkcompatibility.h"
 #include "../misc/rkstandardactions.h"
 #include "../misc/rkstandardicons.h"
 #include "../misc/xmlhelper.h"
@@ -66,76 +76,23 @@ QUrl restorableUrl(const QUrl &url) {
 	return QUrl(url.url().replace(RKSettingsModuleR::helpBaseUrl(), "rkward://RHELPBASE"));
 }
 
-#ifdef NO_QT_WEBENGINE
-#	include <QWebFrame>
-#	include <QNetworkRequest>
-#	include <kwebpage.h>
-#	include <kwebview.h>
-class RKWebPage : public KWebPage {
-#else
-#	include <QWebEnginePage>
-#	include <QWebEngineView>
-#	include <QWebEngineSettings>
-#	include <QWebEngineProfile>
-#	include <QWebEngineScript>
-#	include <QWebEngineScriptCollection>
 class RKWebPage : public QWebEnginePage {
-#endif
 	Q_OBJECT
 public:
-#ifdef NO_QT_WEBENGINE
-// NOTE: According to an earlier note at this place, KIOIntegration used to be very buggy around KF5 5.9.0. It seem to just work,
-//       at 5.44.0, and the symptoms are probably not terrible for earlier versions, so we use it here (allows us to render help:/-pages
-//       inside the help window.
-	explicit RKWebPage (RKHTMLWindow* window): KWebPage (window, KPartsIntegration | KIOIntegration) {
-#else
 	explicit RKWebPage (RKHTMLWindow* window): QWebEnginePage (window) {
-#endif
 		RK_TRACE (APP);
 		RKWebPage::window = window;
 		direct_load = false;
-#ifdef NO_QT_WEBENGINE
-		settings ()->setFontFamily (QWebSettings::StandardFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont).family ());
-		settings ()->setFontFamily (QWebSettings::FixedFont, QFontDatabase::systemFont(QFontDatabase::FixedFont).family ());
-#else
 		settings ()->setFontFamily (QWebEngineSettings::StandardFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont).family ());
 		settings ()->setFontFamily (QWebEngineSettings::FixedFont, QFontDatabase::systemFont(QFontDatabase::FixedFont).family ());
-#endif
 	}
 
 	void load (const QUrl& url) {
 		RK_TRACE (APP);
 		direct_load = true;
-#ifdef NO_QT_WEBENGINE
-		mainFrame ()->load (url);
-#else
 		QWebEnginePage::load (url);
-#endif
 	}
 
-#ifdef NO_QT_WEBENGINE
-	QUrl url () {
-		return mainFrame ()->url ();
-	}
-	void setHtmlWrapper(const QString &html, const QUrl &baseurl) {
-		direct_load = true;
-		mainFrame()->setHtml(html, baseurl);
-	}
-	QPointF scrollPosition () const {
-		return mainFrame ()->scrollPosition ();
-	}
-	void setScrollPosition (const QPoint &pos)  {
-		mainFrame ()->setScrollPosition (pos);
-	}
-	void setScrollPositionWhenDone(const QPoint &pos)  {
-		QMetaObject::Connection * const connection = new QMetaObject::Connection;
-		*connection = connect(this, &QWebPage::loadFinished, [this, pos, connection](){
-			QObject::disconnect(*connection);
-			delete connection;
-			setScrollPosition(pos);
-		});
-	}
-#else
 	void setHtmlWrapper(const QString &html, const QUrl &baseurl) {
 		direct_load = true;
 		setHtml(html, baseurl);
@@ -159,21 +116,12 @@ public:
 			setScrollPosition(pos);
 		});
 	}
-#endif
 
-signals:
+Q_SIGNALS:
 	void pageInternalNavigation (const QUrl& url);
 protected:
-#ifdef NO_QT_WEBENGINE
-/** reimplemented to always emit linkClicked() for pages that need special handling (importantly, rkward://-urls). */
-	bool acceptNavigationRequest (QWebFrame* frame, const QNetworkRequest& request, QWebPage::NavigationType type) override {
-		QUrl navurl = request.url ();
-		QUrl cururl (mainFrame ()->url ());
-		bool is_main_frame = frame == mainFrame ();
-#else
 	bool acceptNavigationRequest (const QUrl &navurl, QWebEnginePage::NavigationType type, bool is_main_frame) override {
 		QUrl cururl (url ());
-#endif
 		Q_UNUSED (type);
 
 		RK_TRACE (APP);
@@ -199,7 +147,7 @@ protected:
 
 		if (cururl.matches (navurl, QUrl::NormalizePathSegments | QUrl::StripTrailingSlash)) {
 			RK_DEBUG (APP, DL_DEBUG, "Page internal navigation request from %s to %s", qPrintable (cururl.toString ()), qPrintable (navurl.toString ()));
-			emit pageInternalNavigation(navurl);
+			Q_EMIT pageInternalNavigation(navurl);
 			return true;
 		}
 
@@ -207,16 +155,10 @@ protected:
 		return false;
 	}
 
-#ifdef NO_QT_WEBENGINE
-/** reimplemented to schedule new window creation for the next page to load */
-	QWebPage* createWindow (QWebPage::WebWindowType) override {
-#else
 	QWebEnginePage* createWindow (QWebEnginePage::WebWindowType) override {
-#endif
 		RK_TRACE (APP);
 		RKWebPage *ret = new RKWebPage (nullptr);
 		RKHTMLWindow::new_window = ret; // Don't actually create a full window, until we know which URL we're talking about.
-#ifndef NO_QT_WEBENGINE
 		// sigh: acceptNavigationRequest() does  not get called on the new page...
 		QMetaObject::Connection * const connection = new QMetaObject::Connection;
 		*connection = connect (ret, &RKWebPage::loadStarted, [ret, connection
@@ -228,7 +170,6 @@ protected:
 			delete connection;
 			ret->acceptNavigationRequest (ret->url (), QWebEnginePage::NavigationTypeLinkClicked, true);
 		});
-#endif
 		return (ret);
 	}
 
@@ -237,18 +178,12 @@ friend class RKHTMLWindow;
 	bool direct_load;
 };
 
-#ifdef NO_QT_WEBENGINE
-class RKWebView : public KWebView {
-public:
-	RKWebView (QWidget *parent) : KWebView (parent, false) {};
-#else
-#include <QWheelEvent>
 class RKWebView : public QWebEngineView {
 public:
-	RKWebView (QWidget *parent) : QWebEngineView (parent) {};
-	void print (QPrinter *printer) {
-		if (!page ()) return;
-		page ()->print (printer, [](bool){});
+	explicit RKWebView(QWidget *parent) : QWebEngineView(parent) {};
+	void print(QPrinter *printer) {
+		if (!page()) return;
+		QWebEngineView::forPage(page())->print(printer);
 	};
 protected:
 	bool eventFilter(QObject *, QEvent *event) override {
@@ -270,17 +205,13 @@ protected:
 /*	void wheelEvent (QWheelEvent *event) override {
 		[handle zooming]
 	} */
-#endif
 };
 
-#ifndef NO_QT_WEBENGINE
-#include <QWebEngineUrlSchemeHandler>
-#include <QWebEngineUrlRequestJob>
-#include <QBuffer>
 class RKWebEngineKIOForwarder : public QWebEngineUrlSchemeHandler {
 public:
-	RKWebEngineKIOForwarder (QObject *parent) : QWebEngineUrlSchemeHandler (parent) {}
+	explicit RKWebEngineKIOForwarder(QObject *parent) : QWebEngineUrlSchemeHandler(parent) {}
 	void requestStarted (QWebEngineUrlRequestJob *request) override {
+		RK_DEBUG(APP, DL_DEBUG, "new KIO request to %s", qPrintable(request->requestUrl().url()));
 		KIO::StoredTransferJob *job = KIO::storedGet(request->requestUrl (), KIO::NoReload, KIO::HideProgressInfo);
 		connect (job, &KIO::StoredTransferJob::result, this, [this, job](){ kioJobFinished(job); });
 		jobs.insert (job, request);
@@ -301,14 +232,13 @@ private:
 	}
 	QMap<KIO::StoredTransferJob*,QPointer<QWebEngineUrlRequestJob>> jobs;
 };
-#endif
 
 
 RKWebPage* RKHTMLWindow::new_window = nullptr;
 RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (parent, RKMDIWindow::HelpWindow) {
 	RK_TRACE (APP);
 
-	current_cache_file = 0;
+	current_cache_file = nullptr;
 	QVBoxLayout* layout = new QVBoxLayout (this);
 	layout->setContentsMargins (0, 0, 0, 0);
 	view = new RKWebView (this);
@@ -322,15 +252,11 @@ RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (par
 	view->setPage (page);
 	view->setContextMenuPolicy (Qt::CustomContextMenu);
 	layout->addWidget (view, 1);
-#ifdef NO_QT_WEBENGINE
-	findbar = new RKFindBar (this);
-#else
 	findbar = new RKFindBar (this, true);
 	findbar->setPrimaryOptions (QList<QWidget*>() << findbar->getOption (RKFindBar::FindAsYouType) << findbar->getOption (RKFindBar::MatchCase));
 	if (!QWebEngineProfile::defaultProfile ()->urlSchemeHandler ("help")) {
 		QWebEngineProfile::defaultProfile ()->installUrlSchemeHandler ("help", new RKWebEngineKIOForwarder (RKWardMainWindow::getMain()));
 	}
-#endif
 	// Apply current color scheme to page. This needs support in the CSS of the page, so will only work for RKWard help and output pages.
 	// Note that the CSS in those pages also has "automatic" support for dark mode ("prefers-color-scheme: dark"; but see https://bugreports.qt.io/browse/QTBUG-89753), however, 
 	// for a seamless appearance, the only option is to set the theme colors dynamically, via javascript.
@@ -343,21 +269,18 @@ RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (par
 	                                                "rksetcolor('--shadow-color', '%5');").arg(scheme->foreground().color().name(), scheme->background().color().name(),
 	                                                scheme->foreground(KColorScheme::VisitedText).color().name(), scheme->foreground(KColorScheme::LinkText).color().name(),
 	                                                scheme->shade(KColorScheme::MidShade).name());
-#ifdef NO_QT_WEBENGINE
-	connect(page, &RKWebPage::loadFinished, [this, color_scheme_js](){
-		page->mainFrame()->evaluateJavaScript(color_scheme_js);
-	});
-#else
 	auto p = QWebEngineProfile::defaultProfile();
 	QWebEngineScript fix_color_scheme;
-	QString id = QStringLiteral("fix_color_scheme");
-	p->scripts()->remove(p->scripts()->findScript(id));  // remove any existing variant of the script. It might have been created for the wrong theme.
+	const QString id = QStringLiteral("fix_color_scheme");
+	const auto scripts = p->scripts()->find(id);
+	for (const auto &script : scripts) {
+		p->scripts()->remove(script);  // remove any existing variant of the script. It might have been created for the wrong theme.
+	}
 	fix_color_scheme.setName(id);
 	fix_color_scheme.setInjectionPoint(QWebEngineScript::DocumentReady);
 	fix_color_scheme.setSourceCode(color_scheme_js);
 	p->scripts()->insert(fix_color_scheme);
 	//page->setBackgroundColor(scheme.background().color());  // avoids brief white blink while loading, but is too risky on pages that are not dark scheme aware.
-#endif
 
 	layout->addWidget (findbar);
 	findbar->hide ();
@@ -368,36 +291,22 @@ RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (par
 	setPart (part);
 	part->initActions ();
 	initializeActivationSignals ();
-#if KPARTS_VERSION < QT_VERSION_CHECK(5, 72, 0)
-	part->setSelectable (true);
-#endif
 	setFocusPolicy (Qt::StrongFocus);
 	setFocusProxy (view);
 
 	// We have to connect this in order to allow browsing.
 	connect (page, &RKWebPage::pageInternalNavigation, this, &RKHTMLWindow::internalNavigation);
-#ifdef NO_QT_WEBENGINE
-	connect (page, &QWebPage::downloadRequested, [this](const QNetworkRequest &request) { page->downloadUrl (request.url ()); });
-#else
-	connect (page->profile (), &QWebEngineProfile::downloadRequested, this, [this](QWebEngineDownloadItem* item) {
+	connect (page->profile (), &QWebEngineProfile::downloadRequested, this, [this](QWebEngineDownloadRequest* item) {
 		QString defpath;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 		defpath = QDir(item->downloadDirectory()).absoluteFilePath(item->downloadFileName());
-#else
-		defpath = item->path();
-#endif
 		QString path = QFileDialog::getSaveFileName(this, i18n("Save as"), defpath);
 		if (path.isEmpty()) return;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 		QFileInfo fi(path);
 		item->setDownloadDirectory(fi.absolutePath());
 		item->setDownloadFileName(fi.fileName());
-#else
-		item->setPath(path);
-#endif
 		item->accept();
 	});
-#endif
+
 	connect (page, &RKWebPage::printRequested, this, &RKHTMLWindow::slotPrint);
 	connect (view, &QWidget::customContextMenuRequested, this, &RKHTMLWindow::makeContextMenu);
 
@@ -423,15 +332,10 @@ QUrl RKHTMLWindow::restorableUrl () {
 	return ::restorableUrl(current_url);
 }
 
-bool RKHTMLWindow::isModified () {
-	RK_TRACE (APP);
-	return false;
-}
-
 void RKHTMLWindow::makeContextMenu (const QPoint& pos) {
 	RK_TRACE (APP);
 
-	QMenu *menu = page->createStandardContextMenu ();
+	QMenu *menu = QWebEngineView::forPage(page)->createStandardContextMenu ();
 	menu->addAction (part->run_selection);
 	menu->exec (view->mapToGlobal (pos));
 	delete (menu);
@@ -457,26 +361,16 @@ void RKHTMLWindow::runSelection () {
 void RKHTMLWindow::findRequest (const QString& text, bool backwards, const RKFindBar* findbar, bool* found) {
 	RK_TRACE (APP);
 
-#ifdef NO_QT_WEBENGINE
-	QWebPage::FindFlags flags = QWebPage::FindWrapsAroundDocument;
-	if (backwards) flags |= QWebPage::FindBackward;
-	bool highlight = findbar->isOptionSet (RKFindBar::HighlightAll);
-	if (highlight) flags |= QWebPage::HighlightAllOccurrences;
-	if (findbar->isOptionSet (RKFindBar::MatchCase)) flags |= QWebPage::FindCaseSensitively;
-
-	// clear previous highlight, if any
-	if (have_highlight) page->findText (QString (), QWebPage::HighlightAllOccurrences);
-
-	*found = page->findText (text, flags);
-	have_highlight = found && highlight;
-#else
 	// QWebEngine does not offer highlight all
 	*found = true;
 	QWebEnginePage::FindFlags flags;
 	if (backwards) flags |= QWebEnginePage::FindBackward;
 	if (findbar->isOptionSet (RKFindBar::MatchCase)) flags |= QWebEnginePage::FindCaseSensitively;
-	page->findText (text, flags, [this](bool found) { if (!found) this->findbar->indicateSearchFail(); });
-#endif
+	page->findText (text, flags, [this](QWebEngineFindTextResult result) {
+		if (result.numberOfMatches() == 0) {
+			this->findbar->indicateSearchFail();
+		}
+	});
 }
 
 
@@ -605,7 +499,7 @@ bool RKHTMLWindow::handleRKWardURL (const QUrl &url, RKHTMLWindow *window) {
 			if (path.startsWith ('/')) path = path.mid (1);
 			int sep = path.indexOf ('/');
 			// NOTE: These links may originate externally, even from untrusted sources. The submit mode *must* remain "ManualSubmit" for this reason!
-			RKComponentMap::invokeComponent (path.left (sep), path.mid (sep+1).split ('\n', RKCompatibility::SkipEmptyParts()), RKComponentMap::ManualSubmit);
+			RKComponentMap::invokeComponent (path.left (sep), path.mid (sep+1).split ('\n', Qt::SkipEmptyParts), RKComponentMap::ManualSubmit);
 		} else if (url.host () == "rhelp") {
 			// TODO: find a nice solution to render this in the current window
 			QStringList spec = url.path ().mid (1).split ('/');
@@ -658,6 +552,11 @@ bool RKHTMLWindow::handleRKWardURL (const QUrl &url, RKHTMLWindow *window) {
 	return false;
 }
 
+void RKHTMLWindow::setContent(const QString &content) {
+	RK_TRACE(APP);
+	page->setHtmlWrapper(content, QUrl());
+}
+
 bool RKHTMLWindow::openURL (const QUrl &url) {
 	RK_TRACE (APP);
 
@@ -697,11 +596,20 @@ bool RKHTMLWindow::openURL (const QUrl &url) {
 				page->setHtmlWrapper(f.readAll(), url.adjusted(QUrl::RemoveFilename));
 				f.close ();
 			} else {
-				page->load (url);
+				// NOTE: Quirk in Qt 6.7: When first loading a page, the window is somehow brought to the front, again. In preview windows
+				//       (initially hidden), this leads to a strange pulsing effect. Delay the actual page load until the window is
+				//       actually shown (showEvent(), below).
+				//       With this, the flicker is still there, but feels more "natural"
+				if (isVisible()) page->load(url);
 			}
 			if (!restore_position.isNull()) page->setScrollPositionWhenDone(restore_position);
 		} else {
-			fileDoesNotExistMessage ();
+			RK_DEBUG(APP, DL_WARNING, "Attempt to open non-existant local file %s", qPrintable(url.toLocalFile()));
+			if (window_mode == HTMLOutputWindow) {
+				page->setHtmlWrapper(QStringLiteral("<HTML><BODY><H1>") + i18n("RKWard output file %s does not (yet) exist").arg(url.toLocalFile()) + QStringLiteral("</H1>\n</BODY></HTML>"), QUrl());
+			} else {
+				fileDoesNotExistMessage ();
+			}
 		}
 		return ok;
 	}
@@ -717,11 +625,7 @@ bool RKHTMLWindow::openURL (const QUrl &url) {
 		QString host = url.host ();
 		if ((host == "127.0.0.1") || (host == "localhost") || host == QHostInfo::localHostName ()) {
 			KIO::TransferJob *job = KIO::get (url, KIO::Reload);
-#if KIO_VERSION < QT_VERSION_CHECK(5,78,0)
-			connect (job, static_cast<void (KIO::TransferJob::*)(KIO::Job*, const QString&)>(&KIO::TransferJob::mimetype), this, &RKHTMLWindow::mimeTypeDetermined);
-#else
 			connect (job, &KIO::TransferJob::mimeTypeFound, this, &RKHTMLWindow::mimeTypeDetermined);
-#endif
 			// WORKAROUND. See slot.
 			connect (job, &KIO::TransferJob::result, this, &RKHTMLWindow::mimeTypeJobFail);
 			return true;
@@ -732,9 +636,20 @@ bool RKHTMLWindow::openURL (const QUrl &url) {
 	return true;
 }
 
+void RKHTMLWindow::showEvent(QShowEvent *event) {
+	RK_TRACE (APP);
+	RKMDIWindow::showEvent(event);
+	// see comment in openURL, above
+	if (page->url().isEmpty() && !current_url.isEmpty() && current_url != page->url()) {
+		QUrl real_url = current_url;
+		current_url.clear();
+		openURL(real_url);
+	}
+}
+
 void RKHTMLWindow::mimeTypeJobFail (KJob* job) {
 	RK_TRACE (APP);
-	
+
 	KIO::TransferJob* tj = static_cast<KIO::TransferJob*> (job);
 	if (tj->error ()) {
 		// WORKAROUND for bug in KIO version 5.9.0: After a redirect, the transfer job would claim "does not exist". Here, we help it get over _one_ redirect, hoping R's help server
@@ -743,11 +658,7 @@ void RKHTMLWindow::mimeTypeJobFail (KJob* job) {
 		QUrl url = tj->url ();
 		if (!tj->redirectUrl ().isEmpty ()) url = tj->redirectUrl ();
 		KIO::TransferJob *secondchance = KIO::get (url, KIO::Reload);
-#if KIO_VERSION < QT_VERSION_CHECK(5,78,0)
-		connect (secondchance, static_cast<void (KIO::TransferJob::*)(KIO::Job*, const QString&)>(&KIO::TransferJob::mimetype), this, &RKHTMLWindow::mimeTypeDetermined);
-#else
 		connect (secondchance, &KIO::TransferJob::mimeTypeFound, this, &RKHTMLWindow::mimeTypeDetermined);
-#endif
 		connect (secondchance, &KIO::TransferJob::result, this, &RKHTMLWindow::mimeTypeJobFail2);
 	}
 }
@@ -850,7 +761,9 @@ void RKHTMLWindow::refresh () {
 		// need to re-render the page
 		openRKHPage(url());
 	} else {
-		view->reload();
+		// NOTE: Special handling for output window, which may not have existed at the time of first "load"
+		if (!view->url().isEmpty()) view->reload();
+		else view->load(url());
 	}
 }
 
@@ -858,11 +771,7 @@ void RKHTMLWindow::scrollToBottom () {
 	RK_TRACE (APP);
 
 	RK_ASSERT (window_mode == HTMLOutputWindow);
-#ifdef NO_QT_WEBENGINE
-	page->mainFrame ()->setScrollBarValue (Qt::Vertical, view->page ()->mainFrame ()->scrollBarMaximum (Qt::Vertical));
-#else
 	page->runJavaScript(QString("{ let se = (document.scrollingElement || document.body); se.scrollTop = se.scrollHeight; }"));
-#endif
 }
 
 void RKHTMLWindow::zoomIn () {
@@ -875,10 +784,11 @@ void RKHTMLWindow::zoomOut () {
 	view->setZoomFactor (view->zoomFactor () / 1.1);
 }
 
-void RKHTMLWindow::setTextEncoding (QTextCodec* encoding) {
+void RKHTMLWindow::setTextEncoding (QStringConverter::Encoding encoding) {
 	RK_TRACE (APP);
 
-	page->settings ()->setDefaultTextEncoding (encoding->name ());
+	QStringEncoder converter(encoding);
+	page->settings ()->setDefaultTextEncoding (converter.name ());
 	view->reload ();
 }
 
@@ -919,16 +829,7 @@ void RKHTMLWindow::startNewCacheFile () {
 void RKHTMLWindow::fileDoesNotExistMessage () {
 	RK_TRACE (APP);
 
-	startNewCacheFile ();
-	if (window_mode == HTMLOutputWindow) {
-		current_cache_file->write (i18n ("<HTML><BODY><H1>RKWard output file could not be found</H1>\n</BODY></HTML>").toUtf8 ());
-	} else {
-		current_cache_file->write (QString ("<html><body><h1>" + i18n ("Page does not exist or is broken") + "</h1></body></html>").toUtf8 ());
-	}
-	current_cache_file->close ();
-
-	QUrl cache_url = QUrl::fromLocalFile (current_cache_file->fileName ());
-	page->load (cache_url);
+	page->setHtmlWrapper(QString("<html><body><h1>" + i18n ("Page does not exist or is broken") + "</h1></body></html>"), QUrl());;
 }
 
 void RKHTMLWindow::flushOutput () {
@@ -940,8 +841,8 @@ void RKHTMLWindow::flushOutput () {
 	}
 
 	// TODO: remove legacy code below, eventually
-	int res = KMessageBox::questionYesNo (this, i18n ("Do you really want to clear the output? This will also remove all image files used in the output. It will not be possible to restore it."), i18n ("Flush output?"));
-	if (res==KMessageBox::Yes) {
+	int res = KMessageBox::questionTwoActions(this, i18n ("Do you really want to clear the output? This will also remove all image files used in the output. It will not be possible to restore it."), i18n("Flush output?"), KStandardGuiItem::clear(), KStandardGuiItem::cancel());
+	if (res==KMessageBox::PrimaryAction) {
 		QFile out_file (current_url.toLocalFile ());
 		RCommand *c = new RCommand ("rk.flush.output (" + RCommand::rQuote (out_file.fileName ()) + ", ask=FALSE)\n", RCommand::App);
 		connect (c->notifier (), &RCommandNotifier::commandFinished, this, &RKHTMLWindow::refresh);
@@ -977,71 +878,70 @@ void RKHTMLWindowPart::initActions () {
 	window->page->action (RKWebPage::Forward)->setVisible (false);
 	// For now we won't bother with this one: Does not behave well, in particular (but not only) WRT to rkward://-links
 	window->page->action (RKWebPage::DownloadLinkToDisk)->setVisible (false);
-#ifndef NO_QT_WEBENGINE
 	// Not really useful for us, and cannot easily be made to work, as all new pages go through RKWorkplace::openAnyUrl()
 	window->page->action (RKWebPage::ViewSource)->setVisible (false);
 	// Well, technically, all our windows are tabs, but we're calling them "window".
 	// At any rate, we don't need both "open link in new tab" and "open link in new window".
 	window->page->action (RKWebPage::OpenLinkInNewTab)->setVisible (false);
-#endif
 
 	// common actions
-	actionCollection ()->addAction (KStandardAction::Copy, "copy", window->view->pageAction (RKWebPage::Copy), SLOT (trigger()));
+	actionCollection()->addAction(KStandardAction::Copy, "copy", window->view->pageAction(RKWebPage::Copy), &QAction::trigger);
 	QAction* zoom_in = actionCollection ()->addAction ("zoom_in", new QAction (QIcon::fromTheme("zoom-in"), i18n ("Zoom In"), this));
 	connect (zoom_in, &QAction::triggered, window, &RKHTMLWindow::zoomIn);
 	QAction* zoom_out = actionCollection ()->addAction ("zoom_out", new QAction (QIcon::fromTheme("zoom-out"), i18n ("Zoom Out"), this));
 	connect (zoom_out, &QAction::triggered, window, &RKHTMLWindow::zoomOut);
-	actionCollection ()->addAction (KStandardAction::SelectAll, "select_all", window->view->pageAction (RKWebPage::SelectAll), SLOT (trigger()));
+	actionCollection()->addAction(KStandardAction::SelectAll, "select_all", window->view->pageAction(RKWebPage::SelectAll), &QAction::trigger);
 	// unfortunately, this will only affect the default encoding, not necessarily the "real" encoding
 	KCodecAction *encoding = new KCodecAction (QIcon::fromTheme("character-set"), i18n ("Default &Encoding"), this, true);
 	encoding->setWhatsThis(i18n ("Set the encoding to assume in case no explicit encoding has been set in the page or in the HTTP headers."));
 	actionCollection ()->addAction ("view_encoding", encoding);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5,78,0)
-	connect (encoding, static_cast<void (KCodecAction::*)(QTextCodec *)>(&KCodecAction::triggered), window, &RKHTMLWindow::setTextEncoding);
-#else
-	connect (encoding, &KCodecAction::codecTriggered, window, &RKHTMLWindow::setTextEncoding);
-#endif
+	connect (encoding, &KCodecAction::codecNameTriggered, window, [this](const QByteArray &name) {
+		auto encoding = QStringConverter::encodingForName(name.constData());
+		if (encoding) {
+			window->setTextEncoding(encoding.value());
+		}
+	});
 
-	print = actionCollection()->addAction(KStandardAction::Print, "print_html", window, SLOT (slotPrint()));
+	print = actionCollection()->addAction(KStandardAction::Print, "print_html", window, &RKHTMLWindow::slotPrint);
 	export_page = actionCollection()->addAction("save_html", new QAction(QIcon::fromTheme("file-save"), i18n("Export Page as HTML"), this));
 	connect(export_page, &QAction::triggered, window, &RKHTMLWindow::slotExport);
 
 	run_selection = RKStandardActions::runCurrent (window, window, SLOT (runSelection()));
 
 	// help window actions
-	back = actionCollection ()->addAction (KStandardAction::Back, "help_back", window, SLOT (slotBack()));
+	back = actionCollection()->addAction(KStandardAction::Back, "help_back", window, &RKHTMLWindow::slotBack);
 	back->setEnabled (false);
 
-	forward = actionCollection ()->addAction (KStandardAction::Forward, "help_forward", window, SLOT (slotForward()));
+	forward = actionCollection()->addAction(KStandardAction::Forward, "help_forward", window, &RKHTMLWindow::slotForward);
 	forward->setEnabled (false);
 
 	// output window actions
-	window->file_save_action = actionCollection()->addAction(KStandardAction::Save, window, SLOT(slotSave()));
+	window->file_save_action = actionCollection()->addAction(KStandardAction::Save, "file_save", window, &RKHTMLWindow::slotSave);
 	window->file_save_action->setText(i18n("Save Output"));
-	window->file_save_as_action = actionCollection()->addAction(KStandardAction::SaveAs, window, SLOT(slotSaveAs()));
+	window->file_save_as_action = actionCollection()->addAction(KStandardAction::SaveAs, "file_save_as", window, &RKHTMLWindow::slotSaveAs);
 	window->file_save_as_action->setText(i18n("Save Output As"));
 
-	outputFlush = actionCollection ()->addAction ("output_flush", window, SLOT (flushOutput()));
+	outputFlush = actionCollection()->addAction("output_flush", window, &RKHTMLWindow::flushOutput);
 	outputFlush->setText (i18n ("&Clear Output"));
 	outputFlush->setIcon (QIcon::fromTheme("edit-delete"));
 
 	outputRefresh = actionCollection()->addAction("output_refresh", window->page->action(RKWebPage::Reload));
 
-	revert = actionCollection()->addAction("output_revert", window, SLOT(slotRevert()));
+	revert = actionCollection()->addAction("output_revert", window, &RKHTMLWindow::slotRevert);
 	revert->setText(i18n("&Revert to last saved state"));
 	revert->setIcon(QIcon::fromTheme("edit-undo"));
 
-	activate = actionCollection()->addAction("output_activate", window, SLOT(slotActivate()));
+	activate = actionCollection()->addAction("output_activate", window, &RKHTMLWindow::slotActivate);
 	activate->setText(i18n("Set Output as &Active"));
 	activate->setIcon(QIcon::fromTheme("emblem-favorite"));
 	activate->setWhatsThis(i18n("Set this output as the file to append output to."));
 
-	actionCollection ()->addAction (KStandardAction::Find, "find", window->findbar, SLOT (activate()));
+	actionCollection()->addAction(KStandardAction::Find, "find", window->findbar, &RKFindBar::activate);
 	QAction* findAhead = actionCollection ()->addAction ("find_ahead", new QAction (i18n ("Find as you type"), this));
 	actionCollection ()->setDefaultShortcut (findAhead, '/');
 	connect (findAhead, &QAction::triggered, window->findbar, &RKFindBar::activate);
-	actionCollection ()->addAction (KStandardAction::FindNext, "find_next", window->findbar, SLOT (forward()));
-	actionCollection ()->addAction (KStandardAction::FindPrev, "find_previous", window->findbar, SLOT (backward()));
+	actionCollection()->addAction(KStandardAction::FindNext, "find_next", window->findbar, &RKFindBar::forward);
+	actionCollection()->addAction(KStandardAction::FindPrev, "find_previous", window->findbar, &RKFindBar::backward);
 }
 
 void RKHTMLWindowPart::setOutputDirectoryActionsEnabled(bool enable) {
@@ -1085,13 +985,13 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url, RKHTMLWindow* container) {
 
 	QStringList anchors, anchornames;
 
-	RKComponentHandle *chandle = 0;
+	RKComponentHandle *chandle = nullptr;
 	if (for_component) {
 		chandle = componentPathToHandle (url.path ());
 		if (!chandle) return false;
 	}
 
-	XMLHelper component_xml_helper (for_component ? chandle->getFilename () : QString (), for_component ? chandle->messageCatalog () : 0);
+	XMLHelper component_xml_helper(for_component ? chandle->getFilename() : QString(), for_component ? chandle->messageCatalog() : nullptr);
 	component_xml = &component_xml_helper;
 	QString help_file_name;
 	QDomElement element;
@@ -1312,7 +1212,7 @@ QString RKHelpRenderer::renderHelpFragment (QDomElement &fragment) {
 	int npos;
 	QString ret;
 	while ((npos = text.indexOf ("<link", pos)) >= 0) {
-		ret += text.midRef(pos, npos - pos);
+		ret += QStringView{text}.mid(pos, npos - pos);
 
 		QString href;
 		int href_start = text.indexOf (" href=\"", npos + 5);
@@ -1332,14 +1232,14 @@ QString RKHelpRenderer::renderHelpFragment (QDomElement &fragment) {
 		ret += prepareHelpLink (href, linktext);
 		pos = end;
 	}
-	ret += text.midRef(pos);
+	ret += QStringView{text}.mid(pos);
 
 	if (component_xml) {
 		text = ret;
 		ret.clear ();
 		pos = 0;
 		while ((npos = text.indexOf ("<label ", pos)) >= 0) {
-			ret += text.midRef(pos, npos - pos);
+			ret += QStringView{text}.mid(pos, npos - pos);
 
 			QString id;
 			int id_start = text.indexOf ("id=\"", npos + 6);
@@ -1351,7 +1251,7 @@ QString RKHelpRenderer::renderHelpFragment (QDomElement &fragment) {
 			}
 			ret += resolveLabel (id);
 		}
-		ret += text.midRef(pos);
+		ret += QStringView{text}.mid(pos);
 	}
 
 	RK_DEBUG (APP, DL_DEBUG, "%s", qPrintable (ret));
@@ -1395,9 +1295,9 @@ QString RKHelpRenderer::prepareHelpLink (const QString &href, const QString &tex
 QString RKHelpRenderer::componentPathToId (const QString &path) {
 	RK_TRACE (APP);
 
-	QStringList path_segments = path.split ('/', RKCompatibility::SkipEmptyParts());
-	if (path_segments.count () > 2) return 0;
-	if (path_segments.count () < 1) return 0;
+	QStringList path_segments = path.split ('/', Qt::SkipEmptyParts);
+	if (path_segments.count () > 2) return QString();
+	if (path_segments.count () < 1) return QString();
 	if (path_segments.count () == 1) path_segments.push_front ("rkward");
 	RK_ASSERT (path_segments.count () == 2);
 
@@ -1438,7 +1338,7 @@ void RKHelpRenderer::writeHTML (const QString& string) {
 #include <KIO/CopyJob>
 
 // static
-RKOutputWindowManager* RKOutputWindowManager::_self = 0;
+RKOutputWindowManager* RKOutputWindowManager::_self = nullptr;
 
 RKOutputWindowManager* RKOutputWindowManager::self () {
 	if (!_self) {
@@ -1516,7 +1416,7 @@ void RKOutputWindowManager::setCurrentOutputPath (const QString &_path) {
 	// watch list (KDE 4.10.2; always?), so we need to re-add it. To make things complex, however, this may happen
 	// asynchronously, with this function called (via rk.set.output.html.file()), _before_ KDirWatch purges the file.
 	// To hack around the race condition, we re-watch the output file after a short delay.
-	QTimer::singleShot (100, this, SLOT (rewatchOutput()));
+	QTimer::singleShot(100, this, [this](){ rewatchOutput(); });
 #endif
 	if (path == current_default_path) return;
 
@@ -1555,7 +1455,7 @@ QList<RKHTMLWindow*> RKOutputWindowManager::existingOutputWindows(const QString
 void RKOutputWindowManager::fileChanged (const QString &path) {
 	RK_TRACE (APP);
 
-	RKHTMLWindow *w = 0;
+	RKHTMLWindow *w = nullptr;
 	QList<RKHTMLWindow *> window_list = windows.values (path);
 	for (int i = 0; i < window_list.size (); ++i) {
 		window_list[i]->refresh ();
