@@ -9,15 +9,18 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #define RKHTMLWINDOW_H
 
 #include <QUrl>
-#include <kparts/part.h>
-#include <kio/jobclasses.h>
+#include <KParts/Part>
 
 #include <QDomElement>
 #include <QNetworkRequest>
 
 #include "../windows/rkmdiwindow.h"
 
+namespace KIO {
+class Job;
+}
 class KActionCollection;
+class KJob;
 class KRecentFilesAction;
 class QAction;
 class RKComponentHandle;
@@ -56,14 +59,14 @@ public:
 	~RKHTMLWindow ();
 /** open given URL. Returns false, if the URL is not an existing local file. Loading a non-local URL may succeed, even if this returns false! */
 	bool openURL (const QUrl &url);
+/** Show the given content, assuming HTML mimetype. */
+	void setContent(const QString &content);
 /** takes care of special handling, if the url is an rkward://-url. Does nothing and returns false, otherwise.
  *  If window is not 0, and the url is a help window, open it, there (otherwise in a new window).
  *  TODO: move to RKWorkplace? As this can really open a bunch of different things, although generally _from_ an html window.
  */
-	static bool handleRKWardURL (const QUrl &url, RKHTMLWindow *window=0);
+	static bool handleRKWardURL(const QUrl &url, RKHTMLWindow *window=nullptr);
 	void openRKHPage (const QUrl &url);
-
-	bool isModified () override;
 /** Return current url */
 	QUrl url () const { return current_url; };
 /** Return current url in a restorable way, i.e. for help pages, abstract the session specific part of the path */
@@ -72,7 +75,7 @@ public:
 	RKOutputDirectory *outputDirectory() const { return dir; };
 
 	WindowMode mode () { return window_mode; };
-public slots:
+public Q_SLOTS:
 	void slotPrint();
 	void slotExport();
 	void slotSave();
@@ -89,9 +92,9 @@ public slots:
 	void refresh ();
 	void zoomIn ();
 	void zoomOut ();
-	void setTextEncoding (QTextCodec* encoding);
+	void setTextEncoding (QStringConverter::Encoding encoding);
 	void updateState();
-private slots:
+private Q_SLOTS:
 	void scrollToBottom ();
 	void mimeTypeDetermined (KIO::Job*, const QString& type);
 	void mimeTypeJobFail (KJob*);
@@ -122,6 +125,7 @@ friend class RKHTMLWindowPart;
 	bool url_change_is_from_history;	// dirty!!!
 
 	QUrl current_url;
+	void showEvent(QShowEvent *event) override;
 	void startNewCacheFile ();
 	QTemporaryFile *current_cache_file;
 
@@ -173,7 +177,7 @@ friend class RKHTMLWindow;
 class RKHelpRenderer {
 public:
 /** ctor */
-	explicit RKHelpRenderer (QIODevice *_device) { device = _device; help_xml = 0; component_xml = 0; };
+	explicit RKHelpRenderer(QIODevice *_device) { device = _device; help_xml = nullptr; component_xml = nullptr; };
 /** destructor */
 	~RKHelpRenderer () {};
 /** render an rkward://[page|component]-page to the device given in the ctor.
@@ -223,7 +227,7 @@ private:
 	QString current_default_path;
 	KDirWatch *file_watcher;
 	QMultiHash<QString, RKHTMLWindow *> windows;
-private slots:
+private Q_SLOTS:
 	void fileChanged (const QString &path);
 	void windowDestroyed (QObject *window);
 	void rewatchOutput ();
