@@ -13,7 +13,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QUrl>
 #include <QTimer>
 
-#include <kparts/part.h>
+#include <KParts/Part>
 
 #include "../settings/rksettings.h"
 
@@ -41,6 +41,7 @@ public:
 		HelpWindow=1 << 3,
 		X11Window=1 << 4,
 		ObjectWindow=1 << 5,
+		PDFWindow=1 << 6,
 		ConsoleWindow=1 << 10,
 		CommandLogWindow=1 << 11,
 		WorkspaceBrowserWindow=1 << 12,
@@ -66,14 +67,14 @@ protected:
 /** constructor
 @param parent parent widget
 @param type Type of window (see RKMDIWindow::Type).*/
-	RKMDIWindow (QWidget *parent, int type, bool tool_window=false, const char *name=0);
+	RKMDIWindow (QWidget *parent, int type, bool tool_window=false, const char *name = nullptr);
 	virtual ~RKMDIWindow ();
-public slots:
-/** Reimplemented from QWidget::setCaption () to emit the signal captionChanged () when the caption is changed. */
+public Q_SLOTS:
+/** Reimplemented from QWidget::setCaption () to Q_EMIT the signal captionChanged () when the caption is changed. */
 	void setCaption (const QString &caption);
 public:
 /** @returns true, if the window's document was modified (and would need to be saved) */
-	virtual bool isModified () { return false; };
+	virtual bool isModified () const { return false; };
 /** Ask the window's document to save itself.
 @returns true on success, _or_ if the document cannot be saved at all (in which case isModified() should return false, too. False, if saving failed / was cancelled */
 	virtual bool save () { return true; };
@@ -82,7 +83,7 @@ public:
 /** @returns A short caption (e.g. only the filename without the path). Default implementation simply calls QWidget::caption () */
 	virtual QString shortCaption ();
 /** @returns The corresponding KPart for this window */
-	KParts::Part *getPart () { return part; };
+	KParts::Part *getPart() const { return part; };
 /** Is this window attached (or detached)?
 @returns true if attached, false if detached */
 	bool isAttached () const { return (state == Attached); };
@@ -107,7 +108,7 @@ public:
 /** Set a status message to be shown in a popup inside the window. The message persists until the given R command has finished, or until this function is called with an empty string.
 This should be used, when the information shown is currently out-of-date (e.g. when refreshing a preview / loading a plot from history), _not_ when the window
 is simply busy (e.g. when saving the current plot to history). */
-	void setStatusMessage (const QString& message, RCommand* command=0);
+	void setStatusMessage (const QString& message, RCommand* command = nullptr);
 /** Set a style hint for the window. So far the only interpreted style hint is "preview", and not all windows implement it. Base implements hiding of "active" indicator border for "preview"s. */
 	virtual void setWindowStyleHint (const QString& hint);
 
@@ -130,13 +131,13 @@ is simply busy (e.g. when saving the current plot to history). */
  *  For the time being, only a single buddy is allowed, and it must outlive all mdi windows. */
 	void addUiBuddy(KXMLGUIClient* buddy);
 	KXMLGUIClient* uiBuddy() const { return ui_buddy; };
-signals:
+Q_SIGNALS:
 /** This signal is emitted, whenever the window caption was changed.
 @param RKMDIWindow* a pointer to this window */
 	void captionChanged (RKMDIWindow *);
 /** This signal is emitted, when the window was activated *with* focus */
 	void windowActivated (RKMDIWindow *);
-protected slots:
+protected Q_SLOTS:
 	void showWindowHelp ();
 	void showWindowSettings ();
 	void clearStatusMessage ();
@@ -149,7 +150,7 @@ protected:
 	void removeUiBuddy(QObject* buddy);
 
 /** reimplemented from QWidget to emulate focus-follows-mouse behavior */
-	void enterEvent (QEvent *event) override;
+	void enterEvent (QEnterEvent *event) override;
 /** @see globalContextProperty() */
 	void setGlobalContextProperty (const QString& property, const QString& value) { global_context_properties.insert (property, value); };
 
@@ -160,7 +161,7 @@ protected:
 friend class RKWorkplace;
 /** type of this window */
 	int type;
-private slots:
+private Q_SLOTS:
 	void slotActivateForFocusFollowsMouse ();
 protected:
 	QAction* file_save_as_action;
