@@ -1,6 +1,6 @@
 /*
 rktoolwindowlist - This file is part of the RKWard project. Created: Thu Apr 07 2011
-SPDX-FileCopyrightText: 2011 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2011-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,6 +10,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <QList>
 #include <QString>
+#include <QKeyCombination>
 
 class RKMDIWindow;
 
@@ -27,10 +28,10 @@ namespace RKToolWindowList {
 		RKMDIWindow *window;
 		QString id;
 		Placement default_placement;
-		int default_shortcut;
+		QKeyCombination default_shortcut;
 	};
 
-	void registerToolWindow (RKMDIWindow *window, const QString &id, Placement default_placement, int default_shortcut);
+	void registerToolWindow (RKMDIWindow *window, const QString &id, Placement default_placement, const QKeyCombination& default_shortcut);
 	void unregisterToolWindow (RKMDIWindow *window);
 	RKMDIWindow* findToolWindowById (const QString &id);
 	QString idOfWindow (RKMDIWindow *window);
