@@ -29,8 +29,8 @@ Note: Most actual functionality is realized in RObjectBrowserInternal, which is
 */
 class RObjectBrowser : public RKMDIWindow {
 public:
-	RObjectBrowser (QWidget *parent, bool tool_window, const char *name=0);
-	~RObjectBrowser ();
+	RObjectBrowser(QWidget *parent, bool tool_window, const char *name=nullptr);
+	~RObjectBrowser();
 	void unlock ();
 	static RObjectBrowser *mainBrowser () { return object_browser; };
 /** reimplemented to create the real file browser widget only when the file browser is shown for the first time */
@@ -55,7 +55,7 @@ Q_OBJECT
 public:
 	explicit RObjectBrowserInternal (QWidget *parent, RObjectBrowser *browser);
 	~RObjectBrowserInternal ();
-private slots:
+private Q_SLOTS:
 	void updateButtonClicked ();
 	void contextMenuCallback (RObject *object, bool *suppress);
 
