@@ -2,7 +2,7 @@ local({
 ## Prepare
 cor.graph <- function(x) {
 	panel.cor <- function(x, y, digits=3, cex.cor, use="pairwise.complete.obs", method="pearson", scale=TRUE) {
-		usr <- par("usr"); on.exit(par(usr))
+		usr <- par("usr"); on.exit(par(usr=usr))
 		par(usr = c(0, 1, 0, 1))
 		r <- abs(cor(x, y, use=use, method=method))
 		txt <- format(c(r, 0.123456789), digits=digits)[1]
